@@ -4,28 +4,20 @@ module RapidDiffs
   module Viewers
     module Text
       class LineNumberComponent < ViewComponent::Base
-        def initialize(line:, position:, file_hash:, file_path:, border: nil)
+        def initialize(line:, line_id:, position:, border: nil)
           @line = line
+          @line_id = line_id
           @position = position
-          @file_hash = file_hash
-          @file_path = file_path
           @border = border
         end
 
-        def id
-          @line.id(@file_hash, @position)
-        end
-
         def line_number
           @position == :old ? @line.old_pos : @line.new_pos
         end
 
-        def legacy_id
-          @line.legacy_id(@file_path)
-        end
-
         def change_type
           return unless @line
+          return 'meta' if @line.meta?
           return 'added' if @line.added?
 
           'removed' if @line.removed?
@@ -46,7 +38,7 @@ module RapidDiffs
         end
 
         def visible?
-          return false unless @line
+          return false unless @line && !@line.meta?
 
           case @position
           when :old then !@line.added?
