@@ -16,7 +16,7 @@ class Admin::UsersController < Admin::ApplicationController
   def index
     return redirect_to admin_cohorts_path if params[:tab] == 'cohorts'
 
-    @users = User.filter_items(params[:filter]).order_name_asc
+    @users = filter_users
 
     if params[:search_query].present?
       # rubocop:disable Gitlab/AvoidGitlabInstanceChecks -- available only for self-managed instances
@@ -35,8 +35,9 @@ class Admin::UsersController < Admin::ApplicationController
 
   # rubocop: disable CodeReuse/ActiveRecord
   def projects
-    @personal_projects = user.personal_projects.includes(:topics)
-    @joined_projects = user.projects.joined(@user).includes(:topics)
+    @personal_projects = user.personal_projects.includes(:topics).page(safe_params[:personal_projects_page]).per(10)
+    @joined_projects = user.projects.joined(@user).includes(:topics).page(safe_params[:projects_page])
+    @user_group_members = user.group_members.or(user.minimal_access_group_members).page(safe_params[:groups_page])
   end
 
   def keys
@@ -327,7 +328,7 @@ class Admin::UsersController < Admin::ApplicationController
   end
 
   def users_with_included_associations(users)
-    users.includes(:authorized_projects, :trusted_with_spam_attribute, :identities) # rubocop: disable CodeReuse/ActiveRecord
+    users.includes(:trusted_with_spam_attribute, :identities) # rubocop: disable CodeReuse/ActiveRecord
   end
 
   def admin_making_changes_for_another_user?
@@ -401,11 +402,11 @@ class Admin::UsersController < Admin::ApplicationController
       :projects_limit,
       :provider,
       :remember_me,
-      :skype,
       :theme_id,
       :twitter,
       :username,
       :website_url,
+      :github,
       { credit_card_validation_attributes: [:credit_card_validated_at] },
       { organization_users_attributes: [:id, :organization_id, :access_level] }
     ]
@@ -460,6 +461,14 @@ class Admin::UsersController < Admin::ApplicationController
   def after_successful_update_flash
     { notice: _('User was successfully updated.') }
   end
+
+  def filter_users
+    User.filter_items(params[:filter]).order_name_asc
+  end
+
+  def safe_params
+    params.permit(:personal_projects_page, :projects_page, :groups_page)
+  end
 end
 
 Admin::UsersController.prepend_mod_with('Admin::UsersController')
