@@ -20,10 +20,17 @@ module HomepageData
       duo_code_review_bot_username: duo_code_review_bot.username,
       merge_requests_review_requested_title: dashboard_list_title(mr_requested_id),
       merge_requests_your_merge_requests_title: dashboard_list_title(mr_requests_id),
-      last_push_event: prepare_last_push_event_data(last_push_event)&.to_json
+      last_push_event: prepare_last_push_event_data(last_push_event)&.to_json,
+      show_feedback_widget: show_feedback_widget?.to_s
     }
   end
 
+  def show_feedback_widget?
+    return true unless Gitlab.ee?
+
+    !License.current&.offline_cloud_license?
+  end
+
   def prepare_last_push_event_data(last_push_event)
     return unless last_push_event
 
