@@ -91,7 +91,7 @@ module IssuableActions
   end
 
   def destroy
-    Issuable::DestroyService.new(container: issuable.project, current_user: current_user).execute(issuable)
+    destroy_service.execute(issuable)
 
     name = issuable.human_class_name
     flash[:notice] = "The #{name} was successfully deleted."
@@ -251,6 +251,7 @@ module IssuableActions
       :state_event,
       :subscription_event,
       :confidential,
+      :status,
       { assignee_ids: [],
         add_label_ids: [],
         remove_label_ids: [] }
@@ -279,6 +280,10 @@ module IssuableActions
     raise NotImplementedError
   end
 
+  def destroy_service
+    Issuable::DestroyService.new(container: issuable.project, current_user: current_user)
+  end
+
   def parent
     @project || @group # rubocop:disable Gitlab/ModuleWithInstanceVariables
   end
