@@ -26,21 +26,31 @@ module KnownSignIn
   end
 
   def update_cookie
-    set_secure_cookie(KNOWN_SIGN_IN_COOKIE, current_user.id,
-                      type: COOKIE_TYPE_ENCRYPTED, httponly: true, expires: KNOWN_SIGN_IN_COOKIE_EXPIRY)
+    set_secure_cookie(
+      KNOWN_SIGN_IN_COOKIE,
+      current_user.id,
+      type: COOKIE_TYPE_ENCRYPTED,
+      httponly: true,
+      expires: KNOWN_SIGN_IN_COOKIE_EXPIRY
+    )
   end
 
   def sessions
-    strong_memoize(:session) do
-      ActiveSession.list(current_user).reject(&:is_impersonated)
-    end
+    ActiveSession.list(current_user).reject(&:is_impersonated)
   end
+  strong_memoize_attr :sessions
 
   def known_ip_addresses
     [current_user.last_sign_in_ip, sessions.map(&:ip_address)].flatten
   end
 
   def notify_user
-    current_user.notification_service.unknown_sign_in(current_user, request.remote_ip, current_user.current_sign_in_at)
+    request_info = Gitlab::Auth::VisitorLocation.new(request)
+    current_user.notification_service.unknown_sign_in(
+      current_user,
+      request.remote_ip,
+      current_user.current_sign_in_at,
+      request_info
+    )
   end
 end
