@@ -1,5 +1,6 @@
 # frozen_string_literal: true
 
+# Remove this file once we migrate the legacy UI to use initSharedAccessTokenApp.
 module RenderAccessTokens
   extend ActiveSupport::Concern
 
@@ -32,16 +33,4 @@ module RenderAccessTokens
   def page
     (pagination_params[:page] || 1).to_i
   end
-
-  def expiry_ics(tokens)
-    cal = Icalendar::Calendar.new
-    tokens.each do |token|
-      cal.event do |event|
-        event.dtstart = Icalendar::Values::Date.new(token[:expires_at].delete('-'))
-        event.dtend = Icalendar::Values::Date.new(token[:expires_at].delete('-'))
-        event.summary = "Token #{token[:name]} expires today"
-      end
-    end
-    cal.to_ical
-  end
 end
