@@ -23,7 +23,7 @@ module WebIdeCSP
 
     default_src = Array(request.content_security_policy.directives['default-src'] || [])
     request.content_security_policy.directives['frame-src'] ||= default_src
-    request.content_security_policy.directives['frame-src'].concat([webpack_url, 'https://*.web-ide.gitlab-static.net/',
+    request.content_security_policy.directives['frame-src'].concat([webpack_url, "https://*.#{WebIde::ExtensionMarketplace.extension_host_domain}/",
       ide_oauth_redirect_url, oauth_authorization_url])
 
     request.content_security_policy.directives['worker-src'] ||= default_src
