@@ -3,12 +3,12 @@
 class Explore::SnippetsController < Explore::ApplicationController
   include Gitlab::NoteableMetadata
 
-  feature_category :snippets
+  feature_category :source_code_management
 
   def index
     @snippets = SnippetsFinder.new(current_user, explore: true)
       .execute
-      .page(params[:page])
+      .page(pagination_params[:page])
       .without_count
       .inc_author
       .inc_statistics
