@@ -4,10 +4,10 @@ class Groups::GroupLinksController < Groups::ApplicationController
   before_action :authorize_admin_group!
   before_action :group_link, only: [:update, :destroy]
 
-  feature_category :subgroups
+  feature_category :groups_and_projects
 
   def update
-    Groups::GroupLinks::UpdateService.new(@group_link).execute(group_link_params)
+    Groups::GroupLinks::UpdateService.new(@group_link, current_user).execute(group_link_params)
 
     if @group_link.expires?
       render json: {
@@ -24,7 +24,12 @@ class Groups::GroupLinksController < Groups::ApplicationController
 
     respond_to do |format|
       format.html do
-        redirect_to group_group_members_path(group), status: :found
+        redirect_to(
+          group_group_members_path(group),
+          status: :found,
+          notice: s_('InviteMembersModal|Group invite removed. ' \
+            'It might take a few minutes for the changes to user access levels to take effect.')
+        )
       end
       format.js { head :ok }
     end
@@ -37,6 +42,6 @@ class Groups::GroupLinksController < Groups::ApplicationController
   end
 
   def group_link_params
-    params.require(:group_link).permit(:group_access, :expires_at)
+    params.require(:group_link).permit(:group_access, :expires_at, :member_role_id)
   end
 end
