@@ -12,21 +12,27 @@ module Groups
       def new; end
 
       def create
-        result = ::Observability::AccessRequestService.new(
-          group,
-          current_user
-        ).execute
+        if group.observability_group_o11y_setting.present?
+          flash[:alert] = s_('Observability|Observability is already enabled for this group')
+        else
+          result = ::Observability::AccessRequestService.new(
+            group,
+            current_user
+          ).execute
 
-        return if result.success?
+          if result.success?
+            flash[:success] = s_('Observability|Welcome to GitLab Observability!')
+          else
+            flash[:alert] = result.message
+          end
+        end
 
-        flash.now[:alert] = result.message
-        render :new, status: :unprocessable_entity
+        redirect_to group_observability_setup_path(group)
       end
 
       private
 
       def authorize_request_access!
-        return render_404 if group.observability_group_o11y_setting.present?
         return render_404 unless ::Feature.enabled?(:observability_sass_features, group)
 
         return if Ability.allowed?(current_user, :create_observability_access_request, group)
