@@ -23,6 +23,8 @@ module Groups
       def show
         @entity = :group
         @variable_limit = ::Plan.default.actual_limits.group_ci_variables
+
+        audit_group_cicd_settings_access
       end
 
       def update
@@ -51,11 +53,29 @@ module Groups
 
       private
 
+      def audit_group_cicd_settings_access
+        audit_context = {
+          name: 'group_ci_cd_settings_accessed',
+          author: current_user,
+          scope: group,
+          target: group,
+          message: 'User accessed CI/CD settings for a group',
+          additional_details: {
+            group_path: group.full_path,
+            group_id: group.id,
+            timestamp: Time.current.iso8601,
+            action: 'group_ci_cd_settings_page_viewed'
+          }
+        }
+
+        ::Gitlab::Audit::Auditor.audit(audit_context)
+      end
+
       def authorize_show_cicd_settings!
         return if can_any?(current_user, [
           :admin_cicd_variables,
           :admin_protected_environments,
-          :admin_runner
+          :admin_runners
         ], group)
 
         access_denied!
@@ -98,8 +118,7 @@ module Groups
         params.require(:group).permit(
           :max_artifacts_size,
           :allow_runner_registration_token,
-          :jwt_ci_cd_job_token_enabled,
-          :job_token_policies_enabled
+          :jwt_ci_cd_job_token_enabled
         )
       end
 
