@@ -7,11 +7,15 @@ module Groups
       before_action :authorize_admin_group!
       before_action :verify_packages_enabled!
 
+      before_action do
+        push_frontend_feature_flag(:maven_central_request_forwarding, group)
+        push_frontend_ability(ability: :admin_dependency_proxy, resource: group, user: current_user)
+      end
+
       feature_category :package_registry
       urgency :low
 
-      def show
-      end
+      def show; end
 
       private
 
@@ -21,3 +25,5 @@ module Groups
     end
   end
 end
+
+Groups::Settings::PackagesAndRegistriesController.prepend_mod
