@@ -3,10 +3,9 @@
 module Groups
   class SharedProjectsController < Groups::ApplicationController
     respond_to :json
-    before_action :group
     skip_cross_project_access_check :index
 
-    feature_category :subgroups
+    feature_category :groups_and_projects
     urgency :low, [:index]
 
     def index
