@@ -6,6 +6,12 @@ class Groups::UploadsController < Groups::ApplicationController
 
   skip_before_action :group, if: -> { action_name == 'show' && embeddable? }
 
+  # TODO: Remove this skip and implement step-up auth enforcement for uploads
+  # See: https://gitlab.com/gitlab-org/gitlab/-/issues/578693
+  # This skip_before_action is temporary to avoid breaking uploads while we add
+  # comprehensive test coverage and proper enforcement in a follow-up MR.
+  skip_before_action :enforce_step_up_auth_for_namespace
+
   before_action :authorize_upload_file!, only: [:create, :authorize]
   before_action :verify_workhorse_api!, only: [:authorize]
   before_action :disallow_new_uploads!, only: :show
