@@ -6,11 +6,12 @@ class JiraConnect::InstallationsController < JiraConnect::ApplicationController
   end
 
   def update
-    if current_jira_installation.update(installation_params)
+    result = update_installation
+    if result.success?
       render json: installation_json(current_jira_installation)
     else
       render(
-        json: { errors: current_jira_installation.errors },
+        json: { errors: result.message },
         status: :unprocessable_entity
       )
     end
@@ -18,6 +19,13 @@ class JiraConnect::InstallationsController < JiraConnect::ApplicationController
 
   private
 
+  def update_installation
+    JiraConnectInstallations::UpdateService.execute(
+      current_jira_installation,
+      installation_params
+    )
+  end
+
   def installation_json(installation)
     {
       gitlab_com: installation.instance_url.blank?,
@@ -26,6 +34,9 @@ class JiraConnect::InstallationsController < JiraConnect::ApplicationController
   end
 
   def installation_params
-    params.require(:installation).permit(:instance_url)
+    params
+      .require(:installation)
+      .permit(:instance_url)
+      .merge(organization_id: Current.organization.id)
   end
 end
