@@ -28,7 +28,7 @@ class Ldap::OmniauthCallbacksController < OmniauthCallbacksController
   define_providers!
 
   override :set_remember_me
-  def set_remember_me(user)
+  def set_remember_me(user, _auth_user)
     user.remember_me = params[:remember_me] if user.persisted?
   end
 
@@ -50,6 +50,11 @@ class Ldap::OmniauthCallbacksController < OmniauthCallbacksController
       server['provider_name']
     end
   end
+
+  override :log_audit_event
+  def log_audit_event(user, options = {})
+    super(user, options, 'authenticated_with_ldap')
+  end
 end
 
 Ldap::OmniauthCallbacksController.prepend_mod_with('Ldap::OmniauthCallbacksController')
