@@ -1,8 +1,7 @@
 # frozen_string_literal: true
 
-# rubocop:disable Rails/ApplicationController
-class MetricsController < ActionController::Base
-  include RequiresWhitelistedMonitoringClient
+class MetricsController < BaseActionController
+  include RequiresAllowlistedMonitoringClient
 
   protect_from_forgery with: :exception, prepend: true
 
@@ -10,9 +9,8 @@ class MetricsController < ActionController::Base
     response = if Gitlab::Metrics.prometheus_metrics_enabled?
                  metrics_service.metrics_text
                else
-                 help_page = help_page_url('administration/monitoring/prometheus/gitlab_metrics',
-                                           anchor: 'gitlab-prometheus-metrics'
-                                          )
+                 help_page = help_page_url(
+                   'administration/monitoring/prometheus/gitlab_metrics.md')
                  "# Metrics are disabled, see: #{help_page}\n"
                end
 
@@ -35,4 +33,3 @@ class MetricsController < ActionController::Base
     )
   end
 end
-# rubocop:enable Rails/ApplicationController
