@@ -8,12 +8,11 @@ module Projects
         include SendFileUpload
 
         before_action :validate_size!
-
-        skip_before_action :default_cache_headers, only: :show
+        before_action :validate_sha!
 
         def show
           relation = design.actions
-          relation = relation.up_to_version(sha) if sha
+          relation = relation.up_to_version(version) if version
           action = relation.most_recent.first
 
           return render_404 unless action
@@ -37,9 +36,19 @@ module Projects
           render_404 unless ::DesignManagement::DESIGN_IMAGE_SIZES.include?(size)
         end
 
+        def validate_sha!
+          render_404 if sha && version.blank?
+        end
+
         def size
           params[:id]
         end
+
+        def version
+          return if sha.blank?
+
+          @version ||= design.versions.find_by_sha(sha)
+        end
       end
     end
   end
