@@ -12,7 +12,7 @@ class Projects::MergeRequests::CreationsController < Projects::MergeRequests::Ap
   before_action :authorize_create_merge_request_from!
   before_action :apply_diff_view_cookie!, only: [:diffs, :diff_for_path]
   before_action :build_merge_request, except: [:create]
-  before_action :start_covered_experience_create_mr, only: [:create]
+  before_action :start_user_experience_create_mr, only: [:create]
 
   feature_category :continuous_integration, [:pipelines]
 
@@ -187,8 +187,8 @@ class Projects::MergeRequests::CreationsController < Projects::MergeRequests::Ap
     @project.namespace
   end
 
-  def start_covered_experience_create_mr
-    Gitlab::CoveredExperience.start_covered_experience_create_merge_request(project)
+  def start_user_experience_create_mr
+    Labkit::UserExperienceSli.start(:create_merge_request)
   end
 end
 
