@@ -6,7 +6,7 @@ class Projects::NetworkController < Projects::ApplicationController
 
   before_action :require_non_empty_project
   before_action :assign_ref_vars
-  before_action :authorize_download_code!
+  before_action :authorize_read_code!
   before_action :assign_options
   before_action :assign_commit
 
@@ -14,7 +14,11 @@ class Projects::NetworkController < Projects::ApplicationController
   urgency :low, [:show]
 
   def show
-    @url = project_network_path(@project, @ref, @options.merge(format: :json))
+    authenticate_user! if require_auth?
+
+    @url = project_network_path(@project, @ref, @options.merge(format: :json, ref_type: ref_type))
+
+    @ref_type = ref_type
     @commit_url = project_commit_path(@project, 'ae45ca32').gsub("ae45ca32", "%s")
 
     respond_to do |format|
@@ -41,4 +45,11 @@ class Projects::NetworkController < Projects::ApplicationController
 
     @commit = @repo.commit(@options[:extended_sha1])
   end
+
+  private
+
+  def require_auth?
+    current_user.blank? && @ref != @project.default_branch_or_main &&
+      Feature.enabled?(:require_login_for_commit_tree, @project)
+  end
 end
