@@ -3,10 +3,11 @@
 module Projects
   module Settings
     class AccessTokensController < Projects::ApplicationController
+      include RenderAccessTokens
       include AccessTokensActions
 
       layout 'project_settings'
-      feature_category :authentication_and_authorization
+      feature_category :system_access
 
       alias_method :resource, :project
 
@@ -19,6 +20,10 @@ module Projects
       def represent(tokens)
         ::ProjectAccessTokenSerializer.new.represent(tokens, project: resource)
       end
+
+      def rotate_service
+        ProjectAccessTokens::RotateService
+      end
     end
   end
 end
