@@ -10,11 +10,9 @@ class Projects::WorkItemsController < Projects::ApplicationController
   before_action :authorize_import_access!, only: [:import_csv, :authorize] # rubocop:disable Rails/LexicallyScopedActionFilter
   before_action do
     push_frontend_feature_flag(:notifications_todos_buttons, current_user)
-    push_force_frontend_feature_flag(:work_items, !!project&.work_items_feature_flag_enabled?)
-    push_force_frontend_feature_flag(:work_items_beta, !!project&.work_items_beta_feature_flag_enabled?)
-    push_force_frontend_feature_flag(:work_items_alpha, !!project&.work_items_alpha_feature_flag_enabled?)
     push_force_frontend_feature_flag(:glql_load_on_click, !!project&.glql_load_on_click_feature_flag_enabled?)
-    push_frontend_feature_flag(:work_item_planning_view, project&.group)
+    push_force_frontend_feature_flag(:work_item_planning_view,
+      !!project&.work_items_consolidated_list_enabled?(current_user))
   end
 
   before_action :check_search_rate_limit!, if: ->(c) do
@@ -42,7 +40,7 @@ class Projects::WorkItemsController < Projects::ApplicationController
   end
 
   def index
-    not_found unless ::Feature.enabled?(:work_item_planning_view, project&.group, type: :wip)
+    not_found unless project&.work_items_consolidated_list_enabled?(current_user)
   end
 
   def show
