@@ -32,6 +32,16 @@ class ProjectsController < Projects::ApplicationController
   before_action :authorize_archive_project!, only: [:archive, :unarchive]
   before_action :event_filter, only: [:show, :activity]
 
+  # Step-up authentication enforcement
+  # IMPORTANT: These before_actions are placed AFTER authorization checks to ensure that
+  # unauthorized users receive a 404/403 response immediately without being prompted for
+  # step-up authentication. This follows the same pattern as GroupsController.
+  # The enforce_step_up_auth_for_namespace method depends on @project being loaded first.
+  # For :new action, the parent's enforcement is sufficient as it checks params[:namespace_id].
+  before_action :enforce_step_up_auth_for_namespace, except: [:index, :create]
+  skip_before_action :enforce_step_up_auth_for_namespace, only: [:create]
+  before_action :enforce_step_up_auth_for_namespace_on_create, only: [:create]
+
   # Project Export Rate Limit
   before_action :check_export_rate_limit!, only: [:export, :download_export, :generate_new_export]
 
@@ -42,19 +52,13 @@ class ProjectsController < Projects::ApplicationController
     push_frontend_feature_flag(:edit_branch_rules, @project)
     # TODO: We need to remove the FF eventually when we rollout page_specific_styles
     push_frontend_feature_flag(:page_specific_styles, current_user)
-    push_frontend_feature_flag(:blob_repository_vue_header_app, @project)
-    push_frontend_feature_flag(:blob_overflow_menu, current_user)
-    push_frontend_feature_flag(:filter_blob_path, current_user)
     push_licensed_feature(:file_locks) if @project.present? && @project.licensed_feature_available?(:file_locks)
     push_frontend_feature_flag(:directory_code_dropdown_updates, current_user)
+    push_frontend_feature_flag(:repository_file_tree_browser, @project)
 
     if @project.present? && @project.licensed_feature_available?(:security_orchestration_policies)
       push_licensed_feature(:security_orchestration_policies)
     end
-
-    push_force_frontend_feature_flag(:work_items, !!@project&.work_items_feature_flag_enabled?)
-    push_force_frontend_feature_flag(:work_items_beta, !!@project&.work_items_beta_feature_flag_enabled?)
-    push_force_frontend_feature_flag(:work_items_alpha, !!@project&.work_items_alpha_feature_flag_enabled?)
   end
 
   layout :determine_layout
@@ -67,7 +71,7 @@ class ProjectsController < Projects::ApplicationController
   feature_category :source_code_management, [:remove_fork, :housekeeping, :refs]
   feature_category :team_planning, [:preview_markdown, :new_issuable_address]
   feature_category :importers, [:export, :remove_export, :generate_new_export, :download_export]
-  feature_category :code_review_workflow, [:unfoldered_environment_names]
+  feature_category :continuous_delivery, [:unfoldered_environment_names]
 
   urgency :low, [:export, :remove_export, :generate_new_export, :download_export]
   urgency :low, [:preview_markdown, :new_issuable_address]
@@ -194,26 +198,20 @@ class ProjectsController < Projects::ApplicationController
   def destroy
     return access_denied! unless can?(current_user, :remove_project, @project)
 
-    return destroy_immediately unless @project.adjourned_deletion_configured?
-    return destroy_immediately if @project.marked_for_deletion_at? && params[:permanently_delete].present?
+    if @project.self_deletion_scheduled? &&
+        ::Gitlab::Utils.to_boolean(params.permit(:permanently_delete)[:permanently_delete])
 
-    result = ::Projects::MarkForDeletionService.new(@project, current_user, {}).execute
+      return destroy_immediately if Gitlab::CurrentSettings.allow_immediate_namespaces_deletion_for_user?(current_user)
 
-    if result[:status] == :success
-      if @project.adjourned_deletion?
-        redirect_to project_path(@project), status: :found
-      else
-        # This is a free project, it will use delayed deletion but can only be restored by an admin.
-        flash[:toast] = format(
-          _("Deleting project '%{project_name}'. All data will be removed on %{date}."),
-          project_name: @project.full_name,
-          # FIXME: Replace `project.marked_for_deletion_at` with `project` after https://gitlab.com/gitlab-org/gitlab/-/work_items/527085
-          date: helpers.permanent_deletion_date_formatted(@project.marked_for_deletion_at)
-        )
-        redirect_to dashboard_projects_path, status: :found
-      end
+      return access_denied!
+    end
+
+    result = ::Projects::MarkForDeletionService.new(@project, current_user).execute
+
+    if result.success?
+      redirect_to project_path(@project), status: :found
     else
-      flash.now[:alert] = result[:message]
+      flash.now[:alert] = result.message
 
       render_edit
     end
@@ -224,14 +222,14 @@ class ProjectsController < Projects::ApplicationController
 
     result = ::Projects::RestoreService.new(@project, current_user, {}).execute
 
-    if result[:status] == :success
+    if result.success?
       flash[:notice] = format(
         _("Project '%{project_name}' has been successfully restored."), project_name: @project.full_name
       )
 
       redirect_to(edit_project_path(@project))
     else
-      flash.now[:alert] = result[:message]
+      flash.now[:alert] = result.message
 
       render_edit
     end
@@ -245,7 +243,7 @@ class ProjectsController < Projects::ApplicationController
   end
 
   def archive
-    ::Projects::UpdateService.new(@project, current_user, archived: true).execute
+    ::Projects::ArchiveService.new(project: @project, current_user: current_user).execute
 
     respond_to do |format|
       format.html { redirect_to project_path(@project) }
@@ -253,7 +251,7 @@ class ProjectsController < Projects::ApplicationController
   end
 
   def unarchive
-    ::Projects::UpdateService.new(@project, current_user, archived: false).execute
+    ::Projects::UnarchiveService.new(project: @project, current_user: current_user).execute
 
     respond_to do |format|
       format.html { redirect_to project_path(@project) }
@@ -369,7 +367,11 @@ class ProjectsController < Projects::ApplicationController
     options = {}
 
     if find_branches
-      branches = BranchesFinder.new(@repository, refs_params.merge(per_page: REFS_LIMIT))
+      # Set default sort to 'updated_desc' for branches if no sort specified
+      branch_params = refs_params.merge(per_page: REFS_LIMIT)
+      branch_params[:sort] = 'updated_desc' if branch_params[:sort].blank?
+
+      branches = BranchesFinder.new(@repository, branch_params)
                    .execute(gitaly_pagination: true)
                    .take(REFS_LIMIT)
                    .map(&:name)
@@ -510,6 +512,7 @@ class ProjectsController < Projects::ApplicationController
       warn_about_potentially_unwanted_characters
       enforce_auth_checks_on_uploads
       merge_request_title_regex
+      merge_request_title_regex_description
       emails_enabled
     ]
 
@@ -550,6 +553,7 @@ class ProjectsController < Projects::ApplicationController
       :template_project_id,
       :merge_method,
       :initialize_with_sast,
+      :initialize_with_secret_detection,
       :initialize_with_readme,
       :ci_separated_caches,
       :suggestion_commit_message,
@@ -558,6 +562,7 @@ class ProjectsController < Projects::ApplicationController
       :merge_commit_template_or_default,
       :squash_commit_template_or_default,
       :merge_request_title_regex,
+      :merge_request_title_regex_description,
       { project_setting_attributes: project_setting_attributes,
         project_feature_attributes: project_feature_attributes }
     ]
@@ -616,13 +621,16 @@ class ProjectsController < Projects::ApplicationController
   def redirect_git_extension
     return unless params[:format] == 'git'
 
+    git_extension_regex = %r{\.git/?\Z}
+    return unless request.path.match?(git_extension_regex)
+
     # `project` calls `find_routable!`, so this will trigger the usual not-found
     # behaviour when the user isn't authorized to see the project
     return if project.nil? || performed?
 
     uri = URI(request.original_url)
     # Strip the '.git' part from the path
-    uri.path = uri.path.sub(%r{\.git/?\Z}, '')
+    uri.path = uri.path.sub(git_extension_regex, '')
 
     redirect_to(uri.to_s)
   end
@@ -636,7 +644,7 @@ class ProjectsController < Projects::ApplicationController
   end
 
   def check_export_rate_limit!
-    prefixed_action = "project_#{params[:action]}".to_sym
+    prefixed_action = :"project_#{params[:action]}"
 
     project_scope = params[:action] == 'download_export' ? @project : nil
 
@@ -646,6 +654,11 @@ class ProjectsController < Projects::ApplicationController
   def render_edit
     render 'edit'
   end
+
+  def enforce_step_up_auth_for_namespace_on_create
+    namespace_id = params.dig(:project, :namespace_id)
+    enforce_step_up_auth_for_namespace_id(namespace_id)
+  end
 end
 
 ProjectsController.prepend_mod_with('ProjectsController')
