@@ -286,7 +286,7 @@ class RegistrationsController < Devise::RegistrationsController
     @resource ||= Users::RegistrationsBuildService
                     .new(current_user, sign_up_params.merge({ skip_confirmation: skip_confirmation?,
                                                               preferred_language: preferred_language,
-                                                              organization_id: Current.organization.id }))
+                                                              organization_id: initial_organization.id }))
                     .execute
   end
 
@@ -381,6 +381,12 @@ class RegistrationsController < Devise::RegistrationsController
     redirect_to new_user_session_path,
       alert: _('Sign-ups are currently disabled. Please contact a GitLab administrator if you need an account.')
   end
+
+  def initial_organization
+    # rubocop:disable Gitlab/PreventOrganizationFirst -- Don't allow arbitrary organization assignment
+    ::Organizations::Organization.first
+    # rubocop:enable Gitlab/PreventOrganizationFirst
+  end
 end
 
 RegistrationsController.prepend_mod_with('RegistrationsController')
