@@ -8,12 +8,12 @@ class Snippets::NotesController < ApplicationController
   before_action :authorize_read_snippet!, only: [:show, :index]
   before_action :authorize_create_note!, only: [:create]
 
-  feature_category :snippets
+  feature_category :source_code_management
 
   private
 
   def note
-    @note ||= snippet.notes.inc_relations_for_view.find(params[:id])
+    @note ||= snippet.notes.inc_relations_for_view(snippet).find(params[:id])
   end
   alias_method :awardable, :note
 
@@ -29,13 +29,17 @@ class Snippets::NotesController < ApplicationController
   alias_method :noteable, :snippet
 
   def finder_params
-    params.merge(last_fetched_at: last_fetched_at, target_id: snippet.id, target_type: 'personal_snippet').tap do |merged_params|
+    params.merge(
+      last_fetched_at: last_fetched_at,
+      target_id: snippet.id,
+      target_type: 'personal_snippet'
+    ).tap do |merged_params|
       merged_params[:project] = project if respond_to?(:project)
     end
   end
 
   def authorize_read_snippet!
-    return render_404 unless can?(current_user, :read_snippet, snippet)
+    render_404 unless can?(current_user, :read_snippet, snippet)
   end
 
   def authorize_create_note!
