@@ -5,9 +5,6 @@
 # Used to find and filter all subgroups and projects of a passed parent group
 # visible to a specified user.
 #
-# When passing a `filter` param, the search is performed over all nested levels
-# of the `parent_group`. All ancestors for a search result are loaded
-#
 # Arguments:
 #   current_user: The user for which the children should be visible
 #   parent_group: The group to find children of
@@ -15,17 +12,20 @@
 #     Supports all params that the `ProjectsFinder` and `GroupProjectsFinder`
 #     support.
 #
-#     filter: string - is aliased to `search` for consistency with the frontend
-#     archived: string - `only` or `true`.
-#                        `non_archived` is passed to the `ProjectFinder`s if none
-#                        was given.
+#     active: boolean - filters for active descendants. When `false`, the search is performed over
+#                       all nested levels of the `parent group` and all inactive ancestors are loaded.
+#     filter: string - aliased to `search` for consistency with the frontend. When a filter is
+#                      passed, the search is performed over all nested levels of the `parent_group`.
+#                      All ancestors for a search result are loaded
 class GroupDescendantsFinder
+  include Gitlab::Utils::StrongMemoize
+
   attr_reader :current_user, :parent_group, :params
 
   def initialize(parent_group:, current_user: nil, params: {})
     @current_user = current_user
     @parent_group = parent_group
-    @params = params.reverse_merge(non_archived: params[:archived].blank?, not_aimed_for_deletion: true)
+    @params = params
   end
 
   def execute
@@ -36,7 +36,7 @@ class GroupDescendantsFinder
                                     .page(page)
 
     preloaded_ancestors = []
-    if params[:filter]
+    if search_descendants?
       preloaded_ancestors |= ancestors_of_filtered_subgroups
       preloaded_ancestors |= ancestors_of_filtered_projects
     end
@@ -53,37 +53,22 @@ class GroupDescendantsFinder
   def paginator
     @paginator ||= Gitlab::MultiCollectionPaginator.new(
       subgroups,
-      projects.with_route,
+      projects,
       per_page: params[:per_page]
     )
   end
 
   def direct_child_groups
-    GroupsFinder.new(current_user, parent: parent_group, all_available: true).execute # rubocop: disable CodeReuse/Finder
+    GroupsFinder # rubocop: disable CodeReuse/Finder
+      .new(current_user, parent: parent_group, all_available: true, active: params[:active])
+      .execute
   end
 
-  # rubocop: disable CodeReuse/ActiveRecord
-  def all_visible_descendant_groups
-    groups_table = Group.arel_table
-    visible_to_user = groups_table[:visibility_level]
-                      .in(Gitlab::VisibilityLevel.levels_for_user(current_user))
-
-    if current_user
-      authorized_groups = GroupsFinder.new(current_user, all_available: false) # rubocop: disable CodeReuse/Finder
-        .execute.arel.as('authorized')
-      authorized_to_user = groups_table.project(1).from(authorized_groups)
-        .where(authorized_groups[:id].eq(groups_table[:id]))
-        .exists
-      visible_to_user = visible_to_user.or(authorized_to_user)
-    end
-
-    parent_group.descendants.where(visible_to_user)
-  end
-  # rubocop: enable CodeReuse/ActiveRecord
-
-  def subgroups_matching_filter
-    all_visible_descendant_groups
-      .search(params[:filter])
+  def descendant_groups
+    descendants = parent_group.descendants
+    descendants = by_visible_to_users(descendants)
+    descendants = by_active(descendants)
+    by_search(descendants)
   end
 
   # When filtering we want all to preload all the ancestors upto the specified
@@ -97,7 +82,9 @@ class GroupDescendantsFinder
   # So when searching 'project', on the 'subgroup' page we want to preload
   # 'nested-group' but not 'subgroup' or 'root'
   def ancestors_of_groups(base_for_ancestors)
-    Group.id_in(base_for_ancestors).self_and_ancestors(upto: parent_group.id)
+    ancestors = Group.id_in(base_for_ancestors).self_and_ancestors(upto: parent_group.id)
+    ancestors = ancestors.self_or_ancestors_inactive if inactive?
+    ancestors
   end
 
   def ancestors_of_filtered_projects
@@ -105,24 +92,24 @@ class GroupDescendantsFinder
     groups_to_load_ancestors_of = paginated_projects_without_direct_descendents.pluck(:namespace_id)
     # rubocop:enable Database/AvoidUsingPluckWithoutLimit, CodeReuse/ActiveRecord
     ancestors_of_groups(groups_to_load_ancestors_of)
-      .with_selects_for_list(archived: params[:archived])
+      .with_selects_for_list(archived: params[:archived], active: params[:active])
   end
 
   def ancestors_of_filtered_subgroups
     ancestors_of_groups(paginated_subgroups_without_direct_descendents)
-      .with_selects_for_list(archived: params[:archived])
+      .with_selects_for_list(archived: params[:archived], active: params[:active])
   end
 
   def subgroups
     # When filtering subgroups, we want to find all matches within the tree of
     # descendants to show to the user
-    groups = if params[:filter]
-               subgroups_matching_filter
+    groups = if search_descendants?
+               descendant_groups
              else
                direct_child_groups
              end
 
-    groups.with_selects_for_list(archived: params[:archived]).order_by(sort)
+    groups.with_selects_for_list(archived: params[:archived], active: params[:active]).order_by(sort)
   end
 
   def direct_child_projects
@@ -133,25 +120,27 @@ class GroupDescendantsFinder
 
   # Finds all projects nested under `parent_group` or any of its descendant
   # groups
-  def projects_matching_filter
+  def descendant_projects
     projects_nested_in_group = Project.in_namespace(parent_group.self_and_descendants.as_ids)
-    params_with_search = params.merge(search: params[:filter])
+
+    finder_params = params.dup
+    finder_params[:search] = params[:filter] if params[:filter]
 
     ProjectsFinder.new( # rubocop:disable CodeReuse/Finder
-      params: params_with_search,
+      params: finder_params,
       current_user: current_user,
       project_ids_relation: projects_nested_in_group
     ).execute
   end
 
   def projects
-    projects = if params[:filter]
-                 projects_matching_filter
+    projects = if search_descendants?
+                 descendant_projects
                else
                  direct_child_projects
                end
 
-    projects.with_route.order_by(sort)
+    projects.with_group_child_entity_associations.order_by(sort)
   end
 
   def sort
@@ -177,4 +166,51 @@ class GroupDescendantsFinder
   def page
     params[:page].to_i
   end
+
+  # Filters group descendants to only include those visible to the current user.
+  #
+  # This method applies visibility filtering based on two criteria:
+  # 1. Groups with visibility level accessible to the current user
+  # 2. Groups where the user has explicit authorization (if authenticated)
+  #
+  # @param descendants [ActiveRecord::Relation<Group>] The collection of group descendants to filter
+  # @return [ActiveRecord::Relation<Group>] Filtered descendants visible to the current user
+  # rubocop: disable CodeReuse/ActiveRecord -- Needs specialized queries for optimization
+  def by_visible_to_users(descendants)
+    groups_table = Group.arel_table
+    visible_to_user = groups_table[:visibility_level]
+      .in(Gitlab::VisibilityLevel.levels_for_user(current_user))
+
+    if current_user
+      authorized_groups = GroupsFinder.new(current_user, all_available: false) # rubocop: disable CodeReuse/Finder
+        .execute.arel.as('authorized')
+      authorized_to_user = groups_table.project(1).from(authorized_groups)
+        .where(authorized_groups[:id].eq(groups_table[:id]))
+        .exists
+      visible_to_user = visible_to_user.or(authorized_to_user)
+    end
+
+    descendants.where(visible_to_user)
+  end
+  # rubocop: enable CodeReuse/ActiveRecord
+
+  def by_active(descendants)
+    return descendants if params[:active].nil?
+
+    params[:active] ? descendants.self_and_ancestors_active : descendants.self_or_ancestors_inactive
+  end
+
+  def by_search(descendants)
+    return descendants unless params[:filter]
+
+    descendants.search(params[:filter])
+  end
+
+  def inactive?
+    params[:active] == false
+  end
+
+  def search_descendants?
+    params[:filter].present? || inactive?
+  end
 end
