@@ -22,6 +22,9 @@
 #     include_ancestors: boolean (defaults to true)
 #     organization: Scope the groups to the Organizations::Organization
 #     active: boolean - filters for active groups.
+#     archived: boolean - default is nil which returns all groups, true returns only archived groups, and false returns
+#                         non archived groups
+#     with_statistics - load project statistics.
 #
 # Users with full private access can see all groups. The `owned` and `parent`
 # params can be used to restrict the groups that are returned.
@@ -43,6 +46,7 @@ class GroupsFinder < UnionFinder
     # filtered_groups can contain an array of scopes, so these
     # are combined into a single query using UNION.
     groups = find_union(filtered_groups, Group)
+    groups = groups.with_statistics if params[:with_statistics] == true
     sort(groups).with_route
   end
 
@@ -57,7 +61,7 @@ class GroupsFinder < UnionFinder
   def all_groups
     return [owned_groups] if params[:owned]
     return [groups_with_min_access_level] if min_access_level?
-    return [Group.all] if current_user&.can_read_all_resources? && all_available?
+    return [Group.all] if can_read_all_groups? && all_available?
 
     groups = [
       authorized_groups,
@@ -112,7 +116,8 @@ class GroupsFinder < UnionFinder
     groups = by_visibility(groups)
     groups = by_ids(groups)
     groups = top_level_only(groups)
-    groups = by_marked_for_deletion_on(groups)
+    groups = marked_for_deletion_on(groups)
+    groups = by_archived(groups)
     by_search(groups)
   end
 
@@ -145,10 +150,16 @@ class GroupsFinder < UnionFinder
     groups.by_parent(parent)
   end
 
-  def by_marked_for_deletion_on(groups)
+  def marked_for_deletion_on(groups)
     return groups unless params[:marked_for_deletion_on].present?
 
-    groups.by_marked_for_deletion_on(params[:marked_for_deletion_on])
+    groups.marked_for_deletion_on(params[:marked_for_deletion_on])
+  end
+
+  def by_archived(groups)
+    return groups if params[:archived].nil?
+
+    params[:archived] ? groups.self_or_ancestors_archived : groups.self_and_ancestors_non_archived
   end
 
   def filter_group_ids(groups)
@@ -166,7 +177,7 @@ class GroupsFinder < UnionFinder
   def by_active(groups)
     return groups if params[:active].nil?
 
-    params[:active] ? groups.active : groups.inactive
+    params[:active] ? groups.self_and_ancestors_active : groups.self_or_ancestors_inactive
   end
 
   def include_parent_shared_groups?
@@ -181,6 +192,15 @@ class GroupsFinder < UnionFinder
     current_user.nil? || all_available?
   end
 
+  def can_read_all_groups?
+    return false unless current_user
+
+    # Auditors can :read_all_resources while admins can :read_all_resources and
+    # read_admin_groups. In EE, a regular user can read_admin_groups through
+    # custom admin roles.
+    current_user.can_read_all_resources? || current_user.can?(:read_admin_groups)
+  end
+
   def all_available?
     params.fetch(:all_available, true)
   end
