@@ -19,7 +19,7 @@
 #     milestone_wildcard_id: 'none', 'any', 'upcoming', 'started' (cannot be simultaneously used with milestone_title)
 #     release_tag: string
 #     author_id: integer
-#     author_username: string
+#     author_username: username string or a group handle (e.g., '@group/subgroup')
 #     assignee_id: integer or 'None' or 'Any'
 #     closed_by_id: integer
 #     assignee_username: string
@@ -182,7 +182,7 @@ class IssuableFinder
 
     state_counts = finder
       .execute
-      .reorder(nil)
+      .without_order
       .group(:state_id)
       .count
 
@@ -282,6 +282,8 @@ class IssuableFinder
       items.where(author_id: current_user.id)
     when 'assigned_to_me'
       items.assigned_to(current_user)
+    when 'reviews_for_me'
+      items.review_requested_to(current_user)
     else
       items
     end
@@ -311,7 +313,7 @@ class IssuableFinder
   end
 
   def by_parent(items)
-    return items.none unless params.projects
+    return items.none unless accessible_projects
 
     if use_namespace_filtering?
       filter_by_namespace(items)
@@ -326,9 +328,9 @@ class IssuableFinder
       # When finding issues for multiple projects it's more efficient
       # to use a JOIN instead of running a sub-query
       # See https://gitlab.com/gitlab-org/gitlab/-/commit/8591cc02be6b12ed60f763a5e0147f2cbbca99e1
-      items.join_project_through_namespace.merge(params.projects.reorder(nil))
+      items.join_project_through_namespace.merge(accessible_projects.reorder(nil))
     else
-      items.in_namespaces(params.projects.map(&:project_namespace_id)).references_project
+      items.in_namespaces(accessible_projects.map(&:project_namespace_id)).references_project
     end
   end
 
@@ -337,13 +339,17 @@ class IssuableFinder
       # When finding issues for multiple projects it's more efficient
       # to use a JOIN instead of running a sub-query
       # See https://gitlab.com/gitlab-org/gitlab/-/commit/8591cc02be6b12ed60f763a5e0147f2cbbca99e1
-      items.merge(params.projects.reorder(nil)).join_project
+      items.merge(accessible_projects.reorder(nil)).join_project
     else
-      items.of_projects(params.projects).references_project
+      items.of_projects(accessible_projects).references_project
     end
   end
   # rubocop: enable CodeReuse/ActiveRecord
 
+  def accessible_projects
+    params.projects
+  end
+
   def use_namespace_filtering?
     ::Feature.enabled?(:use_namespace_id_for_issue_and_work_item_finders, current_user, type: :wip) &&
       [::Issue, ::WorkItem].include?(klass)
@@ -351,7 +357,7 @@ class IssuableFinder
 
   def use_join_strategy_for_project?
     strong_memoize(:use_join_strategy_for_project) do
-      params.projects.is_a?(ActiveRecord::Relation)
+      accessible_projects.is_a?(ActiveRecord::Relation)
     end
   end
 
@@ -381,11 +387,9 @@ class IssuableFinder
     items.pg_full_text_search(search, matched_columns: params[:in].to_s.split(','))
   end
 
-  # rubocop: disable CodeReuse/ActiveRecord
   def by_iids(items)
-    params[:iids].present? ? items.where(iid: params[:iids]) : items
+    params[:iids].present? ? items.iid_in(params[:iids]) : items
   end
-  # rubocop: enable CodeReuse/ActiveRecord
 
   # rubocop: disable CodeReuse/ActiveRecord
   def by_negated_iids(items)
@@ -410,6 +414,7 @@ class IssuableFinder
 
   def by_author(items)
     Issuables::AuthorFilter.new(
+      current_user: current_user,
       params: original_params
     ).filter(items)
   end
@@ -421,6 +426,7 @@ class IssuableFinder
   def assignee_filter
     strong_memoize(:assignee_filter) do
       Issuables::AssigneeFilter.new(
+        current_user: current_user,
         params: original_params
       )
     end
@@ -456,7 +462,7 @@ class IssuableFinder
     elsif params.filter_by_any_milestone?
       items.any_milestone
     elsif params.filter_by_upcoming_milestone?
-      upcoming_ids = Milestone.upcoming_ids(params.projects, params.related_groups,
+      upcoming_ids = Milestone.upcoming_ids(accessible_projects, params.related_groups,
         legacy_filtering_logic: use_legacy_milestone_filtering?)
       items.left_joins_milestones.where(milestone_id: upcoming_ids)
     elsif params.filter_by_started_milestone?
