@@ -30,14 +30,15 @@
 #     not_aimed_for_deletion: boolean
 #     full_paths: string[]
 #     organization: Scope the groups to the Organizations::Organization
-#     current_organization: Organizations::Organization - The current organization from the request
 #     language: int
 #     language_name: string
 #     active: boolean - Whether to include projects that are not archived.
+#     namespace_path: string - Full path of the project's namespace (group or user).
 class ProjectsFinder < UnionFinder
   include CustomAttributesFilter
   include UpdatedAtFilter
   include Projects::SearchFilter
+  include Gitlab::Utils::StrongMemoize
 
   attr_accessor :params
   attr_reader :current_user, :project_ids_relation
@@ -51,6 +52,8 @@ class ProjectsFinder < UnionFinder
   end
 
   def execute
+    return Project.none if params[:namespace_path].present? && namespace_id.nil?
+
     user = params.delete(:user)
     collection =
       if user
@@ -59,6 +62,8 @@ class ProjectsFinder < UnionFinder
         init_collection
       end
 
+    collection = by_organization(collection)
+
     use_cte = params.delete(:use_cte)
     collection = Project.wrap_with_cte(collection) if use_cte
     collection = filter_projects(collection)
@@ -78,6 +83,7 @@ class ProjectsFinder < UnionFinder
 
   # EE would override this to add more filters
   def filter_projects(collection)
+    collection = by_namespace_path(collection)
     collection = by_deleted_status(collection)
     collection = by_ids(collection)
     collection = by_full_paths(collection)
@@ -97,9 +103,9 @@ class ProjectsFinder < UnionFinder
     collection = by_language(collection)
     collection = by_feature_availability(collection)
     collection = by_updated_at(collection)
-    collection = by_organization(collection)
     collection = by_marked_for_deletion_on(collection)
     collection = by_aimed_for_deletion(collection)
+    collection = by_last_repository_check_failed(collection)
     by_repository_storage(collection)
   end
 
@@ -179,6 +185,10 @@ class ProjectsFinder < UnionFinder
     params[:full_paths].present? ? items.where_full_path_in(params[:full_paths], preload_routes: false) : items
   end
 
+  def by_namespace_path(items)
+    params[:namespace_path].present? ? items.in_namespace(namespace_id) : items
+  end
+
   def union(items)
     find_union(items, Project).with_route
   end
@@ -205,18 +215,16 @@ class ProjectsFinder < UnionFinder
     return items unless params[:topic].present?
 
     topics = params[:topic].instance_of?(String) ? params[:topic].split(',') : params[:topic]
-    topics.map(&:strip).uniq.reject(&:empty?).each do |topic|
-      items = items.with_topic_by_name_and_organization_id(topic, topic_organization_ids)
-    end
+    sanitized_topics = topics.map(&:strip).uniq.reject(&:empty?)
 
-    items
+    items.contains_all_topic_names(sanitized_topics)
   end
 
   def by_topic_id(items)
     return items unless params[:topic_id].present?
 
-    topic = Projects::Topic.find_by_id_and_organization_id(params[:topic_id], topic_organization_ids)
-    return Project.none unless topic
+    topic = Projects::Topic.find_by_id(params[:topic_id])
+    return items.none unless topic
 
     items.with_topic(topic)
   end
@@ -224,19 +232,19 @@ class ProjectsFinder < UnionFinder
   def by_marked_for_deletion_on(items)
     return items unless params[:marked_for_deletion_on].present?
 
-    items.by_marked_for_deletion_on(params[:marked_for_deletion_on])
+    items.marked_for_deletion_on(params[:marked_for_deletion_on])
   end
 
   def by_aimed_for_deletion(items)
     if ::Gitlab::Utils.to_boolean(params[:aimed_for_deletion])
-      items.aimed_for_deletion(Date.current)
+      items.self_or_ancestors_aimed_for_deletion
     else
       items
     end
   end
 
   def by_not_aimed_for_deletion(items)
-    params[:not_aimed_for_deletion].present? ? items.not_aimed_for_deletion : items
+    params[:not_aimed_for_deletion].present? ? items.self_and_ancestors_not_aimed_for_deletion : items
   end
 
   def by_last_activity_after(items)
@@ -270,24 +278,28 @@ class ProjectsFinder < UnionFinder
     items
   end
 
-  def sort(items)
-    return items.projects_order_id_desc unless params[:sort]
+  def should_sort_by_similarity?
+    params[:search].present? && (params[:sort].nil? || params[:sort].to_s == 'similarity')
+  end
 
-    return items.sorted_by_similarity_desc(params[:search]) if params[:sort] == 'similarity' && params[:search].present?
+  def sort(items)
+    return items.sorted_by_similarity_desc(params[:search]) if should_sort_by_similarity?
+
+    return items.projects_order_id_desc unless params[:sort]
 
     items.sort_by_attribute(params[:sort])
   end
 
   def by_archived(projects)
     if params[:non_archived]
-      projects.non_archived
-    elsif params.key?(:archived)
+      projects.self_and_ancestors_non_archived
+    elsif params.key?(:archived) && !params[:archived].nil?
       if params[:archived] == 'only'
-        projects.archived
+        projects.self_or_ancestors_archived
       elsif Gitlab::Utils.to_boolean(params[:archived])
         projects
       else
-        projects.non_archived
+        projects.self_and_ancestors_non_archived
       end
     else
       projects
@@ -310,15 +322,14 @@ class ProjectsFinder < UnionFinder
   def by_active(items)
     return items if params[:active].nil?
 
-    params[:active] ? active(items) : inactive(items)
+    params[:active] ? items.self_and_ancestors_active : items.self_or_ancestors_inactive
   end
 
-  def active(items)
-    items.non_archived.not_aimed_for_deletion
-  end
+  def by_last_repository_check_failed(items)
+    return items if params[:last_repository_check_failed].nil?
+    return items.last_repository_check_failed if params[:last_repository_check_failed]
 
-  def inactive(items)
-    items.archived.or(items.aimed_for_deletion(Date.current))
+    items.last_repository_check_not_failed
   end
 
   def finder_params
@@ -327,16 +338,10 @@ class ProjectsFinder < UnionFinder
     { min_access_level: params[:min_access_level] }
   end
 
-  # Returns the available organizations to filter topics
-  def topic_organization_ids
-    @topic_organization_ids ||= begin
-      organization_ids = []
-      organization_ids << current_user.organization_ids if current_user
-      organization_ids << params[:organization].id if params[:organization]
-      organization_ids << params[:current_organization].id if params[:current_organization]
-      organization_ids.flatten.uniq.compact
-    end
+  def namespace_id
+    Namespace.find_by_full_path(params[:namespace_path])&.id
   end
+  strong_memoize_attr :namespace_id
 end
 
 ProjectsFinder.prepend_mod_with('ProjectsFinder')
