@@ -7,9 +7,13 @@ module Mutations
 
       def resolve(args)
         alert = authorized_find!(project_path: args[:project_path], iid: args[:iid])
+        if Feature.enabled?(:hide_incident_management_features, alert.project)
+          raise_resource_not_available_error! 'This feature is not available.'
+        end
+
         result = create_alert_issue(alert, current_user)
 
-        track_usage_event(:incident_management_incident_created, current_user.id)
+        track_alert_events('incident_management_incident_created', alert)
         track_usage_event(:incident_management_alert_create_incident, current_user.id)
 
         prepare_response(alert, result)
