@@ -6,21 +6,17 @@ module Mutations
       class ArtifactsDestroy < Base
         graphql_name 'JobArtifactsDestroy'
 
-        authorize :destroy_artifacts
+        authorize :delete_job_artifact
 
         field :job,
-              Types::Ci::JobType,
-              null: true,
-              description: 'Job with artifacts to be deleted.'
+          Types::Ci::JobType,
+          null: true,
+          description: 'Job with artifacts to be deleted.'
 
         field :destroyed_artifacts_count,
-              GraphQL::Types::Int,
-              null: false,
-              description: 'Number of artifacts deleted.'
-
-        def find_object(id: )
-          GlobalID::Locator.locate(id)
-        end
+          GraphQL::Types::Int,
+          null: false,
+          description: 'Number of artifacts deleted.'
 
         def resolve(id:)
           job = authorized_find!(id: id)
