@@ -7,6 +7,10 @@ module Mutations
         graphql_name 'CreateNote'
         description "Creates a Note.\n#{QUICK_ACTION_ONLY_WARNING}"
 
+        def self.authorization_scopes
+          super + [:ai_workflows]
+        end
+
         argument :discussion_id,
           ::Types::GlobalIDType[::Discussion],
           required: false,
@@ -24,11 +28,10 @@ module Mutations
           discussion_id = nil
 
           if gid = args[:discussion_id]
-            discussion = GitlabSchema.find_by_gid(gid)
+            discussion_id = ::GitlabSchema.parse_gid(gid, expected_type: ::Discussion).model_id
+            discussion = noteable.notes.find_discussion(discussion_id)
 
             authorize_discussion!(discussion)
-
-            discussion_id = discussion.id
           end
 
           super.merge({
