@@ -6,14 +6,14 @@ module Resolvers
       type Types::Ci::RunnerType.connection_type, null: true
 
       argument :membership, ::Types::Ci::RunnerMembershipFilterEnum,
-               required: false,
-               default_value: :descendants,
-               description: 'Control which runners to include in the results.'
+        required: false,
+        default_value: :descendants,
+        description: 'Control which runners to include in the results.'
 
       protected
 
       def runners_finder_params(params)
-        super(params).merge(membership: params[:membership])
+        super.merge(membership: params[:membership])
       end
 
       def parent_param
