@@ -7,23 +7,38 @@ module Resolvers
 
       type ::Types::Ci::JobType.connection_type, null: true
 
-      argument :security_report_types, [Types::Security::ReportTypeEnum],
-              required: false,
-              description: 'Filter jobs by the type of security report they produce.'
-
-      argument :statuses, [::Types::Ci::JobStatusEnum],
-              required: false,
-              description: 'Filter jobs by status.'
+      argument :job_kind, ::Types::Ci::JobKindEnum,
+        required: false,
+        description: 'Filter jobs by kind.'
 
       argument :retried, ::GraphQL::Types::Boolean,
-              required: false,
-              description: 'Filter jobs by retry-status.'
+        required: false,
+        description: 'Filter jobs by retry-status.'
 
-      def resolve(statuses: nil, security_report_types: [], retried: nil)
+      argument :security_report_types, [Types::Security::ReportTypeEnum],
+        required: false,
+        description: 'Filter jobs by the type of security report they produce.'
+
+      argument :statuses, [::Types::Ci::JobStatusEnum],
+        required: false,
+        description: 'Filter jobs by status.'
+
+      argument :when_executed, [::GraphQL::Types::String],
+        required: false,
+        description: 'Filter jobs by when they are executed.'
+
+      def resolve(
+        job_kind: nil,
+        retried: nil,
+        security_report_types: [],
+        statuses: nil,
+        when_executed: nil)
         jobs = init_collection(security_report_types)
-        jobs = jobs.with_status(statuses) if statuses.present?
-        jobs = jobs.retried if retried
         jobs = jobs.latest if retried == false
+        jobs = jobs.retried if retried
+        jobs = jobs.with_status(statuses) if statuses.present?
+        jobs = jobs.with_type(job_kind) if job_kind
+        jobs = jobs.with_when_executed(when_executed) if when_executed.present?
 
         jobs
       end
