@@ -3,7 +3,7 @@
 module Resolvers
   module Kas
     class AgentConfigurationsResolver < BaseResolver
-      type Types::Kas::AgentConfigurationType, null: true
+      type Types::Kas::AgentConfigurationType.connection_type, null: true
 
       # Calls Gitaly via KAS
       calls_gitaly!
@@ -15,13 +15,13 @@ module Resolvers
 
         kas_client.list_agent_config_files(project: project)
       rescue GRPC::BadStatus, Gitlab::Kas::Client::ConfigurationError => e
-        raise Gitlab::Graphql::Errors::ResourceNotAvailable, e.class.name
+        raise_resource_not_available_error! e.class.name
       end
 
       private
 
       def can_read_agent_configuration?
-        current_user.can?(:read_cluster, project)
+        current_user.can?(:read_cluster_agent, project)
       end
 
       def kas_client
