@@ -1,4 +1,5 @@
 # frozen_string_literal: true
+
 # rubocop: disable Graphql/ResolverType
 
 module Resolvers
@@ -11,9 +12,7 @@ module Resolvers
 
     # Return at most 500 pipelines for each MR.
     # Merge requests generally have many fewer pipelines than this.
-    def self.field_options
-      super.merge(max_page_size: 500)
-    end
+    max_page_size 500
 
     def resolve(**args)
       return unless project
