@@ -9,20 +9,14 @@ module Resolvers
     type Types::UserType, null: true
 
     argument :id, Types::GlobalIDType[User],
-             required: false,
-             description: 'ID of the User.'
+      required: false,
+      description: 'ID of the User.'
 
     argument :username, GraphQL::Types::String,
-             required: false,
-             description: 'Username of the User.'
+      required: false,
+      description: 'Username of the User.'
 
-    def ready?(id: nil, username: nil)
-      unless id.present? ^ username.present?
-        raise Gitlab::Graphql::Errors::ArgumentError, 'Provide either a single username or id'
-      end
-
-      super
-    end
+    validates exactly_one_of: [:id, :username]
 
     def resolve(id: nil, username: nil)
       authorize!
@@ -39,7 +33,7 @@ module Resolvers
     def batch_load(username)
       BatchLoader::GraphQL.for(username).batch do |usernames, loader|
         User.by_username(usernames).each do |user|
-          loader.call(user.username, user)
+          loader.call(username, user)
         end
       end
     end
