@@ -2,6 +2,8 @@
 
 module Types
   class BaseObject < GraphQL::Schema::Object
+    include Gitlab::Graphql::VersionFilter::FutureFieldFallback
+
     prepend Gitlab::Graphql::Present
     prepend Gitlab::Graphql::ExposePermissions
     prepend Gitlab::Graphql::MarkdownField
@@ -27,12 +29,19 @@ module Types
       GitlabSchema.id_from_object(object)
     end
 
+    def self.authorization_scopes
+      [:api, :read_api]
+    end
+
     def self.authorization
-      @authorization ||= ::Gitlab::Graphql::Authorize::ObjectAuthorization.new(authorize)
+      @authorization ||= ::Gitlab::Graphql::Authorize::ObjectAuthorization.new(authorize, authorization_scopes)
     end
 
     def self.authorized?(object, context)
-      authorization.ok?(object, context[:current_user])
+      authorization.ok?(object, context[:current_user],
+        scope_validator: context[:scope_validator],
+        skip_abilities: context[:skip_type_authorization]
+      )
     end
 
     def current_user
