@@ -20,6 +20,10 @@ module Types
           field :inputs, [Types::Ci::Inputs::SpecType], null: true,
             description: 'Inputs for the component.'
 
+          field :last_30_day_usage_count, GraphQL::Types::Int, null: true,
+            description: 'Number of times the component has been used in the last 30 days ' \
+              'in a pipeline using `include`.'
+
           def inputs
             object.spec.fetch('inputs', {}).map do |key, value|
               {
