@@ -16,11 +16,18 @@ module Types
 
       alias_method :runner, :object
 
+      # NOTE: instance runners are exposed by default to any authenticated user,
+      # remember to protect any sensitive fields
       field :access_level, ::Types::Ci::RunnerAccessLevelEnum, null: false,
         description: 'Access level of the runner.'
       field :active, GraphQL::Types::Boolean, null: false,
-        description: 'Indicates the runner is allowed to receive jobs.',
-        deprecated: { reason: 'Use paused', milestone: '14.8' }
+        description: "Indicates the runner is allowed to receive jobs.",
+        deprecated: {
+          reason: 'Use `paused`. ' \
+            "This field is the inverse of `paused` and has no relationship to the runner's job execution status. " \
+            "For more details, see `jobExecutionStatus`",
+          milestone: '14.8'
+        }
       field :admin_url, GraphQL::Types::String, null: true,
         description: 'Admin URL of the runner. Only available for administrators.'
       field :contacted_at, Types::TimeType, null: true,
@@ -36,8 +43,7 @@ module Types
         experiment: { milestone: '17.0' }
       field :creation_state, Types::Ci::RunnerCreationStateEnum, null: true,
         description: 'Runner creation state. Used to determine if a runner has been registered ' \
-          'and has contacted the GitLab instance.',
-        experiment: { milestone: '17.11' }
+          'and has contacted the GitLab instance.'
       field :description, GraphQL::Types::String, null: true,
         description: 'Description of the runner.'
       field :edit_admin_url, GraphQL::Types::String, null: true,
@@ -69,7 +75,8 @@ module Types
       field :locked, GraphQL::Types::Boolean, null: true,
         description: 'Indicates the runner is locked.'
       field :maintenance_note, GraphQL::Types::String, null: true,
-        description: 'Runner\'s maintenance notes.'
+        authorize: :update_runner,
+        description: "Runner's maintenance notes."
       field :managers, ::Types::Ci::RunnerManagerType.connection_type, null: true,
         description: 'Runner managers associated with the runner configuration.',
         resolver: Resolvers::Ci::RunnerManagersResolver
@@ -81,7 +88,7 @@ module Types
       field :paused, GraphQL::Types::Boolean, null: false,
         description: 'Indicates the runner is paused and not available to run jobs.'
       field :project_count, GraphQL::Types::Int, null: true,
-        description: 'Number of projects that the runner is associated with.'
+        description: 'Number of projects that the runner is associated with. The count includes projects that might not be visible to the current user.'
       field :projects,
         ::Types::ProjectType.connection_type,
         null: true,
@@ -102,9 +109,10 @@ module Types
       field :tag_list, [GraphQL::Types::String], null: true,
         description: 'Tags associated with the runner.'
       field :token_expires_at, Types::TimeType, null: true,
-        description: 'Runner token expiration time.'
+        description: 'Runner token expiration time.',
+        authorize: :read_runner_sensitive_data
 
-      markdown_field :maintenance_note_html, null: true
+      markdown_field :maintenance_note_html, null: true, authorize: :update_runner
 
       def maintenance_note_html_resolver
         ::MarkupHelper.markdown(object.maintenance_note, context.to_h.dup)
