@@ -8,16 +8,17 @@ module Types
     field_class Types::BaseField
 
     field :current_user_todos, Types::TodoType.connection_type,
-          description: 'To-do items for the current user.',
-          null: false do
-            argument :state, Types::TodoStateEnum,
-                     description: 'State of the to-do items.',
-                     required: false
-          end
+      description: 'To-do items for the current user.',
+      null: false do
+      argument :state, Types::TodoStateEnum,
+        description: 'State of the to-do items.',
+        required: false
+    end
 
     def current_user_todos(state: nil)
       state ||= %i[done pending] # TodosFinder treats a `nil` state param as `pending`
-      key = [state, unpresented.class.name]
+      target_type_name = unpresented.try(:todoable_target_type_name) || unpresented.class.name
+      key = [state, target_type_name]
 
       BatchLoader::GraphQL.for(unpresented).batch(default_value: [], key: key) do |targets, loader, args|
         state, klass_name = args[:key]
@@ -25,7 +26,7 @@ module Types
         targets_by_id = targets.index_by(&:id)
         ids = targets_by_id.keys
 
-        results = TodosFinder.new(current_user, state: state, type: klass_name, target_id: ids).execute
+        results = TodosFinder.new(users: current_user, state: state, type: klass_name, target_id: ids).execute
 
         by_target_id = results.group_by(&:target_id)
 
