@@ -5,7 +5,7 @@ module Types
     graphql_name 'IssueType'
     description 'Issue type'
 
-    ::WorkItems::Type.allowed_types_for_issues.each do |issue_type|
+    ::WorkItems::TypesFilter.allowed_types_for_issues.each do |issue_type|
       value issue_type.upcase, value: issue_type, description: "#{issue_type.titleize} issue type"
     end
 
