@@ -16,6 +16,7 @@ module Admin
       unlock_actions
       delete_actions
       ban_actions
+      trust_actions
 
       @actions
     end
@@ -50,12 +51,11 @@ module Admin
     def delete_actions
       return unless can?(current_user, :destroy_user, @user) && !@user.blocked_pending_approval?
 
-      @actions << 'delete' if @user.can_be_removed?
+      @actions << 'delete' if @user.solo_owned_groups.none?
       @actions << 'delete_with_contributions'
     end
 
     def ban_actions
-      return unless ban_feature_available?
       return if @user.internal?
 
       if @user.banned?
@@ -63,9 +63,23 @@ module Admin
         return
       end
 
-      unless @user.blocked?
-        @actions << 'ban'
-      end
+      @actions << 'ban' unless @user.blocked?
+    end
+
+    def trust_actions
+      return if @user.internal? ||
+        @user.blocked_pending_approval? ||
+        @user.banned? ||
+        @user.blocked? ||
+        @user.deactivated?
+
+      @actions << if @user.trusted?
+                    'untrust'
+                  else
+                    'trust'
+                  end
     end
   end
 end
+
+::Admin::UserActionsHelper.prepend_mod
