@@ -386,6 +386,8 @@ module ApplicationSettingsHelper
       :max_github_response_json_value_count,
       :max_http_decompressed_size,
       :max_http_response_size_limit,
+      :max_http_response_json_depth,
+      :max_http_response_json_structural_chars,
       :max_import_size,
       :max_import_remote_file_size,
       :max_login_attempts,
@@ -598,6 +600,7 @@ module ApplicationSettingsHelper
       :project_api_limit,
       :project_invited_groups_api_limit,
       :projects_api_limit,
+      :project_members_api_limit,
       :create_organization_api_limit,
       :user_contributed_projects_api_limit,
       :user_projects_api_limit,
@@ -636,9 +639,11 @@ module ApplicationSettingsHelper
       :minimum_language_server_version,
       :vscode_extension_marketplace,
       :vscode_extension_marketplace_enabled,
+      :vscode_extension_marketplace_extension_host_domain,
       :reindexing_minimum_index_size,
       :reindexing_minimum_relative_bloat_size,
       :anonymous_searches_allowed,
+      :default_search_scope,
       :git_push_pipeline_limit,
       :delay_user_account_self_deletion,
       :resource_usage_limits,
