@@ -6,7 +6,7 @@ module AutoDevopsHelper
       show_callout?('auto_devops_settings_dismissed') &&
       can?(current_user, :admin_pipeline, project) &&
       project.has_auto_devops_implicitly_disabled? &&
-      !project.repository.gitlab_ci_yml &&
+      !project.has_ci_config_file? &&
       !project.ci_integration
   end
 
