@@ -17,8 +17,11 @@ module FeatureFlagsHelper
       project_id: @project.id,
       feature_flags_path: project_feature_flags_path(@project),
       environments_endpoint: search_project_environments_path(@project, format: :json),
-      strategy_type_docs_page_path: help_page_path('operations/feature_flags', anchor: 'feature-flag-strategies'),
-      environments_scope_docs_path: help_page_path('ci/environments/index.md', anchor: 'scope-environments-with-specs')
+      strategy_type_docs_page_path: help_page_path('operations/feature_flags.md', anchor: 'feature-flag-strategies'),
+      environments_scope_docs_path: help_page_path(
+        'ci/environments/_index.md',
+        anchor: 'limit-the-environment-scope-of-a-cicd-variable'
+      )
     }
   end
 end
