@@ -129,7 +129,7 @@ module IssuablesHelper
 
     count = issuables_count_for_state(issuable_type, state)
     if count != -1
-      html << " " << gl_badge_tag(format_count(issuable_type, count, Gitlab::IssuablesCountForState::THRESHOLD), { variant: :neutral }, { class: "gl-tab-counter-badge gl-hidden sm:gl-inline-flex" })
+      html << " " << gl_badge_tag(format_count(issuable_type, count, Gitlab::IssuablesCountForState::THRESHOLD), { variant: :neutral }, { class: "gl-tab-counter-badge gl-hidden @sm/panel:gl-inline-flex" })
     end
 
     html.html_safe
