@@ -217,13 +217,19 @@ module SearchHelper
         hash[:group] = { id: search_group.id, name: search_group.name, full_name: search_group.full_name }
         hash[:group_metadata] = {
           issues_path: issues_group_path(search_group),
-          mr_path: merge_requests_group_path(search_group)
+          mr_path: merge_requests_group_path(search_group, assignee_username: current_user&.username)
         }
       end
 
       if search_has_project?
         hash[:project] = { id: @project.id, name: @project.name }
-        hash[:project_metadata] = { mr_path: project_merge_requests_path(@project) }
+        hash[:project_metadata] = {}
+
+        if @project.feature_available?(:merge_requests, current_user)
+          mr_path = project_merge_requests_path(@project, assignee_username: current_user&.username)
+          hash[:project_metadata][:mr_path] = mr_path
+        end
+
         if @project.feature_available?(:issues, current_user)
           hash[:project_metadata][:issues_path] =
             project_issues_path(@project)
@@ -239,6 +245,8 @@ module SearchHelper
   end
 
   def search_scope
+    return if ::Gitlab::CurrentSettings.custom_default_search_scope_set?
+
     if current_controller?(:issues)
       'issues'
     elsif current_controller?(:merge_requests)
@@ -407,7 +415,7 @@ module SearchHelper
       term,
       include_namespace: true,
       use_minimum_char_limit: false
-    ).sorted_by_stars_desc.non_archived.limit(limit)
+    ).sorted_by_stars_desc.self_and_ancestors_non_archived.limit(limit)
 
     projects.map do |p|
       {
