@@ -255,17 +255,6 @@ module TimeboxesHelper
     group_milestone_path(milestone.group, milestone.iid, milestone: params)
   end
 
-  def group_or_project_milestone_path(milestone)
-    params =
-      if milestone.group_milestone?
-        { milestone: { title: milestone.title } }
-      else
-        { title: milestone.title }
-      end
-
-    milestone_path(milestone.milestone, params)
-  end
-
   def edit_milestone_path(milestone)
     if milestone.group_milestone?
       edit_group_milestone_path(milestone.group, milestone)
@@ -274,12 +263,6 @@ module TimeboxesHelper
     end
   end
 
-  def can_admin_project_milestones?
-    strong_memoize(:can_admin_project_milestones) do
-      can?(current_user, :admin_milestone, @project)
-    end
-  end
-
   def can_admin_group_milestones?
     strong_memoize(:can_admin_group_milestones) do
       can?(current_user, :admin_milestone, @project.group)
@@ -295,13 +278,8 @@ module TimeboxesHelper
     limit = Milestone::DISPLAY_ISSUES_LIMIT
     link_options = { milestone_title: @milestone.title }
 
-    if Feature.enabled?(:work_items_alpha, current_user)
-      message = _('Showing %{limit} of %{total_count} items. ') % { limit: limit, total_count: total_count }
-      message += link_to(_('View all'), milestones_issues_path(link_options))
-    else
-      message = _('Showing %{limit} of %{total_count} issues. ') % { limit: limit, total_count: total_count }
-      message += link_to(_('View all issues'), milestones_issues_path(link_options))
-    end
+    message = _('Showing %{limit} of %{total_count} items. ') % { limit: limit, total_count: total_count }
+    message += link_to(_('View all'), milestones_issues_path(link_options))
 
     message.html_safe
   end
