@@ -135,12 +135,12 @@ module UsersHelper
     [].tap do |badges|
       badges << blocked_user_badge(user) if user.blocked?
       badges << { text: s_('AdminUsers|Admin'), variant: 'success' } if user.admin? # rubocop:disable Cop/UserAdmin
-      badges << { text: s_('AdminUsers|Bot'), variant: 'muted' } if user.bot?
+      badges << { text: s_('AdminUsers|Bot'), variant: 'neutral' } if user.bot?
       badges << { text: s_('AdminUsers|Deactivated'), variant: 'danger' } if user.deactivated?
-      badges << { text: s_('AdminUsers|External'), variant: 'secondary' } if user.external?
-      badges << { text: s_("AdminUsers|It's you!"), variant: 'muted' } if current_user == user
+      badges << { text: s_('AdminUsers|External'), variant: 'neutral' } if user.external?
+      badges << { text: s_("AdminUsers|It's you!"), variant: 'neutral' } if current_user == user
       badges << { text: s_("AdminUsers|Locked"), variant: 'warning' } if user.access_locked?
-      badges << { text: s_("UserMapping|Placeholder"), variant: 'muted' } if user.placeholder?
+      badges << { text: s_("UserMapping|Placeholder"), variant: 'neutral' } if user.placeholder?
       badges << { text: s_('AdminUsers|LDAP'), variant: 'info' } if user.ldap_user?
     end
   end
@@ -148,7 +148,7 @@ module UsersHelper
   def work_information(user, with_schema_markup: false)
     return unless user
 
-    organization = user.organization
+    organization = user.user_detail_organization
     job_title = user.job_title
 
     if organization.present? && job_title.present?
@@ -212,7 +212,7 @@ module UsersHelper
   end
 
   def has_contact_info?(user)
-    contact_fields = %i[bluesky discord linkedin mastodon skype twitter website_url]
+    contact_fields = %i[bluesky discord linkedin mastodon orcid twitter website_url github]
     has_contact = contact_fields.any? { |field| user.public_send(field).present? }  # rubocop:disable GitlabSecurity/PublicSend -- fields are controlled, it is safe.
     has_contact || display_public_email?(user)
   end
