@@ -17,15 +17,14 @@ module WikiHelper
     add_to_breadcrumbs(_('Wiki'), wiki_path(page.wiki))
   end
 
-  def link_to_wiki_page(page, **options)
-    link_to page.human_title, wiki_page_path(page.wiki, page), **options
-  end
-
   def wiki_sidebar_toggle_button
     render Pajamas::ButtonComponent.new(
-      icon: 'chevron-double-lg-left',
-      button_options: { class: 'sidebar-toggle js-sidebar-wiki-toggle' }
-    )
+      category: :tertiary,
+      icon: 'list-bulleted',
+      button_options: {
+        class: 'wiki-sidebar-header-toggle js-sidebar-wiki-toggle-open gl-mr-2',
+        "aria-label": _('Toggle sidebar')
+      })
   end
 
   # Produces a pure text breadcrumb for a given page.
