@@ -204,13 +204,6 @@ class NotifyPreview < ActionMailer::Preview
     Notify.member_access_granted_email(member.source_type, member.id).message
   end
 
-  def member_about_to_expire_email
-    cleanup do
-      member = project.add_member(user, Gitlab::Access::GUEST, expires_at: 7.days.from_now.to_date)
-      Notify.member_about_to_expire_email('project', member.id).message
-    end
-  end
-
   def pages_domain_enabled_email
     cleanup do
       Notify.pages_domain_enabled_email(pages_domain, user).message
@@ -289,24 +282,32 @@ class NotifyPreview < ActionMailer::Preview
     Notify.two_factor_otp_attempt_failed_email(user, '127.0.0.1').message
   end
 
+  def enabled_two_factor_passkey_email
+    Notify.enabled_two_factor_webauthn_email(user, 'MacBook Touch ID', :passkey).message
+  end
+
   def enabled_two_factor_otp_email
     Notify.enabled_two_factor_otp_email(user).message
   end
 
   def enabled_two_factor_webauthn_email
-    Notify.enabled_two_factor_webauthn_email(user, 'Macbook Touch ID').message
+    Notify.enabled_two_factor_webauthn_email(user, 'MacBook Touch ID').message
   end
 
   def disabled_two_factor_email
     Notify.disabled_two_factor_email(user).message
   end
 
+  def disabled_two_factor_passkey_email
+    Notify.disabled_two_factor_webauthn_email(user, 'MacBook Touch ID', :passkey).message
+  end
+
   def disabled_two_factor_otp_email
     Notify.disabled_two_factor_otp_email(user).message
   end
 
   def disabled_two_factor_webauthn_email
-    Notify.disabled_two_factor_webauthn_email(user, 'Macbook Touch ID').message
+    Notify.disabled_two_factor_webauthn_email(user, 'MacBook Touch ID').message
   end
 
   def new_email_address_added_email
