@@ -24,22 +24,19 @@ class AbuseReport < ApplicationRecord
 
   belongs_to :reporter, class_name: 'User', inverse_of: :reported_abuse_reports
   belongs_to :user, inverse_of: :abuse_reports
-  belongs_to :organization, class_name: 'Organizations::Organization'
+  belongs_to :organization, class_name: 'Organizations::Organization', optional: false
   belongs_to :resolved_by, class_name: 'User', inverse_of: :resolved_abuse_reports
 
   has_many :events, class_name: 'ResourceEvents::AbuseReportEvent', inverse_of: :abuse_report
-  has_many :label_links, inverse_of: :abuse_report, class_name: 'AntiAbuse::Reports::LabelLink'
-  has_many :labels, through: :label_links, source: :abuse_report_label,
-    class_name: 'AntiAbuse::Reports::Label'
+  has_many :admin_abuse_report_assignees, class_name: "Admin::AbuseReportAssignee"
+  has_many :assignees, class_name: "User", through: :admin_abuse_report_assignees
 
   has_many :abuse_events, class_name: 'AntiAbuse::Event', inverse_of: :abuse_report
 
-  has_many :notes, class_name: 'AntiAbuse::Reports::Note'
   has_many :user_mentions, class_name: 'AntiAbuse::Reports::UserMention'
 
   validates :reporter, presence: true
   validates :user, presence: true, on: :create
-  validates :organization_id, presence: true, on: :create
   validates :message, presence: true
   validates :category, presence: true
   validates :user_id,
@@ -80,7 +77,6 @@ class AbuseReport < ApplicationRecord
   scope :by_reporter_id, ->(reporter_id) { where(reporter_id: reporter_id) }
   scope :by_category, ->(category) { where(category: category) }
   scope :with_users, -> { includes(:reporter, :user) }
-  scope :with_labels, -> { includes(:labels) }
 
   enum :category, {
     spam: 1,
