@@ -12,6 +12,7 @@ class ApplicationRecord < ActiveRecord::Base
   include HasCheckConstraints
   include IgnorableColumns
   include PopulatesShardingKey
+  include EachBatch
 
   self.abstract_class = true
 
@@ -21,6 +22,15 @@ class ApplicationRecord < ActiveRecord::Base
 
   alias_method :reset, :reload
 
+  class << self
+    # It is strongly suggested use the `.ids` method instead.
+    #
+    #     User.ids # => returns all the user IDs
+    #     User.where(...).ids # => returns the IDs of records matching the where clause.
+    #
+    alias_method :pluck_primary_key, :ids
+  end
+
   def self.without_order
     reorder(nil)
   end
@@ -41,10 +51,6 @@ class ApplicationRecord < ActiveRecord::Base
     where.not(id: ids)
   end
 
-  def self.pluck_primary_key
-    where(nil).pluck(primary_key)
-  end
-
   def self.safe_ensure_unique(retries: 0)
     transaction(requires_new: true) do # rubocop:disable Performance/ActiveRecordSubtransactions
       yield
@@ -90,8 +96,18 @@ class ApplicationRecord < ActiveRecord::Base
     # When calling this method on an association, just calling `self.create` would call `ActiveRecord::Persistence.create`
     # and that skips some code that adds the newly created record to the association.
     transaction(requires_new: true) { all.create(*args, &block) } # rubocop:disable Performance/ActiveRecordSubtransactions
-  rescue ActiveRecord::RecordNotUnique
-    find_by(*args)
+  rescue ActiveRecord::RecordNotUnique => e
+    find_by(*args).tap do |result|
+      # It's unusual if the find_by was not able to find the record that the
+      # database claimed already existed. There could be some underlying issue,
+      # such as a database trigger that inserts a record into another table.
+      # Log this error so that the full database error can be investigated.
+      Gitlab::ErrorTracking.track_exception(e, args: args) unless result
+    end
+  end
+
+  def self.current_transaction
+    connection.current_transaction
   end
 
   def create_or_load_association(association_name)
@@ -139,11 +155,25 @@ class ApplicationRecord < ActiveRecord::Base
       !not_null_check?(column_name)
   end
 
+  def self.delete_all_returning(*columns)
+    relation = current_scope || all
+
+    Gitlab::Database::DeleteRelationWithReturning.execute(relation, columns.flatten)
+  end
+
+  def self.sharding_keys
+    @sharding_keys ||= Gitlab::Database::Dictionary.entry(table_name).sharding_key || {}
+  end
+
   def readable_by?(user)
-    Ability.allowed?(user, "read_#{to_ability_name}".to_sym, self)
+    Ability.allowed?(user, :"read_#{to_ability_name}", self)
   end
 
   def to_ability_name
     model_name.element
   end
+
+  def deleted_from_database?
+    !self.class.exists?(id)
+  end
 end
