@@ -40,6 +40,7 @@ module ApplicationSettingImplementation
         after_sign_up_text: nil,
         akismet_enabled: false,
         akismet_api_key: nil,
+        allow_immediate_namespaces_deletion: true,
         allow_local_requests_from_system_hooks: true,
         allow_local_requests_from_web_hooks_and_services: false,
         allow_possible_spam: false,
@@ -110,7 +111,7 @@ module ApplicationSettingImplementation
         gitaly_timeout_fast: 10,
         gitaly_timeout_medium: 30,
         gitpod_enabled: false,
-        gitpod_url: 'https://gitpod.io/',
+        gitpod_url: 'https://app.ona.com/',
         gravatar_enabled: Settings.gravatar['enabled'],
         group_download_export_limit: 1,
         group_export_limit: 6,
@@ -146,6 +147,8 @@ module ApplicationSettingImplementation
         max_github_response_json_value_count: 250_000,
         max_http_decompressed_size: 100,
         max_http_response_size_limit: 100,
+        max_http_response_json_depth: 32,
+        max_http_response_json_structural_chars: 1_000_000,
         max_import_size: 0,
         max_import_remote_file_size: 10240,
         max_login_attempts: nil,
@@ -163,7 +166,7 @@ module ApplicationSettingImplementation
         password_authentication_enabled_for_git: true,
         password_authentication_enabled_for_web: Settings.gitlab['signin_enabled'],
         performance_bar_allowed_group_id: nil,
-        personal_access_token_prefix: 'glpat-',
+        personal_access_token_prefix: PersonalAccessToken::PERSONAL_TOKEN_PREFIX,
         instance_token_prefix: '',
         plantuml_enabled: false,
         plantuml_url: nil,
@@ -214,6 +217,7 @@ module ApplicationSettingImplementation
         spam_check_api_key: nil,
         suggest_pipeline_enabled: true,
         terminal_max_session_time: 0,
+        terraform_state_encryption_enabled: true,
         throttle_authenticated_api_enabled: false,
         throttle_authenticated_api_period_in_seconds: 3600,
         throttle_authenticated_api_requests_per_period: 7200,
@@ -318,10 +322,14 @@ module ApplicationSettingImplementation
         group_projects_api_limit: 600,
         group_shared_groups_api_limit: 60,
         groups_api_limit: 200,
+        project_members_api_limit: 60,
         create_organization_api_limit: 10,
         project_api_limit: 400,
         project_invited_groups_api_limit: 60,
         projects_api_limit: 2000,
+        runner_jobs_request_api_limit: 2000,
+        runner_jobs_patch_trace_api_limit: 200,
+        runner_jobs_endpoints_api_limit: 200,
         user_contributed_projects_api_limit: 100,
         user_projects_api_limit: 300,
         user_starred_projects_api_limit: 100,
@@ -346,6 +354,7 @@ module ApplicationSettingImplementation
         top_level_group_creation_enabled: true,
         ropc_without_client_credentials: true,
         vscode_extension_marketplace_enabled: false,
+        vscode_extension_marketplace_extension_host_domain: ::WebIde::ExtensionMarketplace::DEFAULT_EXTENSION_HOST_DOMAIN,
         reindexing_minimum_index_size: 1.gigabyte,
         reindexing_minimum_relative_bloat_size: 0.2,
         git_push_pipeline_limit: 4,
@@ -675,6 +684,13 @@ module ApplicationSettingImplementation
     Hash[storages_map]
   end
 
+  def allow_immediate_namespaces_deletion_for_user?(user)
+    # Keep the previous behavior when the feature flag is disabled
+    return true unless Feature.enabled?(:allow_immediate_namespaces_deletion, user)
+
+    allow_immediate_namespaces_deletion? || user&.can_admin_all_resources?
+  end
+
   private
 
   def set_max_key_restriction!(key_type)
