@@ -3,12 +3,14 @@
 class AuthenticationEvent < ApplicationRecord
   include UsageStatistics
 
+  RETENTION_PERIOD = 1.year
   TWO_FACTOR = 'two-factor'
   TWO_FACTOR_WEBAUTHN = 'two-factor-via-webauthn-device'
   STANDARD = 'standard'
   STATIC_PROVIDERS = [TWO_FACTOR, TWO_FACTOR_WEBAUTHN, STANDARD].freeze
 
   belongs_to :user, optional: true
+  belongs_to :organization, class_name: 'Organizations::Organization'
 
   validates :provider, :user_name, :result, presence: true
   validates :ip_address, ip_address: true
