@@ -1,18 +1,28 @@
 # frozen_string_literal: true
 
 class ChatName < ApplicationRecord
+  include Gitlab::EncryptedAttribute
+
   LAST_USED_AT_INTERVAL = 1.hour
+  MAX_PARAM_LENGTH = 8192
 
-  belongs_to :integration
   belongs_to :user
 
   validates :user, presence: true
-  validates :integration, presence: true
-  validates :team_id, presence: true
-  validates :chat_id, presence: true
+  validates :team_id, presence: true, length: { maximum: MAX_PARAM_LENGTH }
+  validates :team_domain, length: { maximum: MAX_PARAM_LENGTH }
+  validates :chat_id, presence: true, length: { maximum: MAX_PARAM_LENGTH }
+  validates :chat_name, length: { maximum: MAX_PARAM_LENGTH }
 
-  validates :user_id, uniqueness: { scope: [:integration_id] }
-  validates :chat_id, uniqueness: { scope: [:integration_id, :team_id] }
+  validates :chat_id, uniqueness: { scope: :team_id }
+  validates :token, length: { maximum: MAX_PARAM_LENGTH }
+
+  attr_encrypted :token,
+    mode: :per_attribute_iv,
+    algorithm: 'aes-256-gcm',
+    key: :db_key_base_32,
+    encode: false,
+    encode_iv: false
 
   # Updates the "last_used_timestamp" but only if it wasn't already updated
   # recently.
@@ -30,6 +40,6 @@ class ChatName < ApplicationRecord
   end
 
   def update_last_used_at?
-    last_used_at.nil? || last_used_at > LAST_USED_AT_INTERVAL.ago
+    last_used_at.nil? || last_used_at.before?(LAST_USED_AT_INTERVAL.ago)
   end
 end
