@@ -2,20 +2,25 @@
 
 module Ci
   class DailyBuildGroupReportResult < Ci::ApplicationRecord
+    include Ci::Partitionable
+
     PARAM_TYPES = %w[coverage].freeze
 
-    belongs_to :last_pipeline, class_name: 'Ci::Pipeline', foreign_key: :last_pipeline_id
+    belongs_to :last_pipeline, class_name: 'Ci::Pipeline', foreign_key: :last_pipeline_id,
+      inverse_of: :daily_build_group_report_results
     belongs_to :project
-    belongs_to :group
+    belongs_to :group, class_name: '::Group'
 
     validates :data, json_schema: { filename: "daily_build_group_report_result_data" }
 
-    scope :by_ref_path, -> (ref_path) { where(ref_path: ref_path) }
-    scope :by_projects, -> (ids) { where(project_id: ids) }
-    scope :by_group, -> (group_id) { where(group_id: group_id) }
+    partitionable scope: :last_pipeline
+
+    scope :by_ref_path, ->(ref_path) { where(ref_path: ref_path) }
+    scope :by_projects, ->(ids) { where(project_id: ids) }
+    scope :by_group, ->(group_id) { where(group_id: group_id) }
     scope :with_coverage, -> { where("(data->'coverage') IS NOT NULL") }
     scope :with_default_branch, -> { where(default_branch: true) }
-    scope :by_dates, -> (start_date, end_date) { where(date: start_date..end_date) }
+    scope :by_dates, ->(start_date, end_date) { where(date: start_date..end_date) }
     scope :ordered_by_date_and_group_name, -> { order(date: :desc, group_name: :asc) }
 
     store_accessor :data, :coverage
