@@ -3,11 +3,10 @@
 module Ci
   class PipelineScheduleVariable < Ci::ApplicationRecord
     include Ci::HasVariable
+    include Ci::RawVariable
 
     belongs_to :pipeline_schedule
 
-    alias_attribute :secret_value, :value
-
-    validates :key, uniqueness: { scope: :pipeline_schedule_id }
+    validates :key, presence: true, uniqueness: { scope: :pipeline_schedule_id }
   end
 end
