@@ -12,6 +12,10 @@ module Clusters
       RESERVED_NAMESPACES = %w[gitlab-managed-apps].freeze
       REQUIRED_K8S_MIN_VERSION = 23
 
+      MAX_TOKEN_LENGTH = 8192
+      MAX_CA_CERT_LENGTH = 65535
+      MAX_API_URL_LENGTH = 2048
+
       IGNORED_CONNECTION_EXCEPTIONS = [
         Gitlab::HTTP_V2::UrlBlocker::BlockedUrlError,
         Kubeclient::HttpError,
@@ -57,10 +61,10 @@ module Clusters
       # We expect to be `active?` only when enabled and cluster is created (the api_url is assigned)
       validates :api_url, public_url: true, presence: true
       validates :token, presence: true
-      validates :ca_cert, certificate: true, allow_blank: true, length: 1..65535, if: :ca_cert_changed?
+      validates :ca_cert, certificate: true, allow_blank: true, length: 1..MAX_CA_CERT_LENGTH, if: :ca_cert_changed?
 
-      validates :api_url, length: 1..2048, if: :api_url_changed?
-      validates :token, length: 1..8192, if: :token_changed?
+      validates :api_url, length: 1..MAX_API_URL_LENGTH, if: :api_url_changed?
+      validates :token, length: 1..MAX_TOKEN_LENGTH, if: :token_changed?
 
       validate :prevent_modification, on: :update
 
