@@ -4,21 +4,22 @@ module Clusters
   module Providers
     class Gcp < ApplicationRecord
       include Clusters::Concerns::ProviderStatus
+      include Gitlab::EncryptedAttribute
 
       self.table_name = 'cluster_providers_gcp'
 
       belongs_to :cluster, inverse_of: :provider_gcp, class_name: 'Clusters::Cluster'
 
-      default_value_for :zone, 'us-central1-a'
-      default_value_for :num_nodes, 3
-      default_value_for :machine_type, 'n1-standard-2'
-      default_value_for :cloud_run, false
+      attribute :zone, default: 'us-central1-a'
+      attribute :num_nodes, default: 3
+      attribute :machine_type, default: 'n1-standard-2'
+      attribute :cloud_run, default: false
 
       scope :cloud_run, -> { where(cloud_run: true) }
 
       attr_encrypted :access_token,
         mode: :per_attribute_iv,
-        key: Settings.attr_encrypted_db_key_base_truncated,
+        key: :db_key_base_truncated,
         algorithm: 'aes-256-cbc'
 
       validates :gcp_project_id,
@@ -37,12 +38,6 @@ module Clusters
           greater_than: 0
         }
 
-      def api_client
-        return unless access_token
-
-        @api_client ||= GoogleApi::CloudPlatform::Client.new(access_token, nil)
-      end
-
       def nullify_credentials
         assign_attributes(
           access_token: nil,
