@@ -118,4 +118,8 @@ class Compare
     end
     paths.to_a
   end
+
+  def first_diffs_slice(limit, diff_options = {})
+    diffs(diff_options.merge(max_files: limit)).diff_files
+  end
 end
