@@ -88,11 +88,9 @@ module Ci
       end
 
       def create_database_partition?(database_partition)
-        if Feature.enabled?(:ci_create_dynamic_partitions, :instance)
-          Ci::Partition.provisioning(database_partition.values.max).present?
-        else
-          database_partition.before?(Ci::Partition::LATEST_PARTITION_VALUE)
-        end
+        return true if database_partition.before?(Ci::Partition::LAST_STATIC_PARTITION_VALUE)
+
+        Ci::Partition.provisioning(database_partition.values.max).present?
       end
     end
   end
