@@ -24,7 +24,7 @@ module LoadedInGroupList
       with_route
         .with_namespace_details
         .with_counts(archived:, active:)
-        .preload(:deletion_schedule, :namespace_settings_with_ancestors_inherited_settings)
+        .preload(:deletion_schedule, :namespace_settings, :namespace_settings_with_ancestors_inherited_settings)
     end
 
     private
@@ -92,7 +92,7 @@ module LoadedInGroupList
   end
 
   def project_count
-    @project_count ||= try(:preloaded_project_count) || projects.non_archived.count
+    @project_count ||= try(:preloaded_project_count) || projects.count
   end
 
   def subgroup_count
