@@ -13,14 +13,15 @@ module Mentionable
         Commit.reference_pattern,
         MergeRequest.reference_pattern,
         Label.reference_pattern,
-        Milestone.reference_pattern
+        Milestone.reference_pattern,
+        WikiPage.reference_pattern
       ]
     end
 
     def self.default_pattern
       strong_memoize(:default_pattern) do
         issue_pattern = Issue.reference_pattern
-        link_patterns = Regexp.union([Issue, WorkItem, Commit, MergeRequest, Epic, Vulnerability].map(&:link_reference_pattern).compact)
+        link_patterns = Regexp.union([Issue, WorkItem, Commit, MergeRequest, Epic, Vulnerability, WikiPage].map(&:link_reference_pattern).compact)
         reference_pattern(link_patterns, issue_pattern)
       end
     end
