@@ -7,10 +7,7 @@ module RequireEmailVerification
   extend ActiveSupport::Concern
   include Gitlab::Utils::StrongMemoize
 
-  # This value is twice the amount we want it to be, because due to a bug in the devise-two-factor
-  # gem every failed login attempt increments the value of failed_attempts by 2 instead of 1.
-  # See: https://github.com/tinfoil/devise-two-factor/issues/127
-  MAXIMUM_ATTEMPTS = 3 * 2
+  MAXIMUM_ATTEMPTS = 3
   UNLOCK_IN = 24.hours
 
   included do
@@ -45,8 +42,10 @@ module RequireEmailVerification
   private
 
   def override_devise_lockable?
-    strong_memoize(:override_devise_lockable) do
-      Feature.enabled?(:require_email_verification, self) && !two_factor_enabled?
-    end
+    ::Gitlab::CurrentSettings.require_email_verification_on_account_locked &&
+      !two_factor_enabled? &&
+      identities.none? &&
+      Feature.disabled?(:skip_require_email_verification, self, type: :ops)
   end
+  strong_memoize_attr :override_devise_lockable?
 end
