@@ -12,7 +12,7 @@ module TaggableQueries
       taggings_join_model
         .scoped_taggables
         .joins(:tag)
-        .select('COALESCE(array_agg(tags.name ORDER BY name), ARRAY[]::text[])')
+        .select('COALESCE(array_agg(tags.name ORDER BY tags.name), ARRAY[]::text[])')
     end
   end
 
