@@ -2,12 +2,18 @@
 
 module VulnerabilityFindingSignatureHelpers
   extend ActiveSupport::Concern
+
   # If the location object describes a physical location within a file
   # (filename + line numbers), the 'location' algorithm_type should be used
   # If the location object describes arbitrary data, then the 'hash'
   # algorithm_type should be used.
-
-  ALGORITHM_TYPES = { hash: 1, location: 2, scope_offset: 3 }.with_indifferent_access.freeze
+  ALGORITHM_TYPES = {
+    hash: 1,
+    location: 2,
+    scope_offset: 3,
+    scope_offset_compressed: 4,
+    rule_value: 5
+  }.with_indifferent_access.freeze
 
   class_methods do
     def priority(algorithm_type)
