@@ -4,6 +4,7 @@ module Packages
   module Conan
     class RecipeRevision < ApplicationRecord
       include ShaAttribute
+      include PackageFileable
 
       sha_attribute :revision
 
@@ -12,7 +13,6 @@ module Packages
 
       has_many :conan_package_references, inverse_of: :recipe_revision,
         class_name: 'Packages::Conan::PackageReference'
-      has_many :file_metadata, inverse_of: :recipe_revision, class_name: 'Packages::Conan::FileMetadatum'
 
       validates :package, :project, presence: true
       validates :revision, presence: true, format: { with: ::Gitlab::Regex.conan_revision_regex_v2 }
