@@ -9,8 +9,14 @@ class PoolRepository < ApplicationRecord
 
   belongs_to :source_project, class_name: 'Project'
 
+  belongs_to :organization,
+    class_name: 'Organizations::Organization',
+    optional: true
+
   has_many :member_projects, class_name: 'Project'
 
+  before_validation :set_organization
+
   after_create :set_disk_path
 
   scope :by_source_project, ->(project) { where(source_project: project) }
@@ -96,11 +102,7 @@ class PoolRepository < ApplicationRecord
   def unlink_repository(repository, disconnect: true)
     repository.disconnect_alternates if disconnect
 
-    if member_projects.id_not_in(repository.project.id).exists?
-      true
-    else
-      mark_obsolete
-    end
+    member_projects.id_not_in(repository.project.id).exists? || mark_obsolete
   end
 
   def object_pool
@@ -119,6 +121,18 @@ class PoolRepository < ApplicationRecord
 
   private
 
+  # For now, we set the association  without validating.
+  # Until backfill migrations are complete, we must not validate this.
+  # Completing this will mean adding 2 validation aspects:
+  #   1. We should ensure pool repositories have a source project
+  #   2. We should ensure pool repositories have an organization
+  # Issue https://gitlab.com/gitlab-org/gitlab/-/issues/490484
+  def set_organization
+    return if organization
+
+    self.organization = source_project&.organization
+  end
+
   def pool_exists?
     object_pool.exists?
   end
