@@ -7,6 +7,9 @@ class ProjectSetting < ApplicationRecord
   include Projects::SquashOption
   include Gitlab::EncryptedAttribute
   include AfterCommitQueue
+  include SafelyChangeColumnDefault
+
+  columns_changing_default :auto_duo_code_review_enabled, :duo_remote_flows_enabled
 
   ALLOWED_TARGET_PLATFORMS = %w[ios osx tvos watchos android].freeze
 
@@ -18,6 +21,8 @@ class ProjectSetting < ApplicationRecord
   scope :for_projects, ->(projects) { where(project_id: projects) }
   scope :with_namespace, -> { joins(project: :namespace) }
 
+  cascading_attr :web_based_commit_signing_enabled
+
   attr_encrypted :cube_api_key,
     mode: :per_attribute_iv,
     key: :db_key_base_32,
@@ -39,6 +44,8 @@ class ProjectSetting < ApplicationRecord
   validates :issue_branch_template, length: { maximum: Issue::MAX_BRANCH_TEMPLATE }
   validates :target_platforms, inclusion: { in: ALLOWED_TARGET_PLATFORMS }
   validates :suggested_reviewers_enabled, inclusion: { in: [true, false] }
+  validates :merge_request_title_regex_description, length: { maximum:
+                                                              Project::MAX_MERGE_REQUEST_TITLE_REGEX_DESCRIPTION }
   validates :merge_request_title_regex, untrusted_regexp: true,
     length: { maximum: Project::MAX_MERGE_REQUEST_TITLE_REGEX }
 
@@ -47,6 +54,8 @@ class ProjectSetting < ApplicationRecord
     presence: { if: :require_unique_domain? }
 
   validate :validates_mr_default_target_self
+  validate :presence_of_merge_request_title_regex_settings,
+    if: -> { Feature.enabled?(:merge_request_title_regex, project) }
 
   validate :pages_unique_domain_availability, if: :pages_unique_domain_changed?
 
@@ -94,6 +103,14 @@ class ProjectSetting < ApplicationRecord
 
   private
 
+  def presence_of_merge_request_title_regex_settings
+    # Either both are present, or neither
+    if merge_request_title_regex.present? != merge_request_title_regex_description.present?
+      errors.add :merge_request_title_regex, _('and regex description must be either both set, or neither.')
+      errors.add :merge_request_title_regex_description, _('and regex must be either both set, or neither.')
+    end
+  end
+
   def validates_mr_default_target_self
     if mr_default_target_self_changed? && !project.forked?
       errors.add :mr_default_target_self, _('This setting is allowed for forked projects only')
