@@ -2,8 +2,12 @@
 
 class ProtectedTag < ApplicationRecord
   include ProtectedRef
+  include EachBatch
 
   validates :name, uniqueness: { scope: :project_id }
+  validates :project, presence: true
+
+  scope :preload_access_levels, -> { preload(:create_access_levels) }
 
   protected_ref_access_levels :create
 
