@@ -9,7 +9,7 @@ class Release < ApplicationRecord
   include FromUnion
   include UpdatedAtFilterable
 
-  cache_markdown_field :description
+  cache_markdown_field :description, issuable_reference_expansion_enabled: true
 
   belongs_to :project, touch: true
   belongs_to :author, class_name: 'User'
@@ -123,10 +123,6 @@ class Release < ApplicationRecord
     end
   end
 
-  def tag_missing?
-    actual_tag.nil?
-  end
-
   def assets_count(except: [])
     links_count = links.size
     sources_count = except.include?(:sources) ? 0 : sources.size
