@@ -3,6 +3,8 @@
 class ResourceEvent < ApplicationRecord
   include Gitlab::Utils::StrongMemoize
   include Importable
+  include IssueResourceEvent
+  include WorkItemResourceEvent
 
   self.abstract_class = true
 
@@ -18,6 +20,10 @@ class ResourceEvent < ApplicationRecord
     end
   end
 
+  def issuable
+    raise NoMethodError, "`#{self.class.name}#issuable` method must be implemented"
+  end
+
   private
 
   def discussion_id_key
