@@ -9,6 +9,8 @@ module TimeTracking
 
     belongs_to :namespace, foreign_key: 'namespace_id'
 
+    has_many :timelogs
+
     strip_attributes! :name
 
     validates :namespace, presence: true
@@ -18,14 +20,13 @@ module TimeTracking
     validates :description, length: { maximum: 1024 }
     validates :color, color: true, allow_blank: false, length: { maximum: 7 }
     validates :billing_rate,
-              if: :billable?,
-              presence: true,
-              numericality: { greater_than: 0 }
+      if: :billable?,
+      presence: true,
+      numericality: { greater_than: 0 }
 
     DEFAULT_COLOR = ::Gitlab::Color.of('#6699cc')
 
-    attribute :color, ::Gitlab::Database::Type::Color.new
-    default_value_for :color, DEFAULT_COLOR
+    attribute :color, ::Gitlab::Database::Type::Color.new, default: DEFAULT_COLOR
 
     def self.find_by_name(namespace_id, name)
       where(namespace: namespace_id)
