@@ -30,6 +30,7 @@ class Todo < ApplicationRecord
   DUO_ENTERPRISE_ACCESS_GRANTED = 17 # This is an EE-only feature
   DUO_CORE_ACCESS_GRANTED = 18 # This is an EE-only feature
 
+  # EE Action names should be defined in EE_ACTION_NAMES in ee/app/models/ee/todo.rb
   ACTION_NAMES = {
     ASSIGNED => :assigned,
     REVIEW_REQUESTED => :review_requested,
@@ -39,24 +40,16 @@ class Todo < ApplicationRecord
     APPROVAL_REQUIRED => :approval_required,
     UNMERGEABLE => :unmergeable,
     DIRECTLY_ADDRESSED => :directly_addressed,
-    MERGE_TRAIN_REMOVED => :merge_train_removed,
     MEMBER_ACCESS_REQUESTED => :member_access_requested,
     REVIEW_SUBMITTED => :review_submitted,
-    OKR_CHECKIN_REQUESTED => :okr_checkin_requested,
-    ADDED_APPROVER => :added_approver,
     SSH_KEY_EXPIRED => :ssh_key_expired,
-    SSH_KEY_EXPIRING_SOON => :ssh_key_expiring_soon,
-    DUO_PRO_ACCESS_GRANTED => :duo_pro_access_granted,
-    DUO_ENTERPRISE_ACCESS_GRANTED => :duo_enterprise_access_granted,
-    DUO_CORE_ACCESS_GRANTED => :duo_core_access_granted
+    SSH_KEY_EXPIRING_SOON => :ssh_key_expiring_soon
   }.freeze
 
   ACTIONS_MULTIPLE_ALLOWED = [Todo::MENTIONED, Todo::DIRECTLY_ADDRESSED, Todo::MEMBER_ACCESS_REQUESTED].freeze
 
+  # EE parentless action types should be defined in EE_PARENTLESS_ACTION_TYPES in ee/app/models/ee/todo.rb
   PARENTLESS_ACTION_TYPES = [
-    DUO_PRO_ACCESS_GRANTED,
-    DUO_ENTERPRISE_ACCESS_GRANTED,
-    DUO_CORE_ACCESS_GRANTED,
     SSH_KEY_EXPIRED,
     SSH_KEY_EXPIRING_SOON
   ].freeze
@@ -67,6 +60,7 @@ class Todo < ApplicationRecord
   belongs_to :note
   belongs_to :project
   belongs_to :group
+  belongs_to :organization, class_name: 'Organizations::Organization'
   belongs_to :target, -> {
     if self.klass.respond_to?(:with_api_entity_associations)
       self.with_api_entity_associations
@@ -76,16 +70,23 @@ class Todo < ApplicationRecord
   }, polymorphic: true # rubocop:disable Cop/PolymorphicAssociations
 
   belongs_to :user
-  belongs_to :issue, -> { where("target_type = 'Issue'") }, foreign_key: :target_id
+  belongs_to :issue, -> { joins(:todos).where(todos: { target_type: 'Issue' }) }, foreign_key: :target_id
 
   delegate :name, :email, to: :author, prefix: true, allow_nil: true
 
+  before_validation :set_sharding_key
+
   validates :action, :target_type, :user, presence: true
   validates :author, presence: true
   validates :target_id, presence: true, unless: :for_commit?
   validates :commit_id, presence: true, if: :for_commit?
-  validates :project, presence: true, unless: -> { group_id || parentless_type? }
-  validates :group, presence: true, unless: -> { project_id || parentless_type? }
+
+  validates :project, presence: { unless: -> { group_id || parentless_type? } }
+  validates :project, absence: { if: -> { group_id || parentless_type? } }
+  validates :group, presence: { unless: -> { project_id || parentless_type? } }
+  validates :group, absence: { if: -> { project_id || parentless_type? } }
+  validates :organization, presence: { if: :parentless_type? }
+  validates :organization, absence: { unless: :parentless_type? }
 
   scope :pending, -> { with_state(:pending) }
   scope :snoozed, -> { where(arel_table[:snoozed_until].gt(Time.current)) }
@@ -265,8 +266,17 @@ class Todo < ApplicationRecord
       select(arel_table[Arel.star], highest_priority).order(order)
     end
 
+    def action_names
+      ACTION_NAMES
+    end
+
+    def parentless_action_types
+      PARENTLESS_ACTION_TYPES
+    end
+
     def distinct_user_ids
-      distinct.pluck(:user_id)
+      # When used from the todos finder that applies a default order, we need to reset it.
+      reorder(nil).distinct.pluck(:user_id)
     end
 
     # Count pending todos grouped by user_id and state
@@ -329,7 +339,7 @@ class Todo < ApplicationRecord
   end
 
   def action_name
-    ACTION_NAMES[action]
+    self.class.action_names[action]
   end
 
   def body
@@ -362,12 +372,8 @@ class Todo < ApplicationRecord
     target_type == Key.name
   end
 
-  def for_duo_access_granted?
-    [DUO_PRO_ACCESS_GRANTED, DUO_ENTERPRISE_ACCESS_GRANTED, DUO_CORE_ACCESS_GRANTED].include?(action)
-  end
-
   def parentless_type?
-    PARENTLESS_ACTION_TYPES.include?(action)
+    self.class.parentless_action_types.include?(action)
   end
 
   # override to return commits, which are not active record
@@ -396,8 +402,6 @@ class Todo < ApplicationRecord
   def target_url
     return if target.nil?
 
-    return build_duo_getting_started_url if for_duo_access_granted?
-
     case target
     when WorkItem
       build_work_item_target_url
@@ -432,8 +436,33 @@ class Todo < ApplicationRecord
 
   private
 
-  def build_duo_getting_started_url
-    ::Gitlab::Routing.url_helpers.help_page_path('user/get_started/getting_started_gitlab_duo.md')
+  def set_sharding_key
+    # NOTE: Records can be instantiated or created by providing
+    #       all sharding key columns. We only allow for one of
+    #       the sharding key columns to be set. In order to allow
+    #       for a smooth transition and to avoid touching all existing
+    #       codepaths, we set the preferred sharding key column
+    #       in a before_validation.
+    preferred_key = if parentless_type?
+                      :organization
+                    elsif project_id.present?
+                      :project
+                    elsif group_id.present?
+                      :group
+                    end
+
+    case preferred_key
+    when :organization
+      self.organization = user.organization if user_id.present?
+      self.group = nil
+      self.project = nil
+    when :project
+      self.organization = nil
+      self.group = nil
+    when :group
+      self.organization = nil
+      self.project = nil
+    end
   end
 
   def build_work_item_target_url
