@@ -3,6 +3,9 @@
 class Upload < ApplicationRecord
   include Checksummable
   include EachBatch
+  include ObjectStorable
+
+  STORE_COLUMN = :store
 
   # Upper limit for foreground checksum processing
   CHECKSUM_THRESHOLD = 100.megabytes
@@ -15,8 +18,6 @@ class Upload < ApplicationRecord
   validates :model, presence: true
   validates :uploader, presence: true
 
-  scope :with_files_stored_locally, -> { where(store: ObjectStorage::Store::LOCAL) }
-  scope :with_files_stored_remotely, -> { where(store: ObjectStorage::Store::REMOTE) }
   scope :for_model_type_and_id, ->(type, id) { where(model_type: type, model_id: id) }
   scope :for_uploader, ->(uploader_class) { where(uploader: uploader_class.to_s) }
   scope :order_by_created_at_desc, -> { reorder(created_at: :desc) }
@@ -32,21 +33,6 @@ class Upload < ApplicationRecord
   after_commit :update_project_statistics, on: [:create, :destroy], if: :project?
 
   class << self
-    def inner_join_local_uploads_projects
-      upload_table = Upload.arel_table
-      project_table = Project.arel_table
-
-      join_statement = upload_table.project(upload_table[Arel.star])
-                         .join(project_table)
-                         .on(
-                           upload_table[:model_type].eq('Project')
-                             .and(upload_table[:model_id].eq(project_table[:id]))
-                             .and(upload_table[:store].eq(ObjectStorage::Store::LOCAL))
-                         )
-
-      joins(join_statement.join_sources)
-    end
-
     ##
     # FastDestroyAll concerns
     def begin_fast_destroy
