@@ -13,11 +13,6 @@ module WorkItems
     self.table_name = 'work_item_types'
 
     include CacheMarkdownField
-    include ReactiveCaching
-
-    self.reactive_cache_work_type = :no_dependency
-    self.reactive_cache_refresh_interval = 10.minutes
-    self.reactive_cache_lifetime = 1.hour
 
     # type name is used in restrictions DB seeder to assure restrictions for
     # default types are pre-filled
@@ -53,7 +48,7 @@ module WorkItems
     # where it's possible to switch between issue and incident.
     CHANGEABLE_BASE_TYPES = %w[issue incident test_case].freeze
 
-    EE_BASE_TYPES = %w[objective epic key_result requirement].freeze
+    EE_BASE_TYPES = %w[epic key_result objective requirement].freeze
 
     ignore_column :correct_id, remove_with: '18.1', remove_after: '2025-05-15'
 
@@ -64,22 +59,11 @@ module WorkItems
     has_many :widget_definitions, foreign_key: :work_item_type_id, inverse_of: :work_item_type
     has_many :enabled_widget_definitions, -> { where(disabled: false) }, foreign_key: :work_item_type_id,
       inverse_of: :work_item_type, class_name: 'WorkItems::WidgetDefinition'
-    has_many :child_restrictions, class_name: 'WorkItems::HierarchyRestriction', foreign_key: :parent_type_id,
-      inverse_of: :parent_type
-    has_many :parent_restrictions, class_name: 'WorkItems::HierarchyRestriction', foreign_key: :child_type_id,
-      inverse_of: :child_type
-    has_many :allowed_child_types_by_name, -> { order_by_name_asc },
-      through: :child_restrictions, class_name: 'WorkItems::Type',
-      foreign_key: :child_type_id, source: :child_type
-    has_many :allowed_parent_types_by_name, -> { order_by_name_asc },
-      through: :parent_restrictions, class_name: 'WorkItems::Type',
-      foreign_key: :parent_type_id, source: :parent_type
     has_many :user_preferences,
       class_name: 'WorkItems::UserPreference',
       inverse_of: :work_item_type
 
     before_validation :strip_whitespace
-    after_save :clear_reactive_cache!
 
     # TODO: review validation rules
     # https://gitlab.com/gitlab-org/gitlab/-/issues/336919
@@ -90,6 +74,7 @@ module WorkItems
 
     scope :order_by_name_asc, -> { order(arel_table[:name].lower.asc) }
     scope :by_type, ->(base_type) { where(base_type: base_type) }
+    scope :with_widget_definition_preload, -> { preload(:enabled_widget_definitions) }
 
     def self.default_by_type(type)
       found_type = find_by(base_type: type)
@@ -111,19 +96,6 @@ module WorkItems
       default_by_type(:issue)
     end
 
-    def self.allowed_types_for_issues
-      base_types.keys.excluding('objective', 'key_result', 'epic')
-    end
-
-    # method overridden in EE to perform the corresponding checks for the Epic type
-    def self.allowed_group_level_types(resource_parent)
-      if Feature.enabled?(:create_group_level_work_items, resource_parent, type: :wip)
-        base_types.keys.excluding('epic')
-      else
-        []
-      end
-    end
-
     # resource_parent is used in EE
     def widgets(_resource_parent)
       enabled_widget_definitions.filter(&:widget_class)
@@ -141,15 +113,19 @@ module WorkItems
       widget_classes(resource_parent).include?(::WorkItems::Widgets::TimeTracking)
     end
 
-    def default_issue?
-      name == WorkItems::Type::TYPE_NAMES[:issue]
+    def allowed_child_types_by_name
+      child_type_ids = WorkItems::SystemDefined::HierarchyRestriction
+        .where(parent_type_id: id)
+        .map(&:child_type_id)
+
+      WorkItems::Type.where(id: child_type_ids).order_by_name_asc
     end
 
-    def calculate_reactive_cache
-      {
-        allowed_child_types_by_name: allowed_child_types_by_name,
-        allowed_parent_types_by_name: allowed_parent_types_by_name
-      }
+    def allowed_parent_types_by_name
+      parent_type_ids = WorkItems::SystemDefined::HierarchyRestriction
+        .where(child_type_id: id)
+        .map(&:parent_type_id)
+      WorkItems::Type.where(id: parent_type_ids).order_by_name_asc
     end
 
     def supported_conversion_types(resource_parent, user)
@@ -157,20 +133,23 @@ module WorkItems
       WorkItems::Type.by_type(type_names).order_by_name_asc
     end
 
-    def allowed_child_types(cache: false, authorize: false, resource_parent: nil)
-      cached_data = cache ? with_reactive_cache { |query_data| query_data[:allowed_child_types_by_name] } : nil
+    def unavailable_widgets_on_conversion(target_type, resource_parent)
+      source_widgets = widgets(resource_parent)
+      target_widgets = target_type.widgets(resource_parent)
+      target_widget_types = target_widgets.map(&:widget_type).to_set
+      source_widgets.reject { |widget| target_widget_types.include?(widget.widget_type) }
+    end
 
-      types = cached_data || allowed_child_types_by_name
+    def allowed_child_types(authorize: false, resource_parent: nil)
+      types = allowed_child_types_by_name
 
       return types unless authorize
 
       authorized_types(types, resource_parent, :child)
     end
 
-    def allowed_parent_types(cache: false, authorize: false, resource_parent: nil)
-      cached_data = cache ? with_reactive_cache { |query_data| query_data[:allowed_parent_types_by_name] } : nil
-
-      types = cached_data || allowed_parent_types_by_name
+    def allowed_parent_types(authorize: false, resource_parent: nil)
+      types = allowed_parent_types_by_name
 
       return types unless authorize
 
@@ -179,15 +158,13 @@ module WorkItems
 
     def descendant_types
       descendant_types = []
-      next_level_child_types = allowed_child_types(cache: true)
+      next_level_child_types = allowed_child_types
 
       loop do
         descendant_types += next_level_child_types
 
         # We remove types that we've already seen to avoid circular dependencies
-        next_level_child_types = next_level_child_types.flat_map do |type|
-          type.allowed_child_types(cache: true)
-        end - descendant_types
+        next_level_child_types = next_level_child_types.flat_map(&:allowed_child_types) - descendant_types
 
         break if next_level_child_types.empty?
       end
