@@ -3,7 +3,7 @@
 class ContainerRepositoryPolicy < BasePolicy
   delegate { @subject.project }
 
-  condition(:protected_for_delete) { @subject.has_protected_tag_rules_for_delete?(@user) }
+  condition(:protected_for_delete) { @subject.protected_from_delete_by_tag_rules?(@user) }
 
   rule { protected_for_delete }.policy do
     prevent :destroy_container_image
