@@ -1,5 +1,5 @@
 # frozen_string_literal: true
 
 class GroupLabelPolicy < BasePolicy
-  delegate { @subject.parent_container }
+  delegate { @subject.preloaded_parent_container }
 end
