@@ -1,6 +1,8 @@
 # frozen_string_literal: true
 
 class MergeRequestPolicy < IssuablePolicy
+  condition(:can_approve) { can_approve? }
+
   rule { locked }.policy do
     prevent :reopen_merge_request
   end
@@ -12,17 +14,26 @@ class MergeRequestPolicy < IssuablePolicy
   rule { ~can?(:read_merge_request) }.policy do
     prevent :create_note
     prevent :accept_merge_request
+    prevent :mark_note_as_internal
   end
 
-  rule { can?(:update_merge_request) & is_project_member }.policy do
+  rule { can_approve }.policy do
     enable :approve_merge_request
   end
 
+  rule { can?(:approve_merge_request) & bot }.policy do
+    enable :reset_merge_request_approvals
+  end
+
   rule { ~anonymous & can?(:read_merge_request) }.policy do
     enable :create_todo
     enable :update_subscription
   end
 
+  rule { hidden & ~admin }.policy do
+    prevent :read_merge_request
+  end
+
   condition(:can_merge) { @subject.can_be_merged_by?(@user) }
 
   rule { can_merge }.policy do
@@ -32,6 +43,16 @@ class MergeRequestPolicy < IssuablePolicy
   rule { can?(:admin_merge_request) }.policy do
     enable :set_merge_request_metadata
   end
+
+  rule { planner_or_reporter_access }.policy do
+    enable :mark_note_as_internal
+  end
+
+  private
+
+  def can_approve?
+    can?(:update_merge_request) && is_project_member?
+  end
 end
 
 MergeRequestPolicy.prepend_mod_with('MergeRequestPolicy')
