@@ -16,6 +16,21 @@ module Namespaces
 
     rule { can?(:reporter_access) }.policy do
       enable :read_timelog_category
+      enable :reopen_issue
+    end
+
+    rule { can?(:planner_access) }.policy do
+      enable :reopen_issue
+    end
+
+    rule { can?(:guest_access) }.policy do
+      enable :read_work_item
+      enable :read_issue
+      enable :read_note
+      enable :read_namespace
+      enable :read_namespace_via_membership
     end
   end
 end
+
+Namespaces::GroupProjectNamespaceSharedPolicy.prepend_mod
