@@ -16,7 +16,7 @@ module AwardEmojis
     def execute
       from_awardable.award_emoji.find_each do |award|
         new_award = award.dup
-        new_award.awardable = to_awardable
+        new_award.assign_attributes(awardable: to_awardable, namespace_id: nil, organization_id: nil)
         # In some instances when an awardable has a custom emoji and is being moved to a namespace where this
         # emoji does not exist the save! will raise a validation exception.
         # see `AwardEmoji`: validates :name, presence: true, 'gitlab/emoji_name': true
