@@ -54,12 +54,8 @@ module BulkImports
         extra: { source_equals_destination: bulk_import.source_equals_destination? }
       )
 
-      if Feature.enabled?(:importer_user_mapping, current_user) &&
-          Feature.enabled?(:bulk_import_importer_user_mapping, current_user)
-        ::Import::BulkImports::EphemeralData.new(bulk_import.id).enable_importer_user_mapping
-
-        Import::BulkImports::SourceUsersAttributesWorker.perform_async(bulk_import.id)
-      end
+      ::Import::BulkImports::EphemeralData.new(bulk_import.id).enable_importer_user_mapping
+      ::Import::BulkImports::SourceUsersAttributesWorker.perform_async(bulk_import.id)
 
       BulkImportWorker.perform_async(bulk_import.id)
 
