@@ -12,8 +12,8 @@ module Ci
     def execute
       metrics.increment_queue_operation(:runner_queue_timeout)
 
-      return job_not_waiting_error unless build_waiting?
-      return job_not_finished_waiting_error unless can_drop_and_retry?
+      return job_not_waiting_error if build.nil? || build.runner_ack_wait_status == :not_waiting
+      return job_not_finished_waiting_error if build.runner_ack_wait_status != :wait_expired
 
       # build.drop! will cause build to be retried automatically, if the retry count is below the limit
       build.drop!(:runner_provisioning_timeout)
@@ -25,14 +25,6 @@ module Ci
 
     private
 
-    def build_waiting?
-      build&.pending? && build.runner_id.present?
-    end
-
-    def can_drop_and_retry?
-      build.pending? && !build.waiting_for_runner_ack?
-    end
-
     def job_not_waiting_error
       ServiceResponse.error(message: 'Job is not in waiting state', payload: { reason: :not_in_waiting_state })
     end
