@@ -6,7 +6,7 @@
 # @param exit_code [Int] the resulting exit code.
 module Ci
   class TrackFailedBuildService
-    SCHEMA_URL = 'iglu:com.gitlab/ci_build_failed/jsonschema/1-0-0'
+    SCHEMA_URL = 'iglu:com.gitlab/ci_build_failed/jsonschema/1-0-2'
 
     def initialize(build:, exit_code:, failure_reason:)
       @build = build
@@ -42,7 +42,8 @@ module Ci
         build_name: @build.name,
         build_artifact_types: @build.job_artifact_types,
         exit_code: @exit_code,
-        failure_reason: @failure_reason
+        failure_reason: @failure_reason,
+        project: @build.project_id
       }
     end
   end
