@@ -19,7 +19,7 @@ module Groups
             next if Feature.enabled?(:skip_group_share_unlink_auth_refresh, group.root_ancestor)
 
             AuthorizedProjectUpdate::EnqueueGroupMembersRefreshAuthorizedProjectsWorker.perform_async(group.id,
-              { 'priority' => priority_for_refresh, 'direct_members_only' => true })
+              { 'priority' => priority_for_refresh.to_s, 'direct_members_only' => true })
           end
         else
           Gitlab::AppLogger.info(
