@@ -42,8 +42,6 @@ module Import
       private
 
       def cancel_reassignment
-        import_source_user.reassign_to_user = nil
-        import_source_user.reassigned_by_user = nil
         import_source_user.cancel_reassignment
       end
     end
