@@ -2,7 +2,10 @@
 
 module Issues
   class UpdateService < Issues::BaseService
-    WORK_ITEM_DESCRIPTION_FIELDS = %w[description last_edited_by_id last_edited_at lock_version].freeze
+    WORK_ITEM_DESCRIPTION_FIELDS = %w[
+      description description_html cached_markdown_version last_edited_by_id last_edited_at lock_version
+    ].freeze
+
     # NOTE: For Issues::UpdateService, we default perform_spam_check to false, because spam_checking is not
     # necessary in many cases, and we don't want to require every caller to explicitly pass it
     # to disable spam checking.
@@ -133,7 +136,7 @@ module Issues
     def sync_to_work_item_description(issue)
       return true unless WORK_ITEM_DESCRIPTION_FIELDS.intersection(issue.previous_changes.keys).any?
 
-      WorkItems::Description.upsert({
+      result = WorkItems::Description.upsert({
         work_item_id: issue.id,
         namespace_id: issue.namespace_id,
         description: issue.description,
@@ -144,10 +147,10 @@ module Issues
         cached_markdown_version: issue.cached_markdown_version
       }, unique_by: [:work_item_id, :namespace_id])
 
+      # Logging when we fail to upsert the description. We don't want to rollback the transaction for now.
+      Gitlab::AppLogger.info(issue_id: issue.id, message: "Failed to upsert work_item_description") unless result.rows.any?
+
       true
-    rescue StandardError => e
-      Gitlab::ErrorTracking.track_exception(e, issue_id: issue.id, message: "Failed to upsert description: #{e.message}")
-      false
     end
 
     override :after_update
