@@ -9,8 +9,9 @@ module Projects
       def execute
         return {} unless project&.lfs_enabled?
 
-        lfs_changes = if Feature.enabled?(:mirroring_lfs_optimization,
-          project) && params[:updated_revisions] != ['--all']
+        lfs_changes = if Feature.enabled?(:mirroring_lfs_optimization, project) &&
+            params[:updated_revisions].present? &&
+            params[:updated_revisions] != ['--all']
                         Gitlab::Git::LfsChanges.new(project.repository,
                           params[:updated_revisions]).new_pointers(not_in: [])
                       else
