@@ -12,11 +12,15 @@ module ResourceEvents
     def execute
       create_event
 
-      resource.expire_note_etag_cache
+      track_event
+
+      resource.broadcast_notes_changed
     end
 
     private
 
+    def track_event; end
+
     def create_event
       raise NotImplementedError
     end
