@@ -4,12 +4,12 @@ module TwoFactor
   class BaseService
     include BaseServiceUtility
 
-    attr_reader :current_user, :params, :user
+    attr_reader :current_user, :user, :group
 
     def initialize(current_user, params = {})
       @current_user = current_user
-      @params = params
       @user = params.delete(:user)
+      @group = params.delete(:group)
     end
   end
 end
