@@ -4,16 +4,16 @@ module Webauthn
   class DestroyService < BaseService
     attr_reader :webauthn_registration, :user, :current_user
 
-    def initialize(current_user, user, webauthn_registrations_id)
+    def initialize(current_user, user, second_factor_webauthn_registrations_id)
       @current_user = current_user
       @user = user
-      @webauthn_registration = user.webauthn_registrations.find(webauthn_registrations_id)
+      @webauthn_registration = user.second_factor_webauthn_registrations.find(second_factor_webauthn_registrations_id)
     end
 
     def execute
       return error(_('You are not authorized to perform this action')) unless authorized?
 
-      result = destroy_webauthn_device
+      result = destroy_second_factor_webauthn_device
 
       if result[:status] == :success
         notify_on_success(user, webauthn_registration.name)
@@ -33,9 +33,9 @@ module Webauthn
       current_user.can?(:disable_two_factor, user)
     end
 
-    def destroy_webauthn_device
+    def destroy_second_factor_webauthn_device
       ::Users::UpdateService.new(current_user, user: user).execute do |user|
-        user.destroy_webauthn_device(webauthn_registration.id)
+        user.destroy_second_factor_webauthn_device(webauthn_registration.id)
       end
     end
 
