@@ -8,11 +8,12 @@ module WikiPages
       # this class is not thread safe!
       @old_slug = page.slug
 
-      if page.wiki.capture_git_error(event_action) { page.update(@params) }
+      if page.update(@params)
         execute_hooks(page)
         ServiceResponse.success(payload: { page: page })
       else
-        raise UpdateError, s_('Could not update wiki page')
+        message = page.template? ? _('Could not update wiki template') : _('Could not update wiki page')
+        raise UpdateError, message
       end
     rescue UpdateError, WikiPage::PageChangedError, WikiPage::PageRenameError => e
       page.update_attributes(@params) # rubocop:disable Rails/ActiveRecordAliases
@@ -23,8 +24,8 @@ module WikiPages
       )
     end
 
-    def usage_counter_action
-      :update
+    def internal_event_name
+      'update_wiki_page'
     end
 
     def external_action
@@ -40,3 +41,5 @@ module WikiPages
     end
   end
 end
+
+WikiPages::UpdateService.prepend_mod_with('WikiPages::UpdateService')
