@@ -3,10 +3,9 @@ module Packages
   module Rpm
     class RepositoryFileUploader < GitlabUploader
       include ObjectStorage::Concern
+      include Packages::GcsSignedUrlMetadata
 
-      storage_options Gitlab.config.packages
-
-      after :store, :schedule_background_upload
+      storage_location :packages
 
       alias_method :upload, :model
 
