@@ -3,12 +3,10 @@
 class AuthorizedKeysWorker
   include ApplicationWorker
 
-  data_consistency :always
+  data_consistency :sticky
 
   sidekiq_options retry: 3
 
-  PERMITTED_ACTIONS = %w[add_key remove_key].freeze
-
   feature_category :source_code_management
   urgency :high
   weight 2
@@ -18,13 +16,10 @@ class AuthorizedKeysWorker
   def perform(action, *args)
     return unless Gitlab::CurrentSettings.authorized_keys_enabled?
 
-    case action.to_s
-    when 'add_key'
-      authorized_keys.add_key(*args)
-    when 'remove_key'
-      authorized_keys.remove_key(*args)
-    else
-      raise "Unknown action: #{action.inspect}"
+    case action
+    when 'add_key' then authorized_keys.add_key(*args)
+    when 'remove_key' then authorized_keys.remove_key(*args)
+    else raise "Unknown action: #{action.inspect}"
     end
   end
 
