@@ -1,5 +1,8 @@
 # frozen_string_literal: true
 
+# DEPRECATED
+#
+# To be removed by https://gitlab.com/gitlab-org/gitlab/-/issues/366573
 class ClusterWaitForAppInstallationWorker # rubocop:disable Scalability/IdempotentWorker
   include ApplicationWorker
 
@@ -16,9 +19,5 @@ class ClusterWaitForAppInstallationWorker # rubocop:disable Scalability/Idempote
   worker_resource_boundary :cpu
   loggable_arguments 0
 
-  def perform(app_name, app_id)
-    find_application(app_name, app_id) do |app|
-      Clusters::Applications::CheckInstallationProgressService.new(app).execute
-    end
-  end
+  def perform(app_name, app_id); end
 end
