@@ -18,12 +18,16 @@ class GitlabServicePingWorker # rubocop:disable Scalability/IdempotentWorker
   sidekiq_retry_in { |count| (count + 1) * 8.hours.to_i }
 
   def perform(options = {})
+    return unless ::Gitlab::CurrentSettings.usage_ping_generation_enabled?
+
+    organization = Organizations::Organization.first
+
     day_lock(NON_SQL_LEASE_KEY) do
-      save_non_sql_data
+      save_non_sql_data(organization)
     end
 
     day_lock(QUERIES_LEASE_KEY) do
-      save_queries_data
+      save_queries_data(organization)
     end
 
     # Sidekiq does not support keyword arguments, so the args need to be
@@ -37,18 +41,18 @@ class GitlabServicePingWorker # rubocop:disable Scalability/IdempotentWorker
     return if Gitlab.com? && triggered_from_cron
 
     day_lock(LEASE_KEY) do
-      ServicePing::SubmitService.new(payload: usage_data).execute
+      ServicePing::SubmitService.new(organization: organization, payload: usage_data(organization)).execute
     end
   end
 
-  def usage_data
+  def usage_data(organization)
     ServicePing::BuildPayload.new.execute.tap do |payload|
       record = {
         recorded_at: payload[:recorded_at],
         payload: payload,
         created_at: Time.current,
         updated_at: Time.current,
-        organization_id: Organizations::Organization.first.id
+        organization_id: organization.id
       }
 
       RawUsageData.upsert(record, unique_by: :recorded_at)
@@ -70,7 +74,7 @@ class GitlabServicePingWorker # rubocop:disable Scalability/IdempotentWorker
     end
   end
 
-  def save_non_sql_data
+  def save_non_sql_data(organization)
     payload = Gitlab::Usage::ServicePingReport.for(output: :non_sql_metrics_values)
     record = {
       recorded_at: payload[:recorded_at],
@@ -78,7 +82,7 @@ class GitlabServicePingWorker # rubocop:disable Scalability/IdempotentWorker
       metadata: Gitlab::Utils::UsageData.metrics_collection_metadata(payload),
       created_at: Time.current,
       updated_at: Time.current,
-      organization_id: Organizations::Organization.first.id
+      organization_id: organization.id
     }
 
     ServicePing::NonSqlServicePing.upsert(record, unique_by: :recorded_at)
@@ -87,14 +91,14 @@ class GitlabServicePingWorker # rubocop:disable Scalability/IdempotentWorker
     nil
   end
 
-  def save_queries_data
+  def save_queries_data(organization)
     payload = Gitlab::Usage::ServicePingReport.for(output: :metrics_queries)
     record = {
       recorded_at: payload[:recorded_at],
       payload: payload,
       created_at: Time.current,
       updated_at: Time.current,
-      organization_id: Organizations::Organization.first.id
+      organization_id: organization.id
     }
 
     ServicePing::QueriesServicePing.upsert(record, unique_by: :recorded_at)
