@@ -14,7 +14,7 @@ module IncidentManagement
     worker_has_external_dependencies!
 
     def perform(issue_id)
-      incident = Issue.incident.opened.find_by_id(issue_id)
+      incident = Issue.with_issue_type(:incident).opened.find_by_id(issue_id)
 
       return unless incident
 
@@ -25,12 +25,12 @@ module IncidentManagement
     private
 
     def user
-      @user ||= User.alert_bot
+      @user ||= Users::Internal.alert_bot
     end
 
     def close_incident(incident)
       ::Issues::CloseService
-        .new(project: incident.project, current_user: user)
+        .new(container: incident.project, current_user: user)
         .execute(incident, system_note: false)
     end
 
