@@ -7,7 +7,7 @@ class MigrateExternalDiffsWorker # rubocop:disable Scalability/IdempotentWorker
 
   sidekiq_options retry: 3
 
-  feature_category :code_review
+  feature_category :code_review_workflow
 
   def perform(merge_request_diff_id)
     diff = MergeRequestDiff.find_by_id(merge_request_diff_id)
