@@ -4,13 +4,14 @@ module Namespaces
   class RootStatisticsWorker
     include ApplicationWorker
 
-    data_consistency :always
+    data_consistency :sticky
 
     sidekiq_options retry: 3
 
     queue_namespace :update_namespace_statistics
     feature_category :source_code_management
     idempotent!
+    deduplicate :until_executed, if_deduplicated: :reschedule_once
 
     def perform(namespace_id)
       namespace = Namespace.find(namespace_id)
@@ -28,8 +29,7 @@ module Namespaces
 
     private
 
-    def notify_storage_usage(namespace)
-    end
+    def notify_storage_usage(namespace); end
   end
 end
 
