@@ -14,7 +14,7 @@ module Projects
     def perform(project_id)
       @project = Project.find(project_id)
 
-      service = Repositories::HousekeepingService.new(@project)
+      service = ::Repositories::HousekeepingService.new(@project)
 
       service.execute do
         import_failure_service.with_retry(action: 'delete_all_refs') do
@@ -26,12 +26,12 @@ module Projects
       # import actually changed, so we increment the counter to avoid
       # causing GC to run every time.
       service.increment!
-    rescue Repositories::HousekeepingService::LeaseTaken => e
-      Gitlab::Import::Logger.info(
+    rescue ::Repositories::HousekeepingService::LeaseTaken => e
+      ::Import::Framework::Logger.info(
         message: 'Project housekeeping failed',
         project_full_path: @project.full_path,
         project_id: @project.id,
-        'error.message' => e.message
+        'exception.message' => e.message
       )
     end
 
