@@ -47,9 +47,40 @@ workers 2
 
 require_relative "/var/lib/gitlab/lib/gitlab/cluster/lifecycle_events"
 
-on_restart do
-  # Signal application hooks that we're about to restart
-  Gitlab::Cluster::LifecycleEvents.do_before_master_restart
+if Gem::Version.new(Puma::Const::PUMA_VERSION) < Gem::Version.new('7.0')
+  Gitlab::Cluster::LifecycleEvents.set_puma_options @config.options
+
+  on_restart do
+    # Signal application hooks that we're about to restart
+    Gitlab::Cluster::LifecycleEvents.do_before_master_restart
+  end
+
+  on_worker_boot do
+    # Signal application hooks of worker start
+    Gitlab::Cluster::LifecycleEvents.do_worker_start
+  end
+
+  on_worker_shutdown do
+    # Signal application hooks that a worker is shutting down
+    Gitlab::Cluster::LifecycleEvents.do_worker_stop
+  end
+else
+  Gitlab::Cluster::LifecycleEvents.set_puma_worker_count(2)
+
+  before_restart do
+    # Signal application hooks that we're about to restart
+    Gitlab::Cluster::LifecycleEvents.do_before_master_restart
+  end
+
+  before_worker_boot do
+    # Signal application hooks of worker start
+    Gitlab::Cluster::LifecycleEvents.do_worker_start
+  end
+
+  before_worker_shutdown do
+    # Signal application hooks that a worker is shutting down
+    Gitlab::Cluster::LifecycleEvents.do_worker_stop
+  end
 end
 
 before_fork do
@@ -57,17 +88,6 @@ before_fork do
   Gitlab::Cluster::LifecycleEvents.do_before_fork
 end
 
-Gitlab::Cluster::LifecycleEvents.set_puma_options @config.options
-on_worker_boot do
-  # Signal application hooks of worker start
-  Gitlab::Cluster::LifecycleEvents.do_worker_start
-end
-
-on_worker_shutdown do
-  # Signal application hooks that a worker is shutting down
-  Gitlab::Cluster::LifecycleEvents.do_worker_stop
-end
-
 # Preload the application before starting the workers; this conflicts with
 # phased restart feature. (off by default)
 
