@@ -193,10 +193,13 @@ constraints(::Constraints::GroupUrlConstrainer.new) do
 
     namespace :observability do
       resource :o11y_service_settings, only: [:update, :edit, :destroy]
-      resource :access_requests, only: [:new, :create]
+      resource :setup, only: [:show], controller: 'setup'
+      resource :access_requests, only: [:create]
     end
     resources :observability, only: [:show]
 
+    resources :step_up_auths, only: [:new]
+
     post :preview_markdown
 
     post '/restore' => '/groups#restore', as: :restore
