@@ -123,7 +123,6 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
 
           resource :operations, only: [:show, :update] do
             member do
-              post :reset_alerting_token
               post :reset_pagerduty_token
             end
           end
@@ -189,6 +188,8 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
         resources :project_members, except: [:show, :new, :create, :edit], constraints: { id: %r{[a-zA-Z./0-9_\-#%+:]+} }, concerns: :access_requestable do
           collection do
             delete :leave
+
+            get :invite_search, format: :json
           end
 
           member do
@@ -346,12 +347,7 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
             get :search
           end
 
-          resources :deployments, only: [:index, :show] do
-            member do
-              get :metrics
-              get :additional_metrics
-            end
-          end
+          resources :deployments, only: [:index, :show]
         end
 
         resources :alert_management, only: [:index] do
@@ -362,6 +358,8 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
 
         get 'alert_management/:id', to: 'alert_management#details', as: 'alert_management_alert'
 
+        get :work_items, to: 'work_items#calendar', constraints: ->(req) { req.format == :ics }
+        get :work_items, to: 'work_items#rss', constraints: ->(req) { req.format == :atom }
         resources :work_items, only: [:show, :index], param: :iid do
           collection do
             post :import_csv
@@ -414,7 +412,7 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
           to: 'snippets/blobs#raw',
           format: false,
           as: :snippet_blob_raw,
-          constraints: { snippet_id: /\d+/ }
+          constraints: { snippet_id: /\d+/, ref: %r{[^\/]+} }
 
         draw :issues
         draw :merge_requests
@@ -468,6 +466,7 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
         resources :badges, only: [] do
           collection do
             constraints format: /svg/ do
+              get :custom
               get :release
             end
           end
@@ -507,6 +506,12 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
             end
           end
         end
+
+        resources :attestations, only: [] do
+          member do
+            get :download
+          end
+        end
       end
       # End of the /-/ scope.
 
@@ -551,17 +556,9 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
         end
       end
 
-      namespace :prometheus do
-        resources :metrics, constraints: { id: %r{[^\/]+} }, only: [:index, :new, :create, :edit, :update, :destroy] do # rubocop: disable Cop/PutProjectRoutesUnderScope
-          get :active_common, on: :collection # rubocop:todo Cop/PutProjectRoutesUnderScope
-          post :validate_query, on: :collection # rubocop:todo Cop/PutProjectRoutesUnderScope
-        end
-      end
-
       scope :prometheus, as: :prometheus do
         resources :alerts, constraints: { id: /\d+/ }, only: [] do # rubocop: disable Cop/PutProjectRoutesUnderScope
           post :notify, on: :collection, to: 'alerting/notifications#create', defaults: { endpoint_identifier: 'legacy-prometheus' } # rubocop: disable Cop/PutProjectRoutesUnderScope
-          get :metrics_dashboard, on: :member # rubocop:todo Cop/PutProjectRoutesUnderScope
         end
       end
 
