@@ -19,20 +19,10 @@ module Db
                   user.assign_personal_namespace(organization)
                 end
 
-              label_title = "abuse_report_label_#{FactoryBot.generate(:label_title)}"
-              ::AntiAbuse::Reports::Label.create(
-                title: label_title,
-                description: FFaker::Lorem.sentence,
-                color: "#{::Gitlab::Color.color_for(label_title)}"
-              )
-
-              label_ids = ::AntiAbuse::Reports::Label.pluck(:id).sample(rand(5))
-
               ::AbuseReport.create(
                 reporter: ::User.take,
                 user: reported_user,
                 message: 'User sends spam',
-                label_ids: label_ids
               )
 
               print '.'
