@@ -6,7 +6,7 @@ class CreateAiCodeSuggestionEvents < Gitlab::Database::Migration[2.2]
 
   def up
     # rubocop:disable Migration/Datetime -- "timestamp" is a column name
-    create_table :ai_code_suggestion_events,
+    create_table :ai_code_suggestion_events, # rubocop:disable Migration/EnsureFactoryForTable -- Table is removed
       options: 'PARTITION BY RANGE (timestamp)',
       primary_key: [:id, :timestamp] do |t|
       t.bigserial :id, null: false
