@@ -3,7 +3,7 @@
 class QueueBackfillPackagesConanPackageReferences < Gitlab::Database::Migration[2.2]
   milestone '17.8'
 
-  restrict_gitlab_migration gitlab_schema: :gitlab_main_cell
+  restrict_gitlab_migration gitlab_schema: :gitlab_main_org
 
   MIGRATION = 'BackfillPackagesConanPackageReferences'
   DELAY_INTERVAL = 2.minutes
