@@ -3,10 +3,6 @@
 class QueueBackfillOnboardingStatusRole < Gitlab::Database::Migration[2.2]
   milestone '17.8'
 
-  restrict_gitlab_migration gitlab_schema: :gitlab_main
-
-  MIGRATION = "BackfillOnboardingStatusRole"
-
   def up
     # no-op because we are missing some records due to a bypass in application logic
   end
