@@ -5,7 +5,7 @@
 class QueueLimitNamespaceVisibilityByOrganizationVisibility < Gitlab::Database::Migration[2.2]
   milestone '17.9'
 
-  restrict_gitlab_migration gitlab_schema: :gitlab_main_cell
+  restrict_gitlab_migration gitlab_schema: :gitlab_main_org
 
   MIGRATION = "LimitNamespaceVisibilityByOrganizationVisibility"
   DELAY_INTERVAL = 2.minutes
