@@ -6,7 +6,7 @@ class SetOrganizationIdForBulkImports < Gitlab::Database::Migration[2.2]
 
   milestone '17.11'
 
-  restrict_gitlab_migration gitlab_schema: :gitlab_main_cell
+  restrict_gitlab_migration gitlab_schema: :gitlab_main_org
 
   def up
     define_batchable_model('bulk_imports').where(organization_id: nil).each_batch(of: BATCH_SIZE) do |bulk_imports|
