@@ -633,9 +633,6 @@ class FixSeqOwnershipForBuildMetadata < Gitlab::Database::Migration[2.3]
     ['system_access_group_microsoft_applications_id_seq', 'system_access_group_microsoft_applications.id'],
     ['system_access_group_microsoft_graph_access_tokens_id_seq',
       'system_access_group_microsoft_graph_access_tokens.id'],
-    ['system_access_instance_microsoft_applications_id_seq', 'system_access_instance_microsoft_applications.id'],
-    ['system_access_instance_microsoft_graph_access_tokens_id_seq',
-      'system_access_instance_microsoft_graph_access_tokens.id'],
     ['system_access_microsoft_applications_id_seq', 'system_access_microsoft_applications.id'],
     ['system_access_microsoft_graph_access_tokens_id_seq', 'system_access_microsoft_graph_access_tokens.id'],
     ['system_note_metadata_id_seq', 'system_note_metadata.id'],
