@@ -75,6 +75,9 @@ module.exports = (path, options = {}) => {
         addFileAttribute: 'true',
       },
     ]);
+
+    reporters.push(['<rootDir>/scripts/frontend/jest_json_reporter.js', {}]);
+    reporters.push(['<rootDir>/scripts/frontend/jest_test_map_reporter.js', {}]);
   }
 
   const glob = `${path}/**/*@([._])spec.js`;
