@@ -5,9 +5,12 @@ require 'mime/types'
 module API
   class Branches < ::API::Base
     include PaginationParams
+    include APIGuard
 
     BRANCH_ENDPOINT_REQUIREMENTS = API::NAMESPACE_OR_PROJECT_REQUIREMENTS.merge(branch: API::NO_SLASH_URL_PART_REGEX)
 
+    allow_access_with_scope :ai_workflows, if: ->(request) { request.get? || request.head? }
+
     after_validation { content_type "application/json" }
 
     feature_category :source_code_management
