@@ -4,15 +4,10 @@ module API
   module Conan
     module V2
       class ProjectPackages < ::API::Base
-        MAX_FILES_COUNT = 1000
-
-        before do
-          if Feature.disabled?(:conan_package_revisions_support, Feature.current_request)
-            not_found!("'conan_package_revisions_support' feature flag is disabled")
-          end
-        end
+        MAX_FILES_COUNT = MAX_PACKAGE_REVISIONS_COUNT = 1000
 
         helpers do
+          include Gitlab::Utils::StrongMemoize
           def package_files(finder_params)
             ::Packages::Conan::PackageFilesFinder
               .new(package, **finder_params)
@@ -20,6 +15,41 @@ module API
               .limit(MAX_FILES_COUNT)
               .select(:file_name)
           end
+
+          def track_conan_package_event(event)
+            track_package_event(event, :conan, category: 'API::ConanPackages', project: project,
+              namespace: project.namespace)
+          end
+
+          def destroy_package_entity(entity, event_name)
+            track_conan_package_event(event_name)
+
+            entity.transaction do
+              ::Packages::MarkPackageFilesForDestructionService.new(entity.package_files).execute
+              destroy_conditionally!(entity) do
+                entity.destroy
+
+                # Conan cli expects 200 status code when deleting
+                status 200
+              end
+            end
+          end
+
+          def recipe_revision
+            package.conan_recipe_revisions.find_by_revision(params[:recipe_revision])
+          end
+          strong_memoize_attr :recipe_revision
+
+          def package_revisions
+            package.conan_package_revisions
+              .by_recipe_revision_and_package_reference(params[:recipe_revision],
+                params[:conan_package_reference])
+          end
+
+          def package_revision
+            package_revisions.find_by_revision(params[:package_revision])
+          end
+          strong_memoize_attr :package_revision
         end
 
         params do
@@ -97,6 +127,46 @@ module API
                     desc: 'Recipe revision', documentation: { example: 'df28fd816be3a119de5ce4d374436b25' }
                 end
                 namespace ':recipe_revision' do
+                  desc 'Delete recipe revision' do
+                    detail 'This feature was introduced in GitLab 18.1'
+                    success code: 200
+                    failure [
+                      { code: 400, message: 'Bad Request' },
+                      { code: 401, message: 'Unauthorized' },
+                      { code: 403, message: 'Forbidden' },
+                      { code: 404, message: 'Not Found' }
+                    ]
+                    tags %w[conan_packages]
+                  end
+
+                  route_setting :authentication, job_token_allowed: true, basic_auth_personal_access_token: true
+                  route_setting :authorization, job_token_policies: :admin_packages
+
+                  delete urgency: :low do
+                    authorize_destroy_package!(project)
+
+                    not_found!('Package') unless package
+
+                    not_found!('Revision') unless recipe_revision
+
+                    if package.conan_recipe_revisions.one?
+                      track_conan_package_event('delete_package')
+                      destroy_conditionally!(package) do |package|
+                        ::Packages::MarkPackageForDestructionService.new(container: package,
+                          current_user: current_user).execute
+
+                        # Conan cli expects 200 status code when deleting a recipe revision
+                        status 200
+                      end
+                    else
+                      if recipe_revision.package_files.size > MAX_FILES_COUNT
+                        unprocessable_entity! "Cannot delete more than #{MAX_FILES_COUNT} files"
+                      end
+
+                      destroy_package_entity(recipe_revision, 'delete_recipe_revision')
+                    end
+                  end
+
                   namespace 'files' do
                     desc 'List recipe files' do
                       detail 'This feature was introduced in GitLab 17.11'
@@ -190,6 +260,32 @@ module API
                     end
                   end
 
+                  desc 'Get package references metadata' do
+                    detail 'This feature was introduced in GitLab 18.1'
+                    success code: 200
+                    failure [
+                      { code: 400, message: 'Bad Request' },
+                      { code: 401, message: 'Unauthorized' },
+                      { code: 403, message: 'Forbidden' },
+                      { code: 404, message: 'Not Found' }
+                    ]
+                    tags %w[conan_packages]
+                  end
+
+                  route_setting :authentication, job_token_allowed: true, basic_auth_personal_access_token: true
+                  route_setting :authorization,  job_token_policies: :read_packages,
+                    allow_public_access_for_enabled_project_features: :package_registry
+
+                  get 'search', urgency: :low do
+                    check_username_channel
+
+                    authorize_read_package!(project)
+                    not_found!('Package') unless package
+                    not_found!('Revision') unless recipe_revision.present?
+
+                    recipe_revision.conan_package_references.pluck_reference_and_info.to_h
+                  end
+
                   params do
                     requires :conan_package_reference, type: String,
                       regexp: Gitlab::Regex.conan_package_reference_regex, desc: 'Package reference',
@@ -214,9 +310,7 @@ module API
                       get urgency: :low do
                         not_found!('Package') unless package
 
-                        revision = package.conan_package_revisions
-                          .by_recipe_revision_and_package_reference(params[:recipe_revision],
-                            params[:conan_package_reference]).order_by_id_desc.first
+                        revision = package_revisions.order_by_id_desc.first
 
                         not_found!('Revision') unless revision.present?
 
@@ -224,11 +318,70 @@ module API
                       end
                     end
                     namespace 'revisions' do
+                      desc 'Get the list of package revisions' do
+                        detail 'This feature was introduced in GitLab 18.0'
+                        success code: 200, model: ::API::Entities::Packages::Conan::PackageRevisions
+                        failure [
+                          { code: 400, message: 'Bad Request' },
+                          { code: 401, message: 'Unauthorized' },
+                          { code: 403, message: 'Forbidden' },
+                          { code: 404, message: 'Not Found' }
+                        ]
+                        tags %w[conan_packages]
+                      end
+                      route_setting :authentication, job_token_allowed: true, basic_auth_personal_access_token: true
+                      route_setting :authorization, job_token_policies: :read_packages,
+                        allow_public_access_for_enabled_project_features: :package_registry
+                      get urgency: :low do
+                        not_found!('Package') unless package
+
+                        revisions = package_revisions
+                          .order_by_id_desc
+                          .limit(MAX_PACKAGE_REVISIONS_COUNT)
+
+                        package_reference = "#{package.conan_recipe}##{params[:recipe_revision]}:" \
+                          "#{params[:conan_package_reference]}"
+                        present({ package_reference: package_reference, package_revisions: revisions },
+                          with: ::API::Entities::Packages::Conan::PackageRevisions)
+                      end
+
                       params do
                         requires :package_revision, type: String, regexp: Gitlab::Regex.conan_revision_regex_v2,
                           desc: 'Package revision', documentation: { example: '3bdd2d8c8e76c876ebd1ac0469a4e72c' }
                       end
                       namespace ':package_revision' do
+                        desc 'Delete package revision' do
+                          detail 'This feature was introduced in GitLab 18.1'
+                          success code: 200
+                          failure [
+                            { code: 400, message: 'Bad Request' },
+                            { code: 401, message: 'Unauthorized' },
+                            { code: 403, message: 'Forbidden' },
+                            { code: 404, message: 'Not Found' }
+                          ]
+                          tags %w[conan_packages]
+                        end
+
+                        route_setting :authentication, job_token_allowed: true, basic_auth_personal_access_token: true
+                        route_setting :authorization, job_token_policies: :admin_packages
+
+                        delete urgency: :low do
+                          authorize_destroy_package!(project)
+
+                          not_found!('Package') unless package
+
+                          not_found!('Package Revision') unless package_revision
+
+                          if package_revision.package_files.size > MAX_FILES_COUNT
+                            unprocessable_entity! "Cannot delete more than #{MAX_FILES_COUNT} files"
+                          end
+
+                          if package_revisions.one?
+                            destroy_package_entity(package_revision.package_reference, 'delete_package_reference')
+                          else
+                            destroy_package_entity(package_revision, 'delete_package_revision')
+                          end
+                        end
                         namespace 'files' do
                           desc 'List package files' do
                             detail 'This feature was introduced in GitLab 18.0'
