@@ -9,6 +9,8 @@ module API
           expose :ref_type
           expose :refspecs
           expose :git_depth, as: :depth
+          expose :repo_object_format
+          expose :protected
         end
       end
     end
