@@ -3,15 +3,15 @@
 module API
   module Entities
     class MergeRequestApprovals < Grape::Entity
-      expose :user_has_approved do |merge_request, options|
+      expose :user_has_approved, documentation: { type: 'boolean' } do |merge_request, options|
         merge_request.approved_by?(options[:current_user])
       end
 
-      expose :user_can_approve do |merge_request, options|
+      expose :user_can_approve, documentation: { type: 'boolean' } do |merge_request, options|
         merge_request.eligible_for_approval_by?(options[:current_user])
       end
 
-      expose :approved do |merge_request|
+      expose :approved, documentation: { type: 'boolean' } do |merge_request|
         merge_request.approvals.present?
       end
 
