@@ -69,23 +69,21 @@ module API
           project = authorized_user_project(action: :read_package)
           authorize_read_package!(project)
 
-          if Feature.enabled?(:packages_helm_metadata_cache, project)
-            helm_metadata_cache = find_metadata_cache(project.id)
-            if helm_metadata_cache
-              helm_metadata_cache.touch_last_downloaded_at
-              present_carrierwave_file!(helm_metadata_cache.file)
+          helm_metadata_cache = find_metadata_cache(project.id)
+          if helm_metadata_cache
+            helm_metadata_cache.touch_last_downloaded_at
+            present_carrierwave_file!(helm_metadata_cache.file)
 
-              break
-            end
+            break
           end
 
           packages = ::Packages::Helm::PackagesFinder.new(project, params[:channel]).execute
           metadata = ::Packages::Helm::GenerateMetadataService.new(params[:id], params[:channel], packages).execute
 
-          # rubocop:disable CodeReuse/Worker -- This is required because we want to sync metadata cache as soon as it's accessed
-          # Related issue: https://gitlab.com/gitlab-org/gitlab/-/work_items/569680
-          ::Packages::Helm::CreateMetadataCacheWorker.perform_async(project.id, params[:channel])
-          # rubocop:enable CodeReuse/Worker
+          ::Packages::Helm::BulkSyncHelmMetadataCacheService.new(
+            current_user,
+            ::Packages::PackageFile.for_package_ids(packages.map(&:id)).for_helm_with_channel(project, params[:channel])
+          ).execute
 
           present metadata.payload, with: ::API::Entities::Helm::Index
         end
