@@ -113,7 +113,8 @@ module API
     def set_current_organization(user: current_user)
       ::Current.organization = Gitlab::Current::Organization.new(
         params: {},
-        user: user
+        user: user,
+        headers: request.headers
       ).organization
     end
 
@@ -326,7 +327,7 @@ module API
       ::IssuesFinder.new(
         current_user,
         project_id: project.id,
-        issue_types: WorkItems::Type.allowed_types_for_issues
+        issue_types: ::WorkItems::TypesFilter.allowed_types_for_issues
       ).find_by!(iid: iid)
     end
     # rubocop: enable CodeReuse/ActiveRecord
@@ -659,8 +660,13 @@ module API
 
     def handle_api_exception(exception)
       if report_exception?(exception)
+        context_user = begin
+          current_user
+        rescue StandardError
+          nil
+        end
         define_params_for_grape_middleware
-        Gitlab::ApplicationContext.push(user: current_user, remote_ip: request.ip)
+        Gitlab::ApplicationContext.push(user: context_user, remote_ip: request.ip)
         Gitlab::ErrorTracking.track_exception(exception)
       end
 
@@ -871,16 +877,18 @@ module API
       return unless token_info
       return unless TOKEN_SCOPES_TO_AUDIT.intersect?(Array.wrap(token_info[:token_scopes]))
 
+      request_author = Gitlab::Auth::Identity.invert_composite_identity(user)
       context = {
         name: 'api_request_access_with_scope',
-        author: user,
-        scope: user,
+        author: request_author,
+        scope: request_author,
         target: ::Gitlab::Audit::NullTarget.new,
         message: "API request with token scopes #{token_info[:token_scopes]} - #{request.request_method} #{request.path}",
         additional_details: {
           request: request.path,
           method: request.request_method,
-          token_scopes: token_info[:token_scopes]
+          token_scopes: token_info[:token_scopes],
+          scoped_user_id: user.id
         }
       }
 
@@ -1028,18 +1036,20 @@ module API
     end
 
     def url_with_project_id(project)
-      new_params = params.merge(id: project.id.to_s).transform_values { |v| v.is_a?(String) ? CGI.escape(v) : v }
-      new_path = GrapePathHelpers::DecoratedRoute.new(route).path_segments_with_values(new_params).join('/')
+      path_values = params.merge(id: project.id).transform_values { |v| v.is_a?(String) ? CGI.escape(v) : v }
+      path = GrapePathHelpers::DecoratedRoute.new(route).path_segments_with_values(path_values).join('/')
+      extension = File.extname(request.path_info)
 
-      Rack::Request.new(env).tap do |r|
-        r.path_info = "/#{new_path}"
-      end.url
+      Rack::Request.new(env).tap { |r| r.path_info = "/#{path}#{extension}" }.url
     end
 
     def handle_job_token_failure!(project)
       if current_user&.from_ci_job_token? && current_user.ci_job_token_scope
         source_project = current_user.ci_job_token_scope.current_project
-        error_message = format("Authentication by CI/CD job token not allowed from %{source_project_path} to %{target_project_path}.", source_project_path: source_project.path, target_project_path: project.path)
+
+        error_message = format("Authentication by CI/CD job token not allowed from %{source_project_path} to project #%{target_project_id}.",
+          source_project_path: source_project.path,
+          target_project_id: project.id)
 
         forbidden!(error_message)
       else
@@ -1061,13 +1071,13 @@ module API
       when 0
         'This action is unauthorized for CI/CD job tokens.'
       when 1
-        format("Insufficient permissions to access this resource in project %{project}. " \
+        format("Insufficient permissions to access this resource in project #%{project_id}. " \
           "The following token permission is required: %{policy}.",
-          project: project.path, policy: policies[0])
+          project_id: project.id, policy: policies[0])
       else
-        format("Insufficient permissions to access this resource in project %{project}. " \
+        format("Insufficient permissions to access this resource in project #%{project_id}. " \
           "The following token permissions are required: %{policies}.",
-          project: project.path, policies: policies.to_sentence)
+          project_id: project.id, policies: policies.to_sentence)
       end
     end
 
