@@ -52,6 +52,7 @@ module API
         end
         params do
           optional :sha, type: String, desc: 'When present, must have the HEAD SHA of the source branch'
+          optional :publish_review, type: Boolean, desc: 'When `true` submits pending review comments'
 
           use :ee_approval_params
         end
@@ -60,6 +61,12 @@ module API
 
           check_sha_param!(params, merge_request)
 
+          if params[:publish_review]
+            result = ::DraftNotes::PublishService.new(merge_request, current_user).execute
+
+            render_api_error('Failed to publish review', 500) unless result[:status] == :success
+          end
+
           success =
             ::MergeRequests::ApprovalService
               .new(project: user_project, current_user: current_user, params: params)
