@@ -1,9 +1,24 @@
 # frozen_string_literal: true
 
+# rubocop:disable API/DescriptionSuccessResponse -- search api responds with multiple entity types
 module API
   class Search < ::API::Base
     include PaginationParams
     include APIGuard
+    include ::API::Concerns::McpAccess
+
+    SCOPE_ENTITY = {
+      merge_requests: Entities::MergeRequestBasic,
+      issues: Entities::IssueBasic,
+      projects: Entities::BasicProjectDetails,
+      milestones: Entities::Milestone,
+      notes: Entities::Note,
+      commits: Entities::CommitDetail,
+      blobs: Entities::Blob,
+      wiki_blobs: Entities::Blob,
+      snippet_titles: Entities::Snippet,
+      users: Entities::UserBasic
+    }.freeze
 
     before do
       authenticate!
@@ -13,6 +28,7 @@ module API
     end
 
     allow_access_with_scope :ai_workflows, if: ->(request) { request.get? || request.head? }
+    allow_mcp_access_read
 
     feature_category :global_search
     urgency :low
@@ -22,19 +38,6 @@ module API
     end
 
     helpers do
-      SCOPE_ENTITY = {
-        merge_requests: Entities::MergeRequestBasic,
-        issues: Entities::IssueBasic,
-        projects: Entities::BasicProjectDetails,
-        milestones: Entities::Milestone,
-        notes: Entities::Note,
-        commits: Entities::CommitDetail,
-        blobs: Entities::Blob,
-        wiki_blobs: Entities::Blob,
-        snippet_titles: Entities::Snippet,
-        users: Entities::UserBasic
-      }.freeze
-
       def scope_preload_method
         {
           merge_requests: :with_api_entity_associations,
@@ -121,7 +124,7 @@ module API
         scope_preload_method[params[:scope].to_sym]
       end
 
-      def verify_search_scope!(resource:)
+      def verify_search_scope!(_ = {})
         # no-op
       end
 
@@ -162,6 +165,7 @@ module API
     resource :search do
       desc 'Search on GitLab' do
         detail 'This feature was introduced in GitLab 10.5.'
+        tags ['search']
       end
       params do
         requires :search, type: String, desc: 'The expression it should be searched for'
@@ -174,9 +178,10 @@ module API
         use :search_params_ee
         use :pagination
       end
-      route_setting :mcp, tool_name: :gitlab_search, params: Helpers::SearchHelpers.gitlab_search_mcp_params
+      route_setting :mcp, tool_name: :gitlab_search_in_instance,
+        params: Helpers::SearchHelpers.gitlab_search_mcp_params, aggregators: [::Mcp::Tools::GitlabSearchService]
       get do
-        verify_search_scope!(resource: nil)
+        verify_search_scope!
 
         set_headers('Content-Transfer-Encoding' => 'binary')
 
@@ -185,11 +190,12 @@ module API
     end
 
     resource :groups, requirements: API::NAMESPACE_OR_PROJECT_REQUIREMENTS do
-      desc 'Search on GitLab' do
+      desc 'Search on GitLab within a group' do
         detail 'This feature was introduced in GitLab 10.5.'
+        tags %w[search groups]
       end
       params do
-        requires :id, type: String, desc: 'The ID of a group'
+        requires :id, types: [String, Integer], desc: 'The ID or URL-encoded path of the group'
         requires :search, type: String, desc: 'The expression it should be searched for'
         requires :scope,
           type: String,
@@ -200,9 +206,10 @@ module API
         use :search_params_ee
         use :pagination
       end
+      route_setting :mcp, tool_name: :gitlab_search_in_group,
+        params: Helpers::SearchHelpers.gitlab_search_mcp_params, aggregators: [::Mcp::Tools::GitlabSearchService]
       get ':id/(-/)search' do
-        verify_search_scope!(resource: user_group)
-
+        verify_search_scope!(group_id: user_group.id)
         set_headers
 
         present search(group_id: user_group.id), with: entity, current_user: current_user
@@ -210,8 +217,9 @@ module API
     end
 
     resource :projects, requirements: API::NAMESPACE_OR_PROJECT_REQUIREMENTS do
-      desc 'Search on GitLab' do
+      desc 'Search on GitLab within a project' do
         detail 'This feature was introduced in GitLab 10.5.'
+        tags %w[search projects]
       end
       params do
         requires :id, types: [String, Integer], desc: 'The ID or URL-encoded path of the project'
@@ -227,6 +235,8 @@ module API
         use :search_params_ee
         use :pagination
       end
+      route_setting :mcp, tool_name: :gitlab_search_in_project,
+        params: Helpers::SearchHelpers.gitlab_search_mcp_params, aggregators: [::Mcp::Tools::GitlabSearchService]
       get ':id/(-/)search' do
         set_headers
 
@@ -236,3 +246,4 @@ module API
     end
   end
 end
+# rubocop:enable API/DescriptionSuccessResponse
