@@ -20,6 +20,10 @@ module API
       def snippets_for_current_user
         find_snippets(params: { author: current_user })
       end
+
+      def find_snippet(id)
+        find_snippets(user: current_user, params: { ids: id }).first
+      end
     end
 
     resource :snippets do
@@ -69,7 +73,11 @@ module API
 
         filter_params = declared_params(include_missing: false).merge(only_personal: true)
 
-        present paginate(find_snippets(user: nil, params: filter_params)), with: Entities::PersonalSnippet, current_user: current_user
+        present(
+          paginate(find_snippets(user: nil, params: filter_params)),
+          with: Entities::PersonalSnippet,
+          current_user: current_user
+        )
       end
 
       desc 'List all snippets current_user has access to' do
@@ -108,7 +116,7 @@ module API
         requires :id, type: Integer, desc: 'The ID of a snippet'
       end
       get ':id' do
-        snippet = find_snippets.find_by_id(params[:id])
+        snippet = find_snippet(params[:id])
 
         break not_found!('Snippet') unless snippet
 
@@ -141,7 +149,11 @@ module API
         authorize! :create_snippet
 
         attrs = process_create_params(declared_params(include_missing: false))
-        service_response = ::Snippets::CreateService.new(project: nil, current_user: current_user, params: attrs).execute
+        service_response = ::Snippets::CreateService.new(
+          project: nil,
+          current_user: current_user,
+          params: attrs
+        ).execute
         snippet = service_response.payload[:snippet]
 
         if service_response.success?
@@ -188,7 +200,12 @@ module API
         validate_params_for_multiple_files(snippet)
 
         attrs = process_update_params(declared_params(include_missing: false))
-        service_response = ::Snippets::UpdateService.new(project: nil, current_user: current_user, params: attrs, perform_spam_check: true).execute(snippet)
+        service_response = ::Snippets::UpdateService.new(
+          project: nil,
+          current_user: current_user,
+          params: attrs,
+          perform_spam_check: true
+        ).execute(snippet)
 
         snippet = service_response.payload[:snippet]
 
@@ -244,7 +261,7 @@ module API
         requires :id, type: Integer, desc: 'The ID of a snippet'
       end
       get ":id/raw" do
-        snippet = find_snippets.find_by_id(params.delete(:id))
+        snippet = find_snippet(params.delete(:id))
         not_found!('Snippet') unless snippet
 
         present content_for(snippet)
@@ -260,7 +277,7 @@ module API
         use :raw_file_params
       end
       get ":id/files/:ref/:file_path/raw", requirements: { file_path: API::NO_SLASH_URL_PART_REGEX } do
-        snippet = find_snippets.find_by_id(params.delete(:id))
+        snippet = find_snippet(params.delete(:id))
         not_found!('Snippet') unless snippet&.repo_exists?
 
         present file_content_for(snippet)
