@@ -14,12 +14,16 @@ module API
 
       desc 'Get Non SQL usage ping metrics' do
         detail 'This feature was introduced in GitLab 13.11.'
+        success code: 200
+        failure [
+          { code: 401, message: 'Unauthorized' },
+          { code: 403, message: 'Forbidden' },
+          { code: 404, message: 'Not Found' }
+        ]
       end
 
       get 'non_sql_metrics' do
-        Gitlab::QueryLimiting.disable!('https://gitlab.com/gitlab-org/gitlab/-/issues/325534')
-
-        data = Gitlab::Usage::ServicePingReport.for(output: :non_sql_metrics_values)
+        data = ::ServicePing::NonSqlServicePing.for_current_reporting_cycle.pick(:payload) || {}
 
         present data
       end
