@@ -4,9 +4,10 @@ module Authn
   module Tokens
     class FeatureFlagsClientToken
       def self.prefix?(plaintext)
-        current_prefix = ::Operations::FeatureFlagsClient.prefix_for_feature_flags_client_token
-        default_prefix = Authn::TokenField::PrefixHelper.default_instance_prefix(current_prefix)
-        plaintext.start_with?(current_prefix, default_prefix)
+        feature_flags_client_token_prefixes = [::Operations::FeatureFlagsClient.prefix_for_feature_flags_client_token,
+          ::Operations::FeatureFlagsClient::FEATURE_FLAGS_CLIENT_TOKEN_PREFIX].uniq
+
+        plaintext.start_with?(*feature_flags_client_token_prefixes)
       end
 
       attr_reader :revocable, :source
