@@ -4,12 +4,19 @@ module Authn
   module Tokens
     class RunnerAuthenticationToken
       def self.prefix?(plaintext)
-        plaintext.start_with?(Ci::Runner::CREATED_RUNNER_TOKEN_PREFIX)
+        prefixes = [
+          ::Ci::Runner.created_runner_prefix,
+          ::Ci::Runner::CREATED_RUNNER_TOKEN_PREFIX
+        ]
+
+        plaintext.start_with?(*prefixes)
       end
 
       attr_reader :revocable, :source
 
       def initialize(plaintext, source)
+        return unless self.class.prefix?(plaintext)
+
         @revocable = ::Ci::Runner.find_by_token(plaintext)
         @source = source
       end
