@@ -8,21 +8,24 @@ module Banzai
     # HTML that replaces all `lang plantuml` tags with PlantUML img tags.
     #
     class PlantumlFilter < HTML::Pipeline::Filter
+      prepend Concerns::PipelineTimingCheck
+
       def call
         return doc unless settings.plantuml_enabled? && doc.at_xpath(lang_tag)
 
-        plantuml_setup
+        Gitlab::Plantuml.configure
 
         doc.xpath(lang_tag).each do |node|
+          diagram_src = node.content.chomp
           img_tag = Nokogiri::HTML::DocumentFragment.parse(
-            Asciidoctor::PlantUml::Processor.plantuml_content(node.content, {})).css('img').first
+            Asciidoctor::PlantUml::Processor.plantuml_content(diagram_src, {})).css('img').first
 
-          unless img_tag.nil?
-            img_tag.set_attribute('data-diagram', 'plantuml')
-            img_tag.set_attribute('data-diagram-src', "data:text/plain;base64,#{Base64.strict_encode64(node.content)}")
+          next if img_tag.nil?
 
-            node.parent.replace(img_tag)
-          end
+          img_tag.set_attribute('data-diagram', 'plantuml')
+          img_tag.set_attribute('data-diagram-src', "data:text/plain;base64,#{Base64.strict_encode64(diagram_src)}")
+
+          node.parent.replace(img_tag)
         end
 
         doc
@@ -32,21 +35,12 @@ module Banzai
 
       def lang_tag
         @lang_tag ||= Gitlab::Utils::Nokogiri
-          .css_to_xpath('pre[lang="plantuml"] > code, pre > code[lang="plantuml"]').freeze
+          .css_to_xpath('pre[data-canonical-lang="plantuml"] > code, pre > code[data-canonical-lang="plantuml"]').freeze
       end
 
       def settings
         Gitlab::CurrentSettings.current_application_settings
       end
-
-      def plantuml_setup
-        Asciidoctor::PlantUml.configure do |conf|
-          conf.url = settings.plantuml_url
-          conf.png_enable = settings.plantuml_enabled
-          conf.svg_enable = false
-          conf.txt_enable = false
-        end
-      end
     end
   end
 end
