@@ -14,7 +14,7 @@ module Banzai
         def parent_records(parent, ids)
           return AlertManagement::Alert.none unless parent.is_a?(Project)
 
-          parent.alert_management_alerts.where(iid: ids.to_a)
+          parent.alert_management_alerts.iid_in(ids.to_a)
         end
 
         def url_for_object(alert, project)
