@@ -70,23 +70,10 @@ module Banzai
         end
 
         def references_in(text, pattern = Label.reference_pattern)
-          labels = {}
-
-          unescaped_html = unescape_html_entities(text).gsub(pattern).with_index do |match, index|
-            ident = identifier($~)
-            label = yield match, ident, $~[:project], $~[:namespace], $~
-
-            if label != match
-              labels[index] = label
-              "#{REFERENCE_PLACEHOLDER}#{index}"
-            else
-              match
-            end
+          replace_references_in_text_with_html(text.gsub(pattern)) do |match_data|
+            ident = identifier(match_data)
+            yield match_data[0], ident, match_data[:project], match_data[:namespace], match_data
           end
-
-          return text if labels.empty?
-
-          escape_with_placeholders(unescaped_html, labels)
         end
 
         def find_labels(parent, absolute_path: false)
@@ -130,20 +117,18 @@ module Banzai
           end
         end
 
-        def object_link_text(object, matches)
-          label_suffix = ''
+        def object_link_content_html(object, matches)
+          reference = nil
           parent = project || group
 
           if matches[:absolute_path].blank? && (project || full_path_ref?(matches))
             project_path    = reference_cache.full_project_path(matches[:namespace], matches[:project], matches)
             parent_from_ref = from_ref_cached(project_path)
             reference       = parent_from_ref.to_human_reference(parent)
-
-            label_suffix = " <i>in #{ERB::Util.html_escape(reference)}</i>" if reference.present?
           end
 
           presenter = object.present(issuable_subject: parent)
-          LabelsHelper.render_colored_label(presenter, suffix: label_suffix)
+          LabelsHelper.render_colored_label(presenter, in_reference: reference)
         end
 
         def wrap_link(link, label)
@@ -159,6 +144,7 @@ module Banzai
           super + ' gl-link gl-label-link'
         end
 
+        # Returns a String containing text.
         def object_link_title(object, matches)
           presenter = object.present(issuable_subject: project || group)
           LabelsHelper.label_tooltip_title(presenter)
