@@ -10,7 +10,10 @@ module BulkImports
             source_full_path: entry['full_path'],
             destination_name: entry['path'],
             destination_namespace: context.entity.group.full_path,
-            parent_id: context.entity.id
+            organization_id: context.entity.group.organization_id,
+            parent_id: context.entity.id,
+            migrate_projects: context.entity.migrate_projects,
+            migrate_memberships: context.entity.migrate_memberships
           }
         end
       end
