@@ -20,10 +20,7 @@ module Gitlab
                 query.model.arel_table[:start_event_timestamp]
               )
             else
-              Arel::Nodes::Subtraction.new(
-                query.model.arel_table[:end_event_timestamp],
-                query.model.arel_table[:start_event_timestamp]
-              )
+              calculate_duration
             end
           end
 
@@ -32,7 +29,19 @@ module Gitlab
           end
 
           def duration_in_seconds(duration_expression = duration)
-            Arel::Nodes::Extract.new(duration_expression, :epoch)
+            Arel::Nodes::NamedFunction.new('CAST', [Arel::Nodes::Extract.new(duration_expression, :epoch).as('double precision')])
+          end
+
+          private
+
+          def calculate_duration
+            # Cast the duration_in_milliseconds bigint column to interval. We divide the
+            # duration by 1000 thus we get a double precision number (seconds). The division is necessary
+            # to avoid query errors for very long duration values.
+            # Reason: Interval is parsed as a 32 bit integer and when the duration_in_milliseconds has
+            # a very high value the parsing will fail.
+            column = "#{query.model.quoted_table_name}.duration_in_milliseconds / 1000.0 || ' seconds'"
+            Arel::Nodes::NamedFunction.new('CAST', [Arel.sql("(#{column}) AS interval")])
           end
         end
       end
