@@ -35,6 +35,7 @@ module Gitlab
       include Gitlab::Utils::StrongMemoize
       include ActionController::HttpAuthentication::Basic
       include ActionController::HttpAuthentication::Token
+      include Gitlab::RackLoadBalancingHelpers
 
       PRIVATE_TOKEN_HEADER = 'HTTP_PRIVATE_TOKEN'
       PRIVATE_TOKEN_PARAM = :private_token
@@ -332,7 +333,7 @@ module Gitlab
         # The runner sends the job token for PUT /api/jobs/:id in the PRIVATE-TOKEN header
         # and the token JSON parameter. Ignore this personal access token so
         # that the job token can be authenticated.
-        return if api_request? && current_token.start_with?(::Ci::Build::TOKEN_PREFIX)
+        return if api_request? && ::Authn::Tokens::CiJobToken.prefix?(current_token)
 
         # Expiration, revocation and scopes are verified in `validate_access_token!`
         PersonalAccessToken.find_by_token(current_token.to_s) || raise(UnauthorizedError)
@@ -342,6 +343,14 @@ module Gitlab
         self.current_token = parsed_oauth_token
         return unless current_token
 
+        # Ensure we use correct load balancing logic in case it's a newly created token
+        load_balancer_stick_request(
+          ::OauthAccessToken,
+          :oauth_token,
+          current_token,
+          hash_id: true
+        )
+
         # Expiration, revocation and scopes are verified in `validate_access_token!`
         oauth_token = OauthAccessToken.by_token(current_token)
         raise UnauthorizedError unless oauth_token
