@@ -4,6 +4,8 @@ module Gitlab
   module BackgroundMigration
     # Backfills the `members.member_namespace_id` column for `type=ProjectMember`
     class BackfillProjectMemberNamespaceId < Gitlab::BackgroundMigration::BatchedMigrationJob
+      feature_category :database
+
       def perform
         parent_batch_relation = relation_scoped_to_range(batch_table, batch_column, start_id, end_id)
 
@@ -20,7 +22,7 @@ module Gitlab
       end
 
       def batch_metrics
-        @batch_metrics ||= Gitlab::Database::BackgroundMigration::BatchMetrics.new
+        @batch_metrics ||= Gitlab::Database::Batch::Metrics.new
       end
 
       private
