@@ -7,8 +7,9 @@ module Gitlab
         LoadError = Class.new(StandardError)
 
         class << self
-          def load!(content, context, inputs = {})
-            Loader.new(content, inputs: inputs, context: context).load.then do |result|
+          def load!(content, context, inputs = {}, external_context = nil)
+            Loader.new(content, inputs: inputs, context: context,
+              external_context: external_context).load.then do |result|
               raise result.error_class, result.error if !result.valid? && result.error_class.present?
               raise LoadError, result.error unless result.valid?
 
