@@ -50,9 +50,11 @@ module Gitlab
             association => {
               **::Ci::Pipeline::PROJECT_ROUTE_AND_NAMESPACE_ROUTE,
               runner: :tags,
+              job_environment: [],
               job_artifacts_archive: [],
               user: [],
               metadata: [],
+              job_definition: [],
               ci_stage: []
             }
           }
@@ -76,6 +78,7 @@ module Gitlab
           finished_at: pipeline.finished_at,
           duration: pipeline.duration,
           queued_duration: pipeline.queued_duration,
+          protected_ref: pipeline.protected_ref?,
           variables: pipeline.variables.map(&:hook_attrs),
           url: Gitlab::Routing.url_helpers.project_pipeline_url(pipeline.project, pipeline)
         }
