@@ -4,6 +4,7 @@ module Gitlab
   module Database
     MAIN_DATABASE_NAME = 'main'
     CI_DATABASE_NAME = 'ci'
+    SEC_DATABASE_NAME = 'sec'
     DEFAULT_POOL_HEADROOM = 10
 
     # This constant is used when renaming tables concurrently.
@@ -178,9 +179,12 @@ module Gitlab
     end
 
     def self.database_mode
-      if !has_config?(CI_DATABASE_NAME)
+      secondary_databases = Gitlab::Database.all_database_connections.select { |_, db| db.has_gitlab_shared? }.keys
+      secondary_databases -= [MAIN_DATABASE_NAME]
+
+      if secondary_databases.none? { |db| has_config?(db) }
         MODE_SINGLE_DATABASE
-      elsif has_database?(CI_DATABASE_NAME)
+      elsif secondary_databases.any? { |db| has_database?(db) }
         MODE_MULTIPLE_DATABASES
       else
         MODE_SINGLE_DATABASE_CI_CONNECTION
@@ -223,6 +227,24 @@ module Gitlab
       MAX_TIMESTAMP_VALUE > timestamp ? timestamp : MAX_TIMESTAMP_VALUE.dup
     end
 
+    # We use ApplicationRecord here but these quoting helpers can be used on any query fragment
+    # since all our databases use the same PostgreSQL adapter
+    def self.quote_table_name(table_name)
+      if ::Gitlab.next_rails?
+        ApplicationRecord.adapter_class.quote_table_name(table_name)
+      else
+        ApplicationRecord.connection.quote_table_name(table_name)
+      end
+    end
+
+    def self.quote_column_name(column_name)
+      if ::Gitlab.next_rails?
+        ApplicationRecord.adapter_class.quote_column_name(column_name)
+      else
+        ApplicationRecord.connection.quote_column_name(column_name)
+      end
+    end
+
     def self.all_uncached(&block)
       # Calls to #uncached only disable caching for the current connection. Since the load balancer
       # can potentially upgrade from read to read-write mode (using a different connection), we specify
@@ -314,7 +336,7 @@ module Gitlab
     def self.empty_config?(db_config)
       return true unless db_config
 
-      ::Gitlab.next_rails? && db_config.is_a?(ActiveRecord::ConnectionAdapters::NullPool::NullConfig)
+      db_config.is_a?(ActiveRecord::ConnectionAdapters::NullPool::NullConfig)
     end
 
     # At the moment, the connection can only be retrieved by
@@ -390,15 +412,7 @@ module Gitlab
 
           ::Gitlab::Database::Metrics.subtransactions_increment(self.name) if transaction_type == :sub_transaction
 
-          if ::Gitlab.next_rails?
-            super(**options, &block)
-          else
-            payload = { connection: connection, transaction_type: transaction_type }
-
-            ActiveSupport::Notifications.instrument('transaction.active_record', payload) do
-              super(**options, &block)
-            end
-          end
+          super(**options, &block)
         end
 
         private
