@@ -133,10 +133,13 @@ module Gitlab
 
           instrumentation = Instrumentation.new(result_dir: result_dir)
 
+          Gitlab::Database::Migrations::PreparedAsyncDmlOperationsTesting::AsyncOperationsRunner.install!
+
           within_context_for_database(@database) do
             sorted_migrations.each do |migration|
               instrumentation.observe(version: migration.version, name: migration.name, connection: ActiveRecord::Migration.connection) do
                 ActiveRecord::Migrator.new(direction, migration_context.migrations, migration_context.schema_migration, migration_context.internal_metadata, migration.version).run
+                Gitlab::Database::Migrations::PreparedAsyncDmlOperationsTesting::AsyncOperationsRunner.execute!
               end
             end
           end
