@@ -32,16 +32,24 @@ module Gitlab
 
       def link_toml(key, value, type, &url_proc)
         if value.is_a? String
-          link_regex(/^(?<name>#{key})\s*=\s*"#{value}"/, &url_proc)
-        else
-          link_regex(/^\[#{type}\.(?<name>#{key})]/, &url_proc)
+          link_regex(Gitlab::UntrustedRegexp.new(%{^(?<name>#{key})\\s*=\\s*"#{value}"}), &url_proc)
+        elsif value.is_a? Hash
+          # Don't link when using a custom registry
+          return if value['registry']
+
+          # Don't link unless a crates.io version is provided
+          # See https://doc.rust-lang.org/cargo/reference/specifying-dependencies.html#multiple-locations
+          return unless value['version']
+
+          link_regex(Gitlab::UntrustedRegexp.new("^(?<name>#{key})\\s*=\\s*\\{"), &url_proc)
+          link_regex(Gitlab::UntrustedRegexp.new("^\\[#{type}\\.(?<name>#{key})\\]"), &url_proc)
         end
       end
 
       def toml
         @toml ||= begin
-          TomlRB.parse(plain_text)
-        rescue StandardError
+          Gitlab::Utils::TomlParser.safe_parse(plain_text)
+        rescue Gitlab::Utils::TomlParser::ParseError
           nil
         end
       end
