@@ -18,9 +18,6 @@ module Gitlab
       end
 
       def filter_replies!
-        document.xpath('//blockquote').each(&:remove)
-        document.xpath('//table').each(&:remove)
-
         # bogus links with no href are sometimes added by outlook,
         # and can result in Html2Text adding extra square brackets
         # to the text, so we unwrap them here.
@@ -37,7 +34,7 @@ module Gitlab
       end
 
       def filtered_text
-        @filtered_text ||= Html2Text.convert(filtered_html)
+        @filtered_text ||= ::Gitlab::Email::HtmlToMarkdownParser.convert(filtered_html)
       end
     end
   end
