@@ -41,8 +41,13 @@ module Gitlab
         # Add subscriptions here:
 
         store.subscribe ::MergeRequests::UpdateHeadPipelineWorker, to: ::Ci::PipelineCreatedEvent
+        # Currently it is used only for DuoWorkflows::Workflow. DuoWorkflows::Workflow, pipeline can never be in manual.
+        # That's why a constraint on manual is added. In future if this needs to be used at other places where manual
+        # needs to be considered, then remove the if block and just verify that DuoWorkflows::Workflow is working fine.
+        # Mostly it will be fine.
+        store.subscribe ::Ci::Workloads::UpdateWorkloadStatusEventWorker, to: ::Ci::PipelineFinishedEvent,
+          if: ->(event) { event.data[:status] != 'manual' }
         store.subscribe ::Namespaces::UpdateRootStatisticsWorker, to: ::Projects::ProjectDeletedEvent
-        store.subscribe ::Ci::Runners::UpdateProjectRunnersOwnerWorker, to: ::Projects::ProjectDeletedEvent
 
         store.subscribe ::MergeRequests::ProcessAutoMergeFromEventWorker,
           to: ::MergeRequests::AutoMerge::TitleDescriptionUpdateEvent
@@ -59,13 +64,25 @@ module Gitlab
         store.subscribe ::Ci::InitializePipelinesIidSequenceWorker, to: ::Projects::ProjectCreatedEvent
         store.subscribe ::Pages::DeletePagesDeploymentWorker, to: ::Projects::ProjectArchivedEvent
         store.subscribe ::Pages::ResetPagesDefaultDomainRedirectWorker, to: ::Pages::Domains::PagesDomainDeletedEvent
+        store.subscribe ::MergeRequests::ProcessDraftNotePublishedWorker, to: ::MergeRequests::DraftNotePublishedEvent
 
         subscribe_to_member_destroyed_events(store)
+        subscribe_to_namespace_transfered_events(store)
       end
 
       def subscribe_to_member_destroyed_events(store)
         store.subscribe ::WorkItems::UserPreferences::DestroyWorker, to: ::Members::DestroyedEvent
       end
+
+      def subscribe_to_namespace_transfered_events(store)
+        store.subscribe ::WorkItems::ProcessProjectTransferEventsWorker,
+          to: ::Projects::ProjectTransferedEvent,
+          if: ->(event) { ::WorkItems::ProcessProjectTransferEventsWorker.handles_event?(event) }
+
+        store.subscribe ::WorkItems::ProcessGroupTransferEventsWorker,
+          to: ::Groups::GroupTransferedEvent,
+          if: ->(event) { ::WorkItems::ProcessGroupTransferEventsWorker.handles_event?(event) }
+      end
     end
   end
 end
