@@ -3,9 +3,11 @@
 module Gitlab
   module Git
     class ChangedPath
-      attr_reader :status, :path, :old_mode, :new_mode, :new_blob_id, :old_blob_id, :old_path
+      attr_reader :status, :path, :old_mode, :new_mode, :new_blob_id, :old_blob_id, :old_path, :commit_id
 
-      def initialize(status:, path:, old_mode:, new_mode:, new_blob_id: nil, old_blob_id: nil, old_path: nil)
+      def initialize(
+        status:, path:, old_mode:, new_mode:, new_blob_id: nil, old_blob_id: nil, old_path: nil,
+        commit_id: nil)
         @status = status
         @path = path
         @old_mode = old_mode
@@ -13,6 +15,7 @@ module Gitlab
         @old_blob_id = old_blob_id
         @new_blob_id = new_blob_id
         @old_path = old_path.presence || @path
+        @commit_id = commit_id
       end
 
       def new_file?
