@@ -11,15 +11,27 @@ module Gitlab
       include Gitlab::Git::WrapsGitalyErrors
       include Gitlab::EncodingHelper
       include Gitlab::Utils::StrongMemoize
-      prepend Gitlab::Git::RuggedImpl::Repository
 
       SEARCH_CONTEXT_LINES = 3
       REV_LIST_COMMIT_LIMIT = 2_000
       GITALY_INTERNAL_URL = 'ssh://gitaly/internal.git'
       GITLAB_PROJECTS_TIMEOUT = Gitlab.config.gitlab_shell.git_timeout
       EMPTY_REPOSITORY_CHECKSUM = '0000000000000000000000000000000000000000'
+      DEFAULT_LOG_OPTIONS = {
+        limit: 10,
+        offset: 0,
+        path: nil,
+        author: nil,
+        follow: false,
+        skip_merges: false,
+        after: nil,
+        before: nil,
+        all: false,
+        message_regex: nil
+      }.freeze
 
       NoRepository = Class.new(::Gitlab::Git::BaseError)
+      CommitNotFound = Class.new(::Gitlab::Git::BaseError)
       RepositoryExists = Class.new(::Gitlab::Git::BaseError)
       InvalidRepository = Class.new(::Gitlab::Git::BaseError)
       InvalidBlobName = Class.new(::Gitlab::Git::BaseError)
@@ -45,7 +57,10 @@ module Gitlab
       # Relative path of repo
       attr_reader :relative_path
 
-      attr_reader :storage, :gl_repository, :gl_project_path
+      attr_reader :storage, :gl_repository, :gl_project_path, :container
+
+      delegate :list_oversized_blobs, :list_all_blobs, :list_blobs, to: :gitaly_blob_client
+      delegate :repository_info, to: :gitaly_repository_client
 
       # This remote name has to be stable for all types of repositories that
       # can join an object pool. If it's structure ever changes, a migration
@@ -54,13 +69,12 @@ module Gitlab
       # state.
       alias_method :object_pool_remote_name, :gl_repository
 
-      # This initializer method is only used on the client side (gitlab-ce).
-      # Gitaly-ruby uses a different initializer.
-      def initialize(storage, relative_path, gl_repository, gl_project_path)
+      def initialize(storage, relative_path, gl_repository, gl_project_path, container: nil)
         @storage = storage
         @relative_path = relative_path
         @gl_repository = gl_repository
         @gl_project_path = gl_project_path
+        @container = container
 
         @name = @relative_path.split("/").last
       end
@@ -69,6 +83,11 @@ module Gitlab
         "<#{self.class.name}: #{self.gl_project_path}>"
       end
 
+      # Support Feature Flag Repository actor
+      def flipper_id
+        "Repository:#{@relative_path}"
+      end
+
       def ==(other)
         other.is_a?(self.class) && [storage, relative_path] == [other.storage, other.relative_path]
       end
@@ -79,29 +98,20 @@ module Gitlab
         [self.class, storage, relative_path].hash
       end
 
-      # This method will be removed when Gitaly reaches v1.1.
-      def path
-        File.join(
-          Gitlab.config.repositories.storages[@storage].legacy_disk_path, @relative_path
-        )
-      end
-
       # Default branch in the repository
-      def root_ref
-        gitaly_ref_client.default_branch_name
-      rescue GRPC::NotFound => e
-        raise NoRepository, e.message
-      rescue GRPC::Unknown => e
-        raise Gitlab::Git::CommandError, e.message
+      def root_ref(head_only: false)
+        wrapped_gitaly_errors do
+          gitaly_ref_client.default_branch_name(head_only: head_only)
+        end
       end
 
       def exists?
         gitaly_repository_client.exists?
       end
 
-      def create_repository(default_branch = nil)
+      def create_repository(default_branch = nil, object_format: nil)
         wrapped_gitaly_errors do
-          gitaly_repository_client.create_repository(default_branch)
+          gitaly_repository_client.create_repository(default_branch, object_format: object_format)
         rescue GRPC::AlreadyExists => e
           raise RepositoryExists, e.message
         end
@@ -110,9 +120,9 @@ module Gitlab
       # Returns an Array of branch names
       # sorted by name ASC
       def branch_names
-        wrapped_gitaly_errors do
-          gitaly_ref_client.branch_names
-        end
+        refs = list_refs([Gitlab::Git::BRANCH_REF_PREFIX])
+
+        refs.map { |ref| Gitlab::Git.branch_name(ref.name) }
       end
 
       # Returns an Array of Branches
@@ -128,6 +138,10 @@ module Gitlab
         wrapped_gitaly_errors do
           gitaly_ref_client.find_branch(name)
         end
+      rescue Gitlab::Git::AmbiguousRef
+        # Gitaly returns "reference is ambiguous" error in case when users request
+        # branch "my-branch", when another branch "my-branch/branch" exists.
+        # We handle this error here and return nil for this case.
       end
 
       def find_tag(name)
@@ -139,7 +153,7 @@ module Gitlab
         # `CommandError` by the wrapper. This has been converted in v15.3.0 to instead return a structured
         # error with a `tag_not_found` error, so rescuing from `Internal` errors can be removed in v15.4.0 and
         # later.
-      rescue Gitlab::Git::UnknownRef
+      rescue Gitlab::Git::ReferenceNotFoundError
         # This is the new error returned by `find_tag`, which knows to translate the structured error returned
         # by Gitaly when the tag does not exist.
       end
@@ -152,15 +166,7 @@ module Gitlab
 
       # Returns the number of valid branches
       def branch_count
-        wrapped_gitaly_errors do
-          gitaly_ref_client.count_branch_names
-        end
-      end
-
-      def rename(new_relative_path)
-        wrapped_gitaly_errors do
-          gitaly_repository_client.rename(new_relative_path)
-        end
+        branch_names.count
       end
 
       def remove
@@ -171,9 +177,9 @@ module Gitlab
         nil
       end
 
-      def replicate(source_repository)
+      def replicate(source_repository, partition_hint: "")
         wrapped_gitaly_errors do
-          gitaly_repository_client.replicate(source_repository)
+          gitaly_repository_client.replicate(source_repository, partition_hint: partition_hint)
         end
       end
 
@@ -196,16 +202,14 @@ module Gitlab
 
       # Returns the number of valid tags
       def tag_count
-        wrapped_gitaly_errors do
-          gitaly_ref_client.count_tag_names
-        end
+        tag_names.count
       end
 
       # Returns an Array of tag names
       def tag_names
-        wrapped_gitaly_errors do
-          gitaly_ref_client.tag_names
-        end
+        refs = list_refs([Gitlab::Git::TAG_REF_PREFIX])
+
+        refs.map { |ref| Gitlab::Git.tag_name(ref.name) }
       end
 
       # Returns an Array of Tags
@@ -256,7 +260,11 @@ module Gitlab
 
       def archive_metadata(ref, storage_path, project_path, format = "tar.gz", append_sha:, path: nil)
         ref ||= root_ref
-        commit = Gitlab::Git::Commit.find(self, ref)
+
+        commit_id = extract_commit_id_from_ref(ref)
+        return {} if commit_id.nil?
+
+        commit = Gitlab::Git::Commit.find(self, commit_id)
         return {} if commit.nil?
 
         prefix = archive_prefix(ref, commit.id, project_path, append_sha: append_sha, path: path)
@@ -265,13 +273,16 @@ module Gitlab
           'ArchivePrefix' => prefix,
           'ArchivePath' => archive_file_path(storage_path, commit.id, prefix, format),
           'CommitId' => commit.id,
-          'GitalyRepository' => gitaly_repository.to_h
+          'GitalyRepository' => gitaly_repository.to_h,
+          'StoragePath' => storage_path
         }
       end
 
       # This is both the filename of the archive (missing the extension) and the
       # name of the top-level member of the archive under which all files go
       def archive_prefix(ref, sha, project_path, append_sha:, path:)
+        ref = ref.gsub(%r{^refs/(?:heads|tags)/}, '')
+
         append_sha = (ref != sha) if append_sha.nil?
 
         formatted_ref = ref.tr('/', '-')
@@ -327,9 +338,27 @@ module Gitlab
 
       # Return repo size in megabytes
       def size
-        size = gitaly_repository_client.repository_size
+        if Feature.enabled?(:use_repository_info_for_repository_size)
+          repository_info_size_megabytes
+        else
+          kilobytes = gitaly_repository_client.repository_size
+          (kilobytes.to_f / 1024).round(2)
+        end
+      end
 
-        (size.to_f / 1024).round(2)
+      # Return repository recent objects size in mebibytes
+      #
+      # This differs from the #size method in that it does not include the size of:
+      # - stale objects
+      # - cruft packs of unreachable objects
+      #
+      # see: https://gitlab.com/gitlab-org/gitaly/-/blob/257ee33ca268d48c8f99dcbfeaaf7d8b19e07f06/internal/gitaly/service/repository/repository_info.go#L41-62
+      def recent_objects_size
+        wrapped_gitaly_errors do
+          recent_size_in_bytes = gitaly_repository_client.repository_info.objects.recent_size
+
+          Gitlab::Utils.bytes_to_megabytes(recent_size_in_bytes)
+        end
       end
 
       # Return git object directory size in bytes
@@ -345,31 +374,26 @@ module Gitlab
       #     path: 'app/models',
       #     limit: 10,
       #     offset: 5,
-      #     after: Time.new(2016, 4, 21, 14, 32, 10)
+      #     after: Time.new(2016, 4, 21, 14, 32, 10),
+      #     message_regex: 'project'
       #   )
       def log(options)
-        default_options = {
-          limit: 10,
-          offset: 0,
-          path: nil,
-          author: nil,
-          follow: false,
-          skip_merges: false,
-          after: nil,
-          before: nil,
-          all: false
-        }
+        raise ArgumentError, 'Invalid message_regex pattern' unless valid_message_regex?(options[:message_regex])
 
-        options = default_options.merge(options)
-        options[:offset] ||= 0
+        options = DEFAULT_LOG_OPTIONS.merge(options)
 
         limit = options[:limit]
         if limit == 0 || !limit.is_a?(Integer)
           raise ArgumentError, "invalid Repository#log limit: #{limit.inspect}"
         end
 
-        wrapped_gitaly_errors do
-          gitaly_commit_client.find_commits(options)
+        # call Gitaly client to fetch commits, if a NotFound happens we return an empty array
+        begin
+          wrapped_gitaly_errors do
+            gitaly_commit_client.find_commits(options)
+          end
+        rescue Gitlab::Git::Repository::CommitNotFound
+          []
         end
       end
 
@@ -379,17 +403,24 @@ module Gitlab
         end
       end
 
+      def check_objects_exist(refs)
+        wrapped_gitaly_errors do
+          gitaly_commit_client.object_existence_map(Array.wrap(refs))
+        end
+      end
+
       def new_blobs(newrevs, dynamic_timeout: nil)
-        newrevs = Array.wrap(newrevs).reject { |rev| rev.blank? || rev == ::Gitlab::Git::BLANK_SHA }
+        newrevs = Array.wrap(newrevs).reject { |rev| rev.blank? || Gitlab::Git.blank_ref?(rev) }
         return [] if newrevs.empty?
 
         newrevs = newrevs.uniq.sort
 
-        @new_blobs ||= Hash.new do |h, revs|
-          h[revs] = blobs(['--not', '--all', '--not'] + newrevs, with_paths: true, dynamic_timeout: dynamic_timeout)
-        end
-
-        @new_blobs[newrevs]
+        @new_blobs ||= {}
+        @new_blobs[newrevs] ||= blobs(
+          ['--not', '--all', '--not'] + newrevs,
+          with_paths: true,
+          dynamic_timeout: dynamic_timeout
+        ).to_a
       end
 
       # List blobs reachable via a set of revisions. Supports the
@@ -397,13 +428,13 @@ module Gitlab
       # GitalyClient.medium_timeout and dynamic timeout if the dynamic
       # timeout is set, otherwise it'll always use the medium timeout.
       def blobs(revisions, with_paths: false, dynamic_timeout: nil)
-        revisions = revisions.reject { |rev| rev.blank? || rev == ::Gitlab::Git::BLANK_SHA }
+        revisions = revisions.reject { |rev| rev.blank? || Gitlab::Git.blank_ref?(rev) }
 
         return [] if revisions.blank?
 
         wrapped_gitaly_errors do
           gitaly_blob_client.list_blobs(revisions, limit: REV_LIST_COMMIT_LIMIT,
-                                                   with_paths: with_paths, dynamic_timeout: dynamic_timeout)
+            with_paths: with_paths, dynamic_timeout: dynamic_timeout)
         end
       end
 
@@ -437,25 +468,22 @@ module Gitlab
       def raw_changes_between(old_rev, new_rev)
         @raw_changes_between ||= {}
 
-        @raw_changes_between[[old_rev, new_rev]] ||=
-          begin
-            return [] if new_rev.blank? || new_rev == Gitlab::Git::BLANK_SHA
+        return [] if new_rev.blank? || Gitlab::Git.blank_ref?(new_rev)
 
-            wrapped_gitaly_errors do
-              gitaly_repository_client.raw_changes_between(old_rev, new_rev)
-                .each_with_object([]) do |msg, arr|
-                msg.raw_changes.each { |change| arr << ::Gitlab::Git::RawDiffChange.new(change) }
-              end
-            end
+        @raw_changes_between[[old_rev, new_rev]] ||= wrapped_gitaly_errors do
+          gitaly_repository_client.raw_changes_between(old_rev, new_rev)
+            .each_with_object([]) do |msg, arr|
+            msg.raw_changes.each { |change| arr << ::Gitlab::Git::RawDiffChange.new(change) }
           end
+        end
       rescue ArgumentError => e
         raise Gitlab::Git::Repository::GitError, e
       end
 
       # Returns the SHA of the most recent common ancestor of +from+ and +to+
-      def merge_base(*commits)
+      def merge_base(...)
         wrapped_gitaly_errors do
-          gitaly_repository_client.find_merge_base(*commits)
+          gitaly_repository_client.find_merge_base(...)
         end
       end
 
@@ -464,18 +492,36 @@ module Gitlab
         gitaly_commit_client.ancestor?(from, to)
       end
 
-      def merged_branch_names(branch_names = [])
+      def merged_branch_names(branch_names = [], include_identical: false)
         return [] unless root_ref
 
-        root_sha = find_branch(root_ref)&.target
+        root_branch = find_branch(root_ref)
+        return [] unless root_branch
 
-        return [] unless root_sha
+        root_sha = root_branch.target
+        root_branch_name = root_branch.name
 
-        branches = wrapped_gitaly_errors do
-          gitaly_merged_branch_names(branch_names, root_sha)
+        wrapped_gitaly_errors do
+          Set.new(gitaly_merged_branch_names(branch_names, root_sha, root_branch_name, include_identical: include_identical))
         end
+      end
 
-        Set.new(branches)
+      # Returns an array of DiffBlob objects that represent a diff between
+      # two blobs in a repository. For each diff generated, the pre-image and
+      # post-image blob IDs should be obtained using `find_changed_paths` method.
+      def diff_blobs(...)
+        wrapped_gitaly_errors do
+          gitaly_diff_client.diff_blobs(...)
+        end
+      end
+
+      # Returns an array of DiffBlob objects that represent diffs between
+      # pairs of blobs in a repository using raw changed path information.
+      # More efficient for large batches of files compared to diff_blobs.
+      def diff_blobs_with_raw_info(...)
+        wrapped_gitaly_errors do
+          gitaly_diff_client.diff_blobs_with_raw_info(...)
+        end
       end
 
       # Return an array of Diff objects that represent the diff
@@ -502,13 +548,13 @@ module Gitlab
         empty_diff_stats
       end
 
-      def find_changed_paths(commits)
-        processed_commits = commits.reject { |ref| ref.blank? || Gitlab::Git.blank_ref?(ref) }
+      def find_changed_paths(treeish_objects, merge_commit_diff_mode: nil, find_renames: false, diff_filters: nil)
+        processed_objects = treeish_objects.compact
 
-        return [] if processed_commits.empty?
+        return [] if processed_objects.empty?
 
         wrapped_gitaly_errors do
-          gitaly_commit_client.find_changed_paths(processed_commits)
+          gitaly_commit_client.find_changed_paths(processed_objects, merge_commit_diff_mode: merge_commit_diff_mode, find_renames: find_renames, diff_filters: diff_filters)
         end
       rescue CommandError, TypeError, NoRepository
         []
@@ -534,12 +580,12 @@ module Gitlab
       # Returns matching refs for OID
       #
       # Limit of 0 means there is no limit.
-      def refs_by_oid(oid:, limit: 0)
+      def refs_by_oid(oid:, limit: 0, ref_patterns: nil)
         wrapped_gitaly_errors do
-          gitaly_ref_client.find_refs_by_oid(oid: oid, limit: limit)
+          gitaly_ref_client.find_refs_by_oid(oid: oid, limit: limit, ref_patterns: ref_patterns) || []
         end
       rescue CommandError, TypeError, NoRepository
-        nil
+        []
       end
 
       # Returns url for submodule
@@ -604,9 +650,9 @@ module Gitlab
         # TODO: implement this method
       end
 
-      def add_branch(branch_name, user:, target:)
+      def add_branch(branch_name, user:, target:, skip_ci: false)
         wrapped_gitaly_errors do
-          gitaly_operation_client.user_create_branch(branch_name, user, target)
+          gitaly_operation_client.user_create_branch(branch_name, user, target, skip_ci: skip_ci)
         end
       end
 
@@ -622,9 +668,9 @@ module Gitlab
         end
       end
 
-      def rm_branch(branch_name, user:)
+      def rm_branch(branch_name, user:, target_sha: nil)
         wrapped_gitaly_errors do
-          gitaly_operation_client.user_delete_branch(branch_name, user)
+          gitaly_operation_client.user_delete_branch(branch_name, user, target_sha: target_sha)
         end
       end
 
@@ -640,19 +686,27 @@ module Gitlab
         end
       end
 
-      def merge(user, source_sha, target_branch, message, &block)
+      def merge(user, source_sha:, target_branch:, message:, target_sha: nil, &block)
         wrapped_gitaly_errors do
-          gitaly_operation_client.user_merge_branch(user, source_sha, target_branch, message, &block)
+          gitaly_operation_client.user_merge_branch(user,
+            source_sha: source_sha,
+            target_branch: target_branch,
+            message: message,
+            target_sha: target_sha,
+            &block)
         end
       end
 
-      def ff_merge(user, source_sha, target_branch)
+      def ff_merge(user, source_sha:, target_branch:, target_sha: nil)
         wrapped_gitaly_errors do
-          gitaly_operation_client.user_ff_branch(user, source_sha, target_branch)
+          gitaly_operation_client.user_ff_branch(user,
+            source_sha: source_sha,
+            target_branch: target_branch,
+            target_sha: target_sha)
         end
       end
 
-      def revert(user:, commit:, branch_name:, message:, start_branch_name:, start_repository:, dry_run: false)
+      def revert(user:, commit:, branch_name:, message:, start_branch_name:, start_repository:, dry_run: false, target_sha: nil)
         args = {
           user: user,
           commit: commit,
@@ -660,7 +714,8 @@ module Gitlab
           message: message,
           start_branch_name: start_branch_name,
           start_repository: start_repository,
-          dry_run: dry_run
+          dry_run: dry_run,
+          target_sha: target_sha
         }
 
         wrapped_gitaly_errors do
@@ -668,19 +723,9 @@ module Gitlab
         end
       end
 
-      def cherry_pick(user:, commit:, branch_name:, message:, start_branch_name:, start_repository:, dry_run: false)
-        args = {
-          user: user,
-          commit: commit,
-          branch_name: branch_name,
-          message: message,
-          start_branch_name: start_branch_name,
-          start_repository: start_repository,
-          dry_run: dry_run
-        }
-
+      def cherry_pick(...)
         wrapped_gitaly_errors do
-          gitaly_operation_client.user_cherry_pick(**args)
+          gitaly_operation_client.user_cherry_pick(...)
         end
       end
 
@@ -708,9 +753,33 @@ module Gitlab
         raise DeleteBranchError, e
       end
 
-      def delete_refs(*ref_names)
+      def async_delete_refs(*refs)
+        raise "async_delete_refs only supports project repositories" unless container.is_a?(Project)
+
+        records = refs.map do |ref|
+          BatchedGitRefUpdates::Deletion.new(project_id: container.id, ref: ref, created_at: Time.current, updated_at: Time.current)
+        end
+
+        BatchedGitRefUpdates::Deletion.bulk_insert!(records)
+      end
+
+      # Update a list of references from X -> Y
+      #
+      # Ref list is expected to be an array of hashes in the form:
+      # old_sha:
+      # new_sha
+      # reference:
+      #
+      # When new_sha is Gitlab::Git::SHA1_BLANK_SHA, then this will be deleted
+      def update_refs(ref_list)
         wrapped_gitaly_errors do
-          gitaly_delete_refs(*ref_names)
+          gitaly_ref_client.update_refs(ref_list: ref_list) if ref_list.any?
+        end
+      end
+
+      def delete_refs(...)
+        wrapped_gitaly_errors do
+          gitaly_delete_refs(...)
         end
       end
 
@@ -741,12 +810,6 @@ module Gitlab
         gitaly_commit_client.ls_files(ref)
       end
 
-      def copy_gitattributes(ref)
-        wrapped_gitaly_errors do
-          gitaly_repository_client.apply_gitattributes(ref)
-        end
-      end
-
       def info_attributes
         return @info_attributes if @info_attributes
 
@@ -783,27 +846,17 @@ module Gitlab
         end
       end
 
-      def license(from_gitaly)
+      def license
         wrapped_gitaly_errors do
           response = gitaly_repository_client.find_license
 
           break nil if response.license_short_name.empty?
 
-          if from_gitaly
-            break ::Gitlab::Git::DeclaredLicense.new(key: response.license_short_name,
-                                                     name: response.license_name,
-                                                     nickname: response.license_nickname.presence,
-                                                     url: response.license_url.presence,
-                                                     path: response.license_path)
-          end
-
-          licensee_object = Licensee::License.new(response.license_short_name)
-
-          break nil if licensee_object.name.blank?
-
-          licensee_object.meta.nickname = "LICENSE" if licensee_object.key == "other"
-
-          licensee_object
+          ::Gitlab::Git::DeclaredLicense.new(key: response.license_short_name,
+            name: response.license_name,
+            nickname: response.license_nickname.presence,
+            url: response.license_url.presence,
+            path: response.license_path)
         end
       rescue Licensee::InvalidLicense => e
         Gitlab::ErrorTracking.track_exception(e)
@@ -817,9 +870,14 @@ module Gitlab
       end
 
       def compare_source_branch(target_branch_name, source_repository, source_branch_name, straight:)
-        CrossRepoComparer
-          .new(source_repository, self)
-          .compare(source_branch_name, target_branch_name, straight: straight)
+        CrossRepo.new(source_repository, self).execute(target_branch_name) do |target_commit_id|
+          Gitlab::Git::Compare.new(
+            source_repository,
+            target_commit_id,
+            source_branch_name,
+            straight: straight
+          )
+        end
       end
 
       def write_ref(ref_path, ref, old_ref: nil)
@@ -830,9 +888,10 @@ module Gitlab
         end
       end
 
-      def list_refs(patterns = [Gitlab::Git::BRANCH_REF_PREFIX])
+      # peel_tags slows down the request by a factor of 3-4
+      def list_refs(...)
         wrapped_gitaly_errors do
-          gitaly_ref_client.list_refs(patterns)
+          gitaly_ref_client.list_refs(...)
         end
       end
 
@@ -854,8 +913,11 @@ module Gitlab
       # forced - should we use --force flag?
       # no_tags - should we use --no-tags flag?
       # prune - should we use --prune flag?
-      # check_tags_changed - should we ask gitaly to calculate whether any tags changed?
-      def fetch_remote(url, refmap: nil, ssh_auth: nil, forced: false, no_tags: false, prune: true, check_tags_changed: false, http_authorization_header: "")
+      # resolved_address - resolved IP address for provided URL
+      def fetch_remote(
+        url,
+        refmap: nil, ssh_auth: nil, forced: false, no_tags: false, prune: true,
+        http_authorization_header: "", resolved_address: "")
         wrapped_gitaly_errors do
           gitaly_repository_client.fetch_remote(
             url,
@@ -864,18 +926,18 @@ module Gitlab
             forced: forced,
             no_tags: no_tags,
             prune: prune,
-            check_tags_changed: check_tags_changed,
             timeout: GITLAB_PROJECTS_TIMEOUT,
-            http_authorization_header: http_authorization_header
+            http_authorization_header: http_authorization_header,
+            resolved_address: resolved_address
           )
         end
       end
 
-      def import_repository(url, http_authorization_header: '', mirror: false)
+      def import_repository(url, http_authorization_header: '', mirror: false, resolved_address: '')
         raise ArgumentError, "don't use disk paths with import_repository: #{url.inspect}" if url.start_with?('.', '/')
 
         wrapped_gitaly_errors do
-          gitaly_repository_client.import_repository(url, http_authorization_header: http_authorization_header, mirror: mirror)
+          gitaly_repository_client.import_repository(url, http_authorization_header: http_authorization_header, mirror: mirror, resolved_address: resolved_address)
         end
       end
 
@@ -903,10 +965,6 @@ module Gitlab
         gitaly_repository_client.create_from_bundle(bundle_path)
       end
 
-      def create_from_snapshot(url, auth)
-        gitaly_repository_client.create_from_snapshot(url, auth)
-      end
-
       def rebase(user, rebase_id, branch:, branch_sha:, remote_repository:, remote_branch:, push_options: [], &block)
         wrapped_gitaly_errors do
           gitaly_operation_client.rebase(
@@ -922,6 +980,18 @@ module Gitlab
         end
       end
 
+      def rebase_to_ref(user, source_sha:, target_ref:, first_parent_ref:, expected_old_oid: "")
+        wrapped_gitaly_errors do
+          gitaly_operation_client.user_rebase_to_ref(
+            user,
+            source_sha: source_sha,
+            target_ref: target_ref,
+            first_parent_ref: first_parent_ref,
+            expected_old_oid: expected_old_oid
+          )
+        end
+      end
+
       def squash(user, start_sha:, end_sha:, author:, message:)
         wrapped_gitaly_errors do
           gitaly_operation_client.user_squash(user, start_sha, end_sha, author, message)
@@ -955,6 +1025,7 @@ module Gitlab
       # @param [String] start_sha: The sha to be used as the parent of the commit.
       # @param [Gitlab::Git::Repository] start_repository: The repository that contains the start branch or sha. Defaults to use this repository.
       # @param [Boolean] force: Force update the branch.
+      # @param [String] target_sha: The latest sha of the target branch (optional). Used to prevent races in updates between different clients.
       # @return [Gitlab::Git::OperationService::BranchUpdate]
       #
       # rubocop:disable Metrics/ParameterLists
@@ -962,31 +1033,16 @@ module Gitlab
         user, branch_name:, message:, actions:,
         author_email: nil, author_name: nil,
         start_branch_name: nil, start_sha: nil, start_repository: nil,
-        force: false)
-
+        force: false, sign: true, target_sha: nil
+      )
         wrapped_gitaly_errors do
           gitaly_operation_client.user_commit_files(user, branch_name,
-              message, actions, author_email, author_name,
-              start_branch_name, start_repository, force, start_sha)
+            message, actions, author_email, author_name, start_branch_name,
+            start_repository, force, start_sha, sign, target_sha)
         end
       end
       # rubocop:enable Metrics/ParameterLists
 
-      def set_full_path(full_path:)
-        return unless full_path.present?
-
-        # This guard avoids Gitaly log/error spam
-        raise NoRepository, 'repository does not exist' unless exists?
-
-        gitaly_repository_client.set_full_path(full_path)
-      end
-
-      def full_path
-        wrapped_gitaly_errors do
-          gitaly_repository_client.full_path
-        end
-      end
-
       def disconnect_alternates
         wrapped_gitaly_errors do
           gitaly_repository_client.disconnect_alternates
@@ -1021,6 +1077,10 @@ module Gitlab
         @gitaly_blob_client ||= Gitlab::GitalyClient::BlobService.new(self)
       end
 
+      def gitaly_diff_client
+        @gitaly_diff_client ||= Gitlab::GitalyClient::DiffService.new(self)
+      end
+
       def gitaly_conflicts_client(our_commit_oid, their_commit_oid)
         Gitlab::GitalyClient::ConflictsService.new(self, our_commit_oid, their_commit_oid)
       end
@@ -1029,6 +1089,10 @@ module Gitlab
         @praefect_info_client ||= Gitlab::GitalyClient::PraefectInfoService.new(self)
       end
 
+      def gitaly_analysis_client
+        @gitaly_analysis_client ||= Gitlab::GitalyClient::AnalysisService.new(self)
+      end
+
       def branch_names_contains_sha(sha, limit: 0)
         gitaly_ref_client.branch_names_contains_sha(sha, limit: limit)
       end
@@ -1054,46 +1118,52 @@ module Gitlab
         end
       end
 
-      def search_files_by_name(query, ref)
+      def search_files_by_name(query, ref, limit: 0, offset: 0)
         safe_query = query.sub(%r{^/*}, "")
         ref ||= root_ref
 
         return [] if empty? || safe_query.blank?
 
-        gitaly_repository_client.search_files_by_name(ref, safe_query).map do |file|
+        gitaly_repository_client.search_files_by_name(ref, safe_query, limit: limit, offset: offset).map do |file|
           Gitlab::EncodingHelper.encode_utf8(file)
         end
       end
 
-      def search_files_by_regexp(filter, ref = 'HEAD')
-        gitaly_repository_client.search_files_by_regexp(ref, filter).map do |file|
+      def search_files_by_regexp(filter, ref = 'HEAD', limit: 0, offset: 0)
+        gitaly_repository_client.search_files_by_regexp(ref, filter, limit: limit, offset: offset).map do |file|
           Gitlab::EncodingHelper.encode_utf8(file)
         end
+      rescue GRPC::NotFound
+        raise NoRepository
       end
 
       def find_commits_by_message(query, ref, path, limit, offset)
         wrapped_gitaly_errors do
-          gitaly_commit_client
-            .commits_by_message(query, revision: ref, path: path, limit: limit, offset: offset)
-            .map { |c| commit(c) }
+          gitaly_commit_client.commits_by_message(query, revision: ref, path: path, limit: limit, offset: offset)
         end
       end
 
-      def list_commits_by(query, ref, author: nil, before: nil, after: nil, limit: 1000)
-        params = {
-          author: author,
-          ignore_case: true,
-          commit_message_patterns: query,
-          before: before,
-          after: after,
-          reverse: false,
-          pagination_params: { limit: limit }
-        }
+      def list_commits(
+        ref:,
+        query: nil,
+        author: nil,
+        committed_before: nil,
+        committed_after: nil,
+        pagination_params: { page_token: nil, limit: 1000 }
+      )
+        pagination_params[:limit] ||= 1000
 
         wrapped_gitaly_errors do
-          gitaly_commit_client
-            .list_commits([ref], params)
-            .map { |c| commit(c) }
+          gitaly_commit_client.list_commits(
+            [ref],
+            author: author,
+            ignore_case: true,
+            commit_message_patterns: query,
+            before: committed_before,
+            after: committed_after,
+            reverse: false,
+            pagination_params: pagination_params
+          )
         end
       end
 
@@ -1117,7 +1187,7 @@ module Gitlab
 
       def checksum
         # The exists? RPC is much cheaper, so we perform this request first
-        raise NoRepository, "Repository does not exists" unless exists?
+        raise NoRepository, "Repository does not exist" unless exists?
 
         gitaly_repository_client.calculate_checksum
       rescue GRPC::NotFound
@@ -1130,8 +1200,104 @@ module Gitlab
         end
       end
 
+      def get_patch_id(old_revision, new_revision)
+        wrapped_gitaly_errors do
+          gitaly_commit_client.get_patch_id(old_revision, new_revision)
+        end
+      end
+
+      def object_pool
+        wrapped_gitaly_errors do
+          gitaly_repository_client.object_pool.object_pool
+        end
+      end
+
+      # Note: this problem should be addressed in https://gitlab.com/gitlab-org/gitlab/-/issues/441770
+      # Gitlab::Git::Repository shouldn't call Repository directly
+      # Instead empty_tree_id value should be passed to Gitaly client
+      # via method arguments
+      def empty_tree_id
+        container.repository.empty_tree_id
+      end
+
+      def object_format
+        wrapped_gitaly_errors do
+          gitaly_repository_client.object_format.format
+        end
+      end
+
+      def get_file_attributes(revision, file_paths, attributes)
+        wrapped_gitaly_errors do
+          gitaly_repository_client
+            .get_file_attributes(revision, file_paths, attributes)
+            .attribute_infos
+            .map(&:to_h)
+        end
+      end
+
+      # rubocop: disable CodeReuse/ActiveRecord -- not an active record operation
+      def detect_generated_files(base, head, changed_paths)
+        return Set.new if changed_paths.blank?
+
+        # We only display diffs upto the diff_max_files size so we can avoid
+        # checking the rest if it exceeds the limit.
+        changed_paths = changed_paths.take(Gitlab::CurrentSettings.diff_max_files)
+
+        # Check .gitattributes overrides first
+        checked_files = get_file_attributes(
+          base,
+          changed_paths.map(&:path),
+          Gitlab::Git::ATTRIBUTE_OVERRIDES[:generated]
+        ).map { |attrs| { path: attrs[:path], generated: attrs[:value] == "set" } }
+
+        # Check automatic generated file detection for the remaining paths
+        overridden_paths = checked_files.pluck(:path)
+        remainder = changed_paths.reject { |changed_path| overridden_paths.include?(changed_path.path) }
+        checked_files += check_blobs_generated(base, head, remainder) if remainder.present?
+
+        checked_files
+          .select { |attrs| attrs[:generated] }
+          .pluck(:path)
+          .to_set
+
+      rescue Gitlab::Git::CommandError, Gitlab::Git::ResourceExhaustedError => e
+        # An exception can be raised due to an unknown revision or paths.
+        # Gitlab::Git::ResourceExhaustedError could be raised if the request payload is too large.
+        Gitlab::ErrorTracking.track_exception(
+          e,
+          gl_project_path: @gl_project_path,
+          base: base,
+          head: head,
+          paths_count: changed_paths.count,
+          paths_bytesize: changed_paths.map(&:path).join.bytesize
+        )
+
+        Set.new
+      end
+      # rubocop: enable CodeReuse/ActiveRecord
+
       private
 
+      def valid_message_regex?(pattern)
+        return true unless pattern
+
+        !!Gitlab::UntrustedRegexp.new(pattern)
+      rescue RegexpError
+        false
+      end
+
+      def check_blobs_generated(base, head, changed_paths)
+        wrapped_gitaly_errors do
+          gitaly_analysis_client.check_blobs_generated(base, head, changed_paths)
+        end
+      end
+
+      def repository_info_size_megabytes
+        bytes = repository_info.size
+
+        Gitlab::Utils.bytes_to_megabytes(bytes).round(2)
+      end
+
       def empty_diff_stats
         Gitlab::Git::DiffStatsCollection.new([])
       end
@@ -1142,12 +1308,13 @@ module Gitlab
         end
       end
 
-      def gitaly_merged_branch_names(branch_names, root_sha)
+      def gitaly_merged_branch_names(branch_names, root_sha, root_branch_name, include_identical: false)
         qualified_branch_names = branch_names.map { |b| "refs/heads/#{b}" }
+        merged_branches = gitaly_ref_client.merged_branches(qualified_branch_names)
 
-        gitaly_ref_client.merged_branches(qualified_branch_names)
-          .reject { |b| b.target == root_sha }
-          .map(&:name)
+        return merged_branches.reject { |b| b.name == root_branch_name }.map(&:name) if include_identical
+
+        merged_branches.reject { |b| b.target == root_sha }.map(&:name)
       end
 
       def process_count_commits_options(options)
@@ -1195,13 +1362,29 @@ module Gitlab
         gitaly_ref_client.ref_exists?(ref_name)
       end
 
-      def gitaly_copy_gitattributes(revision)
-        gitaly_repository_client.apply_gitattributes(revision)
-      end
-
       def gitaly_delete_refs(*ref_names)
         gitaly_ref_client.delete_refs(refs: ref_names) if ref_names.any?
       end
+
+      # The order is based on git priority to resolve ambiguous references
+      #
+      # `git show <ref>`
+      #
+      # In case of name clashes, it uses this order:
+      # 1. Commit
+      # 2. Tag
+      # 3. Branch
+      def extract_commit_id_from_ref(ref)
+        return ref if Gitlab::Git.commit_id?(ref)
+
+        tag = find_tag(ref)
+        return tag.dereferenced_target.sha if tag
+
+        branch = find_branch(ref)
+        return branch.dereferenced_target.sha if branch
+
+        ref
+      end
     end
   end
 end
