@@ -43,6 +43,10 @@ module Gitlab
       end
     end
 
+    def self.with_context(...)
+      GitalyContext.with_context(...)
+    end
+
     def self.interceptors
       return [] unless Labkit::Tracing.enabled?
 
@@ -332,6 +336,8 @@ module Gitlab
 
       relative_path = fetch_relative_path
 
+      gitaly_context = GitalyContext.current_context.merge(gitaly_context)
+
       ::Gitlab::Auth::Identity.currently_linked do |identity|
         gitaly_context['scoped-user-id'] = identity.scoped_user.id.to_s
       end
@@ -346,6 +352,7 @@ module Gitlab
       metadata['gitaly-session-id'] = session_id
       metadata['username'] = context_data['meta.user'] if context_data&.fetch('meta.user', nil)
       metadata['user_id'] = context_data['meta.user_id'].to_s if context_data&.fetch('meta.user_id', nil)
+      metadata[Labkit::Fields::GL_USER_ID] = context_data['meta.gl_user_id'].to_s if context_data&.fetch('meta.gl_user_id', nil)
       metadata['remote_ip'] = context_data['meta.remote_ip'] if context_data&.fetch('meta.remote_ip', nil)
       metadata['relative-path-bin'] = relative_path if relative_path
       metadata['gitaly-client-context-bin'] = gitaly_context.to_json if gitaly_context.present?
