@@ -27,8 +27,6 @@ module Gitlab
 
           return if target_id.blank?
 
-          skip_invalid_records = Feature.enabled?(:validate_label_link_parent_presence_on_import, :instance)
-
           issue.label_names.each do |label_name|
             # Although unlikely it's technically possible for an issue to be
             # given a label that was created and assigned after we imported all
@@ -43,7 +41,7 @@ module Gitlab
               updated_at: time
             )
             begin
-              label_link.validate! if skip_invalid_records
+              label_link.validate!
             rescue ActiveRecord::RecordInvalid => e
               track_error(e, label_link)
               next
@@ -52,7 +50,7 @@ module Gitlab
             items << label_link
           end
 
-          LabelLink.bulk_insert!(items, validate: !skip_invalid_records)
+          LabelLink.bulk_insert!(items, validate: false)
         end
 
         def find_target_id
