@@ -13,7 +13,10 @@ module Gitlab
         # rubocop: enable CodeReuse/ActiveRecord
 
         def execute
-          bulk_insert(Label, build_labels)
+          rows, validation_errors = build_labels
+
+          bulk_insert(rows)
+          bulk_insert_failures(validation_errors) if validation_errors.any?
           build_labels_cache
         end
 
@@ -29,7 +32,7 @@ module Gitlab
           LabelFinder.new(project).build_cache
         end
 
-        def build(label)
+        def build_attributes(label)
           time = Time.zone.now
 
           {
@@ -49,6 +52,19 @@ module Gitlab
         def object_type
           :label
         end
+
+        private
+
+        def model
+          Label
+        end
+
+        def github_identifiers(label)
+          {
+            title: label[:name],
+            object_type: object_type
+          }
+        end
       end
     end
   end
