@@ -6,6 +6,8 @@ module Gitlab
       class LfsObjectsImporter
         include ParallelScheduling
 
+        RETRY_DELAY = 120
+
         def importer_class
           LfsObjectImporter
         end
@@ -27,13 +29,21 @@ module Gitlab
         end
 
         def each_object_to_import
-          lfs_objects = Projects::LfsPointers::LfsObjectDownloadListService.new(project).execute
+          download_service = Projects::LfsPointers::LfsObjectDownloadListService.new(project)
+
+          download_service.each_list_item do |object|
+            next if already_imported?(object)
 
-          lfs_objects.each do |object|
             Gitlab::GithubImport::ObjectCounter.increment(project, object_type, :fetched)
 
             yield object
+
+            mark_as_imported(object)
           end
+        rescue Projects::LfsPointers::LfsObjectDownloadListService::LfsObjectDownloadListError => e
+          raise e unless e.message.include?('TooManyRequests')
+
+          raise Gitlab::GithubImport::RateLimitError.new('Rate Limit exceeded', RETRY_DELAY)
         rescue StandardError => e
           Gitlab::Import::ImportFailureService.track(
             project_id: project.id,
@@ -41,6 +51,10 @@ module Gitlab
             exception: e
           )
         end
+
+        def id_for_already_imported_cache(object)
+          object.oid
+        end
       end
     end
   end
