@@ -72,6 +72,12 @@ module Gitlab
           )
         end
 
+        def diff_hunk
+          return @attributes[:diff_hunk] if @attributes[:diff_hunk].present?
+
+          @attributes[:diff_hunk] = generate_default_diff_hunk
+        end
+
         def noteable_type
           DiffNotes::DiscussionId::NOTEABLE_TYPE
         end
@@ -93,6 +99,7 @@ module Gitlab
           return Gitlab::Git.diff_line_code(file_path, 1, 1) if on_file?
 
           diff_line = Gitlab::Diff::Parser.new.parse(diff_hunk.lines).to_a.last
+
           Gitlab::Git.diff_line_code(file_path, diff_line.new_pos, diff_line.old_pos)
         end
 
@@ -134,6 +141,22 @@ module Gitlab
 
         private
 
+        def generate_default_diff_hunk
+          line_number = @attributes[:end_line] || @attributes[:line] || 1
+          "@@ -#{line_number},1 +#{line_number},1 @@\n#{fetch_file_line_content(line_number)}"
+        end
+
+        def fetch_file_line_content(line_number)
+          return 'context not found' unless merge_request&.project&.repository
+
+          @file_lines ||= begin
+            blob = merge_request.project.repository.blob_at(@attributes[:original_commit_id], @attributes[:file_path])
+            blob&.data&.lines || []
+          end
+
+          @file_lines[line_number - 1]&.chomp || 'context not found'
+        end
+
         def diff_line_params
           if addition?
             { new_line: end_line, old_line: nil }
