@@ -8,6 +8,8 @@ module Gitlab
       ResourceNotAvailable = Class.new(BaseError)
       MutationError = Class.new(BaseError)
       LimitError = Class.new(BaseError)
+      InvalidMembersError = Class.new(StandardError)
+      InvalidMemberCountError = Class.new(StandardError)
     end
   end
 end
