@@ -9,7 +9,7 @@ module Gitlab
 
         IMPORTED_OBJECT_MAX_RETRIES = 5
 
-        OVERRIDES = { user_contributions: :user, merge_schedule: 'MergeRequests::MergeSchedule' }.freeze
+        OVERRIDES = { user_contributions: :user, merge_schedule: 'MergeRequests::MergeSchedule', merge_data: 'MergeRequests::MergeData' }.freeze
         EXISTING_OBJECT_RELATIONS = %i[].freeze
 
         # This represents all relations that have unique key on `project_id` or `group_id`
@@ -169,9 +169,9 @@ module Gitlab
         end
 
         def remove_encrypted_attributes!
-          return unless relation_class.respond_to?(:attr_encrypted_attributes) && relation_class.attr_encrypted_attributes.any?
+          return unless relation_class.respond_to?(:attr_encrypted_encrypted_attributes) && relation_class.attr_encrypted_encrypted_attributes.any?
 
-          relation_class.attr_encrypted_attributes.each_key do |key|
+          relation_class.attr_encrypted_encrypted_attributes.each_key do |key|
             @relation_hash[key.to_s] = nil
           end
         end
