@@ -4,6 +4,7 @@ module Gitlab
   module ImportExport
     class RepoRestorer
       include Gitlab::ImportExport::CommandLineUtil
+      include ::Import::Framework::ProgressTracking
 
       attr_reader :importable
 
@@ -16,12 +17,14 @@ module Gitlab
       def restore
         return true unless File.exist?(path_to_bundle)
 
-        ensure_repository_does_not_exist!
+        with_progress_tracking(**progress_tracking_options) do
+          ensure_repository_does_not_exist!
 
-        repository.create_from_bundle(path_to_bundle)
-        update_importable_repository_info
+          repository.create_from_bundle(path_to_bundle)
+          update_importable_repository_info
 
-        true
+          true
+        end
       rescue StandardError => e
         shared.error(e)
         false
@@ -42,12 +45,30 @@ module Gitlab
       def ensure_repository_does_not_exist!
         if repository.exists?
           shared.logger.info(
-            message: %Q{Deleting existing "#{repository.disk_path}" to re-import it.}
+            message: %(Deleting existing "#{repository.disk_path}" to re-import it.)
           )
 
-          Repositories::DestroyService.new(repository).execute
+          ::Repositories::DestroyService.new(repository).execute
+
+          # Because Gitlab::Git::Repository#remove happens inside a run_after_commit
+          # callback in the ::Repositories::DestroyService#execute we need to trigger
+          # the callback.
+          repository.project.touch
         end
       end
+
+      def progress_tracking_options
+        {
+          scope: {
+            "#{importable.class.name.downcase}_id" => importable.id
+          },
+          data: basename
+        }
+      end
+
+      def basename
+        File.basename(path_to_bundle)
+      end
     end
   end
 end
