@@ -4,6 +4,7 @@ module Gitlab
   module ManifestImport
     class Metadata
       EXPIRY_TIME = 1.week
+      KEY_PREFIX = 'manifest_import:metadata:user'
 
       attr_reader :user, :fallback
 
@@ -15,8 +16,8 @@ module Gitlab
       def save(repositories, group_id)
         Gitlab::Redis::SharedState.with do |redis|
           redis.multi do |multi|
-            multi.set(key_for('repositories'), Gitlab::Json.dump(repositories), ex: EXPIRY_TIME)
-            multi.set(key_for('group_id'), group_id, ex: EXPIRY_TIME)
+            multi.set(hashtag_key_for('repositories'), Gitlab::Json.dump(repositories), ex: EXPIRY_TIME)
+            multi.set(hashtag_key_for('group_id'), group_id, ex: EXPIRY_TIME)
           end
         end
       end
@@ -35,13 +36,13 @@ module Gitlab
 
       private
 
-      def key_for(field)
-        "manifest_import:metadata:user:#{user.id}:#{field}"
+      def hashtag_key_for(field)
+        "#{KEY_PREFIX}:{#{user.id}}:#{field}"
       end
 
       def redis_get(field)
         Gitlab::Redis::SharedState.with do |redis|
-          redis.get(key_for(field))
+          redis.get(hashtag_key_for(field))
         end
       end
     end
