@@ -59,13 +59,13 @@ module Gitlab
           ProjectTemplate.new('dotnetcore', '.NET Core', _('A .NET Core console application template, customizable for any .NET Core project'), 'https://gitlab.com/gitlab-org/project-templates/dotnetcore', 'illustrations/third-party-logos/dotnet.svg'),
           ProjectTemplate.new('android', 'Android', _('A ready-to-go template for use with Android apps'), 'https://gitlab.com/gitlab-org/project-templates/android', 'illustrations/logos/android.svg'),
           ProjectTemplate.new('gomicro', 'Go Micro', _('Go Micro is a framework for micro service development'), 'https://gitlab.com/gitlab-org/project-templates/go-micro', 'illustrations/logos/gomicro.svg'),
-          ProjectTemplate.new('astro', 'Pages/Astro', _('Everything you need to create a GitLab Pages site using Astro'), 'https://gitlab.com/pages/astro', 'illustrations/third-party-logos/astro.svg'),
-          ProjectTemplate.new('docusaurus', 'Pages/Docusaurus', _('Everything you need to create a GitLab Pages site using Docusaurus'), 'https://gitlab.com/pages/docusaurus'),
-          ProjectTemplate.new('hugo', 'Pages/Hugo', _('Everything you need to create a GitLab Pages site using Hugo'), 'https://gitlab.com/pages/hugo', 'illustrations/logos/hugo.svg'),
-          ProjectTemplate.new('jekyll', 'Pages/Jekyll', _('Everything you need to create a GitLab Pages site using Jekyll'), 'https://gitlab.com/pages/jekyll', 'illustrations/logos/jekyll.svg'),
-          ProjectTemplate.new('nextjs', 'Pages/Next.js', _('Everything you need to create a GitLab Pages site using Next.js'), 'https://gitlab.com/pages/nextjs'),
-          ProjectTemplate.new('nuxt', 'Pages/Nuxt', _('Everything you need to create a GitLab Pages site using Nuxt'), 'https://gitlab.com/pages/nuxt', 'illustrations/third-party-logos/nuxt.svg'),
-          ProjectTemplate.new('plainhtml', 'Pages/Plain HTML', _('Everything you need to create a GitLab Pages site using plain HTML'), 'https://gitlab.com/pages/plain-html'),
+          ProjectTemplate.new('astro', 'Pages/Astro', _('Template for GitLab Pages and Astro. Astro is a static site generator written in JavaScript.'), 'https://gitlab.com/pages/astro', 'illustrations/third-party-logos/astro.svg'),
+          ProjectTemplate.new('docusaurus', 'Pages/Docusaurus', _('Template for GitLab Pages and Docusaurus. Docusaurus is a static site generator written in React.'), 'https://gitlab.com/pages/docusaurus'),
+          ProjectTemplate.new('hugo', 'Pages/Hugo', _('Template for GitLab Pages and Hugo. Hugo is a static site generator written in Go.'), 'https://gitlab.com/pages/hugo', 'illustrations/logos/hugo.svg'),
+          ProjectTemplate.new('jekyll', 'Pages/Jekyll', _('Template for GitLab Pages and Jekyll. Jekyll is a static site generator written in Ruby.'), 'https://gitlab.com/pages/jekyll', 'illustrations/logos/jekyll.svg'),
+          ProjectTemplate.new('nextjs', 'Pages/Next.js', _('Template for GitLab Pages and Next.js. Next.js is a React framework for building web applications.'), 'https://gitlab.com/pages/nextjs'),
+          ProjectTemplate.new('nuxt', 'Pages/Nuxt', _('Template for GitLab Pages and Nuxt. Nuxt is a Vue framework for building web applications.'), 'https://gitlab.com/pages/nuxt', 'illustrations/third-party-logos/nuxt.svg'),
+          ProjectTemplate.new('plainhtml', 'Pages/Plain HTML', _('Template for GitLab Pages using plain HTML, CSS, and JavaScript.'), 'https://gitlab.com/pages/plain-html'),
           ProjectTemplate.new('gitpod_spring_petclinic', 'Gitpod/Spring Petclinic', _('A Gitpod configured Webapplication in Spring and Java'), 'https://gitlab.com/gitlab-org/project-templates/gitpod-spring-petclinic', 'illustrations/logos/gitpod.svg'),
           ProjectTemplate.new('salesforcedx', 'SalesforceDX', _('A project boilerplate for Salesforce App development with Salesforce Developer tools'), 'https://gitlab.com/gitlab-org/project-templates/salesforcedx'),
           ProjectTemplate.new('serverless_framework', 'Serverless Framework/JS', _('A basic page and serverless function that uses AWS Lambda, AWS API Gateway, and GitLab Pages'), 'https://gitlab.com/gitlab-org/project-templates/serverless-framework', 'illustrations/logos/serverless_framework.svg'),
