@@ -246,12 +246,12 @@ module Gitlab
       @utc_date_regex ||= /\A[0-9]{4}-[0-9]{2}-[0-9]{2}\z/
     end
 
-    def issue
-      @issue ||= /(?<issue>\d+)(?<format>\+s{,1})?(?=\W|\z)/
+    def issue(reference_postfix = nil)
+      /(?<issue>\d{1,20})#{Regexp.escape(reference_postfix) if reference_postfix}(?<format>\+s{,1})?(?=\W|\z)/
     end
 
-    def work_item
-      @work_item ||= /(?<work_item>\d+)(?<format>\+s{,1})?(?=\W|\z)/
+    def work_item(reference_postfix = nil)
+      /(?<work_item>\d{1,20})#{Regexp.escape(reference_postfix) if reference_postfix}(?<format>\+s{,1})?(?=\W|\z)/
     end
 
     def base64_regex
