@@ -4,9 +4,9 @@ module Gitlab
   module SlashCommands
     class IssueNew < IssueCommand
       def self.match(text)
-        # we can not match \n with the dot by passing the m modifier as than
+        # we can not match \n with the dot by passing the m modifier as then
         # the title and description are not separated
-        /\Aissue\s+(new|create)\s+(?<title>[^\n]*)\n*(?<description>(.|\n)*)/.match(text)
+        /\Aissue\s+(?:new|create)\s+(?<title>[^\n]*)\n*(?<description>(?:.|\n)*)/.match(text)
       end
 
       def self.help_message
@@ -37,7 +37,7 @@ module Gitlab
       private
 
       def create_issue(title:, description:)
-        ::Issues::CreateService.new(project: project, current_user: current_user, params: { title: title, description: description }, spam_params: nil).execute
+        ::Issues::CreateService.new(container: project, current_user: current_user, params: { title: title, description: description }, perform_spam_check: false).execute
       end
 
       def presenter(issue)
