@@ -12,13 +12,12 @@ module Gitlab
 
       GIT_NAMESPACE = 'git'
 
-      def initialize(signature_text, signed_text, signer, commit, author_email)
+      def initialize(signature_text, signed_text, signer, commit)
         @signature_text = signature_text
         @signed_text = signed_text
         @signer = signer
         @commit = commit
         @committer_email = commit.committer_email
-        @author_email = author_email
       end
 
       def type
@@ -58,17 +57,12 @@ module Gitlab
       alias_method :key_fingerprint_sha256, :key_fingerprint
 
       def user_id
-        if verification_status == :verified_system && Feature.enabled?(:check_for_mailmapped_commit_emails,
-          @commit.project)
-          return User.find_by_any_email(author_email)&.id
-        end
-
         signed_by_key&.user_id
       end
 
       private
 
-      attr_reader :commit, :committer_email, :author_email
+      attr_reader :commit, :committer_email
 
       def all_attributes_present?
         # Signing an empty string is valid, but signature_text and committer_email
