@@ -2,9 +2,17 @@
 
 module Gitlab
   module TopologyServiceClient
+    DEFAULT_TIMEOUT_IN_SECONDS = 1
+
     class BaseService
-      def initialize
+      def initialize(timeout: nil)
         raise NotImplementedError unless enabled?
+
+        @timeout = timeout
+      end
+
+      def cell_id
+        @cell_id ||= Gitlab.config.cell.id
       end
 
       private
@@ -13,12 +21,17 @@ module Gitlab
         @client ||= service_class.new(
           topology_service_address,
           service_credentials,
-          interceptors: [MetadataInterceptor.new]
+          interceptors: [
+            Labkit::Correlation::GRPC::ClientInterceptor.instance,
+            Gitlab::Cells::TopologyService::MetadataClient.new(
+              Gitlab.config.cell.topology_service_client.metadata)
+          ],
+          **options
         )
       end
 
-      def cell_id
-        @cell_id ||= Gitlab.config.cell.id
+      def options
+        { timeout: @timeout || DEFAULT_TIMEOUT_IN_SECONDS }
       end
 
       def service_credentials
