@@ -28,7 +28,6 @@ module Gitlab
             user: user,
             **extra).to_context, *context
         ]
-        @tracker = nil if reset_tracker?
 
         track_struct_event(tracker, category, action, label: label, property: property, value: value, contexts: contexts)
       end
@@ -55,24 +54,6 @@ module Gitlab
 
       private
 
-      def reset_tracker?
-        return false unless ::Gitlab.staging?
-
-        # reset tracker if any of the features used for creation of tracker changed
-        feature_map = {
-          track_struct_event_logger: Feature.enabled?(:track_struct_event_logger, Feature.current_request),
-          snowplow_sync_emitter: Feature.enabled?(:snowplow_sync_emitter, Feature.current_request),
-          snowplow_emitter_batching_off: Feature.enabled?(:snowplow_emitter_batching_off, :instance)
-        }
-
-        no_feature_changes = feature_map == @feature_map
-
-        return false if no_feature_changes
-
-        @feature_map = feature_map
-        true
-      end
-
       def track_struct_event(destination, category, action, label:, property:, value:, contexts:)
         log_experiment = Feature.enabled?(:track_struct_event_logger, Feature.current_request) &&
           contexts.to_s.include?('experiment')
