@@ -6,13 +6,14 @@ module Security
       private
 
       def update_existing_content!
+        add_stages!([Security::CiConfiguration::DEFAULT_TEST_STAGE]) unless @auto_devops_enabled
         @existing_gitlab_ci_content['include'] = generate_includes
       end
 
       def template
         return 'Auto-DevOps.gitlab-ci.yml' if @auto_devops_enabled
 
-        'Security/Container-Scanning.gitlab-ci.yml'
+        'Jobs/Container-Scanning.gitlab-ci.yml'
       end
 
       def comment
