@@ -18,7 +18,7 @@ module Sidebars
 
         override :sprite_icon
         def sprite_icon
-          'git-merge'
+          'merge-request'
         end
 
         override :render?
@@ -31,14 +31,9 @@ module Sidebars
           true
         end
 
-        override :pill_count
-        def pill_count
-          strong_memoize(:pill_count) do
-            count_service = ::Groups::MergeRequestsCountService
-            count = count_service.new(context.group, context.current_user).count
-
-            format_cached_count(count_service::CACHED_COUNT_THRESHOLD, count)
-          end
+        override :pill_count_field
+        def pill_count_field
+          'openMergeRequestsCount'
         end
 
         override :pill_html_options
@@ -52,6 +47,17 @@ module Sidebars
         def active_routes
           { path: 'groups#merge_requests' }
         end
+
+        override :serialize_as_menu_item_args
+        def serialize_as_menu_item_args
+          super.merge({
+            pill_count: pill_count,
+            pill_count_field: pill_count_field,
+            has_pill: has_pill?,
+            super_sidebar_parent: ::Sidebars::Groups::SuperSidebarMenus::CodeMenu,
+            item_id: :group_merge_request_list
+          })
+        end
       end
     end
   end
