@@ -23,9 +23,9 @@ module Sidebars
       def add_menus
         return unless context.current_user
 
+        add_menu(Sidebars::YourWork::Menus::HomepageMenu.new(context))
         add_menu(Sidebars::YourWork::Menus::ProjectsMenu.new(context))
         add_menu(Sidebars::YourWork::Menus::GroupsMenu.new(context))
-        add_menu(Sidebars::YourWork::Menus::OrganizationsMenu.new(context))
         add_menu(Sidebars::YourWork::Menus::IssuesMenu.new(context))
         add_menu(Sidebars::YourWork::Menus::MergeRequestsMenu.new(context))
         add_menu(Sidebars::YourWork::Menus::TodosMenu.new(context))
