@@ -137,12 +137,6 @@ const transpileDependencyConfig = {
   loader: 'babel-loader',
   options: {
     presets: [['@babel/preset-env', { targets: { esmodules: true } }]],
-    plugins: [
-      // See: https://gitlab.com/gitlab-org/gitlab/-/issues/336216
-      '@babel/plugin-proposal-optional-chaining',
-      // See: https://gitlab.com/gitlab-org/gitlab/-/issues/336216
-      '@babel/plugin-proposal-nullish-coalescing-operator',
-    ],
   },
 };
 
@@ -153,7 +147,6 @@ module.exports = function storybookWebpackConfig({ config }) {
   );
   config.resolve.alias = {
     ...config.resolve.alias,
-    gridstack: require.resolve('gridstack/dist/es5/gridstack.js'),
     '@cubejs-client/core': require.resolve('@cubejs-client/core/dist/cubejs-client-core.js'),
     uuid: require.resolve('uuid'),
     '/assets': path.resolve(__dirname, '../../app/assets'),
