@@ -12,12 +12,12 @@ module Tooling
       DB_DOCS_PATH = %r{\Adb/docs/[^/]+\.ya?ml\z}
 
       SUGGESTION = <<~MESSAGE_MARKDOWN
-        :warning: You have added `gitlab_main_clusterwide` as the schema for this table. We expect most tables to use the
-        `gitlab_main_cell` schema instead, as using the clusterwide schema can have significant scaling implications.
+        :warning: You have added `gitlab_main_clusterwide` (deprecated) as the schema for this table. We expect most tables to use the
+        `gitlab_main_org` schema instead.
 
-        Please see the [guidelines on choosing gitlab schema](https://docs.gitlab.com/ee/development/cells/#choose-either-the-gitlab_main_cell-or-gitlab_main_clusterwide-schema) for more information.
+        Please see the [guidelines on choosing gitlab schema](https://docs.gitlab.com/ee/development/cells/#what-schema-to-choose-if-the-feature-can-be-cluster-wide) for more information.
 
-        Please consult with `@gitlab-com/gl-infra/tenant-scale/organizations` if you believe that the clusterwide schema is the best fit for this table.
+        Please consult with `@gitlab-com/gl-infra/tenant-scale/cells-infrastructure` if you believe that the clusterwide schema is the best fit for this table.
       MESSAGE_MARKDOWN
 
       def add_suggestions_on_using_clusterwide_schema
