@@ -6,6 +6,7 @@ import (
 	"fmt"
 	"io"
 	"net/http"
+	"slices"
 	"sync"
 	"time"
 
@@ -20,6 +21,9 @@ import (
 )
 
 const wsCloseTimeout = 5 * time.Second
+const wsStopWorkflowTimeout = 10 * time.Second
+
+var normalClosureErrCodes = []int{websocket.CloseGoingAway, websocket.CloseNormalClosure}
 
 var marshaler = protojson.MarshalOptions{
 	UseProtoNames:   true,
@@ -48,14 +52,18 @@ type runner struct {
 	rails       *api.API
 	token       string
 	originalReq *http.Request
+	marshalBuf  []byte
 	conn        websocketConn
 	wf          workflowStream
 	client      *Client
 	sendMu      sync.Mutex
+	mcpManager  mcpManager
 }
 
 func newRunner(conn websocketConn, rails *api.API, r *http.Request, cfg *api.DuoWorkflow) (*runner, error) {
-	client, err := NewClient(cfg.ServiceURI, cfg.Headers, cfg.Secure)
+	userAgent := r.Header.Get("User-Agent")
+
+	client, err := NewClient(cfg.ServiceURI, cfg.Headers, cfg.Secure, userAgent)
 	if err != nil {
 		return nil, fmt.Errorf("failed to initialize client: %v", err)
 	}
@@ -65,55 +73,79 @@ func newRunner(conn websocketConn, rails *api.API, r *http.Request, cfg *api.Duo
 		return nil, fmt.Errorf("failed to initialize stream: %v", err)
 	}
 
+	mcpManager, err := newMcpManager(rails, r, cfg.McpServers)
+	if err != nil {
+		// Log the error while the feature is in development
+		log.WithRequest(r).WithError(err).Info("failed to initialize MCP server(s)")
+	}
+
 	return &runner{
 		rails:       rails,
 		token:       cfg.Headers["x-gitlab-oauth-token"],
 		originalReq: r,
+		marshalBuf:  make([]byte, ActionResponseBodyLimit),
 		conn:        conn,
 		wf:          wf,
 		client:      client,
+		mcpManager:  mcpManager,
 	}, nil
 }
 
 func (r *runner) Execute(ctx context.Context) error {
 	errCh := make(chan error, 2)
 
-	go func() {
-		for {
-			if err := r.handleWebSocketMessage(); err != nil {
-				errCh <- err
-				return
-			}
-		}
-	}()
-
-	go func() {
-		for {
-			action, err := r.wf.Recv()
-			if err != nil {
-				if err == io.EOF {
-					errCh <- nil // Expected error when a workflow ends
-				} else {
-					errCh <- fmt.Errorf("duoworkflow: failed to read a gRPC message: %v", err)
-				}
-				return
-			}
-
-			if err := r.handleAgentAction(ctx, action); err != nil {
-				errCh <- err
-				return
-			}
-		}
-	}()
+	go r.handleWebSocketMessages(errCh)
+	go r.handleAgentMessages(ctx, errCh)
 
 	return <-errCh
 }
 
+func (r *runner) handleWebSocketMessages(errCh chan<- error) {
+	for {
+		_, message, err := r.conn.ReadMessage()
+		if err != nil {
+			if e, ok := err.(*websocket.CloseError); ok && slices.Contains(normalClosureErrCodes, e.Code) {
+				reason := fmt.Sprintf("WORKHORSE_WEBSOCKET_CLOSE_%d", e.Code)
+				stopErr := r.stopWorkflow(reason, err)
+				errCh <- fmt.Errorf("handleWebSocketMessages: %v", stopErr)
+				return
+			}
+
+			errCh <- fmt.Errorf("handleWebSocketMessages: failed to read a WS message: %v", err)
+			return
+		}
+
+		if err := r.handleWebSocketMessage(message); err != nil {
+			errCh <- err
+			return
+		}
+	}
+}
+
+func (r *runner) handleAgentMessages(ctx context.Context, errCh chan<- error) {
+	for {
+		action, err := r.wf.Recv()
+		if err != nil {
+			if err == io.EOF {
+				errCh <- nil // Expected error when a workflow ends
+			} else {
+				errCh <- fmt.Errorf("handleAgentMessages: failed to read a gRPC message: %v", err)
+			}
+			return
+		}
+
+		if err := r.handleAgentAction(ctx, action); err != nil {
+			errCh <- err
+			return
+		}
+	}
+}
+
 func (r *runner) Close() error {
 	r.sendMu.Lock()
 	defer r.sendMu.Unlock()
 
-	return errors.Join(r.wf.CloseSend(), r.client.Close(), r.closeWebSocketConnection())
+	return errors.Join(r.wf.CloseSend(), r.client.Close(), r.closeWebSocketConnection(), r.mcpManager.Close())
 }
 
 func (r *runner) closeWebSocketConnection() error {
@@ -142,15 +174,14 @@ func (r *runner) closeWebSocketConnection() error {
 	return nil
 }
 
-func (r *runner) handleWebSocketMessage() error {
-	_, message, err := r.conn.ReadMessage()
-	if err != nil {
-		return fmt.Errorf("handleWebSocketMessage: failed to read a WS message: %v", err)
+func (r *runner) handleWebSocketMessage(message []byte) error {
+	response := &pb.ClientEvent{}
+	if err := unmarshaler.Unmarshal(message, response); err != nil {
+		return fmt.Errorf("handleWebSocketMessage: failed to unmarshal a WS message: %v", err)
 	}
 
-	response := &pb.ClientEvent{}
-	if err = unmarshaler.Unmarshal(message, response); err != nil {
-		return fmt.Errorf("handleWebSocketMessage: failed to unmarshal a WS message: %v", err)
+	if startReq := response.GetStartRequest(); startReq != nil {
+		startReq.McpTools = append(startReq.McpTools, r.mcpManager.Tools()...)
 	}
 
 	log.WithContextFields(r.originalReq.Context(), log.Fields{
@@ -159,7 +190,7 @@ func (r *runner) handleWebSocketMessage() error {
 		"request_id":   response.GetActionResponse().GetRequestID(),
 	}).Info("Sending action response")
 
-	if err = r.threadSafeSend(response); err != nil {
+	if err := r.threadSafeSend(response); err != nil {
 		if err == io.EOF {
 			// ignore EOF to let Recv() fail and return a meaningful message
 			return nil
@@ -185,8 +216,8 @@ func (r *runner) handleAgentAction(ctx context.Context, action *pb.Action) error
 		if err != nil {
 			return fmt.Errorf("handleAgentAction: failed to perform API call: %v", err)
 		}
-
 		statusCode := event.GetActionResponse().GetHttpResponse().StatusCode
+
 		log.WithContextFields(r.originalReq.Context(), log.Fields{
 			"path":                 action.GetRunHTTPRequest().Path,
 			"method":               action.GetRunHTTPRequest().Method,
@@ -196,21 +227,56 @@ func (r *runner) handleAgentAction(ctx context.Context, action *pb.Action) error
 			"action_response_type": fmt.Sprintf("%T", event.GetActionResponse().GetResponseType()),
 			"request_id":           action.GetRequestID(),
 		}).Info("Sending HTTP response event")
+
 		if err := r.threadSafeSend(event); err != nil {
 			return fmt.Errorf("handleAgentAction: failed to send gRPC message: %v", err)
 		}
+
 		log.WithContextFields(r.originalReq.Context(), log.Fields{
 			"path": action.GetRunHTTPRequest().Path,
 		}).Info("Successfully sent HTTP response event")
+	case *pb.Action_RunMCPTool:
+		mcpTool := action.GetRunMCPTool()
 
-	default:
-		message, err := marshaler.Marshal(action)
+		// If a tool is not recongnized, propagate the message to the client
+		// It's possible when a user has local MCP servers configured in IDE
+		if !r.mcpManager.HasTool(mcpTool.Name) {
+			return r.sendActionToWs(action)
+		}
+		event, err := r.mcpManager.CallTool(ctx, action)
 		if err != nil {
-			return fmt.Errorf("handleAgentAction: failed to unmarshal action: %v", err)
+			return fmt.Errorf("handleAgentAction: failed to call MCP tool: %v", err)
 		}
 
-		if err = r.conn.WriteMessage(websocket.BinaryMessage, message); err != nil {
-			return fmt.Errorf("handleAgentAction: failed to send WS message: %v", err)
+		log.WithContextFields(ctx, log.Fields{
+			"request_id":           action.GetRequestID(),
+			"name":                 mcpTool.Name,
+			"args_size":            len(mcpTool.Args),
+			"payload_size":         proto.Size(event),
+			"event_type":           fmt.Sprintf("%T", event.Response),
+			"action_response_type": fmt.Sprintf("%T", event.GetActionResponse().GetResponseType()),
+		}).Info("Sending MCP tool response")
+
+		if err := r.threadSafeSend(event); err != nil {
+			return fmt.Errorf("handleAgentAction: failed to send gRPC message: %v", err)
+		}
+	default:
+		return r.sendActionToWs(action)
+	}
+
+	return nil
+}
+
+func (r *runner) sendActionToWs(action *pb.Action) error {
+	var err error
+	r.marshalBuf, err = marshaler.MarshalAppend(r.marshalBuf[:0], action)
+	if err != nil {
+		return fmt.Errorf("sendActionToWs: failed to unmarshal action: %v", err)
+	}
+
+	if err = r.conn.WriteMessage(websocket.BinaryMessage, r.marshalBuf); err != nil {
+		if err != websocket.ErrCloseSent {
+			return fmt.Errorf("sendActionToWs: failed to send WS message: %v", err)
 		}
 	}
 
@@ -222,3 +288,55 @@ func (r *runner) threadSafeSend(event *pb.ClientEvent) error {
 	defer r.sendMu.Unlock()
 	return r.wf.Send(event)
 }
+
+func (r *runner) stopWorkflow(reason string, closeErr error) error {
+	log.WithRequest(r.originalReq).WithFields(log.Fields{
+		"close_error": closeErr.Error(),
+	}).Info("stopWorkflow: sending stop workflow request...")
+
+	stopRequest := &pb.ClientEvent{
+		Response: &pb.ClientEvent_StopWorkflow{
+			StopWorkflow: &pb.StopWorkflowRequest{
+				Reason: reason,
+			},
+		},
+	}
+
+	if err := r.threadSafeSend(stopRequest); err != nil {
+		return fmt.Errorf("failed to send stop request: %v", err)
+	}
+
+	select {
+	case <-r.originalReq.Context().Done():
+		return nil
+	case <-time.After(wsStopWorkflowTimeout):
+		return fmt.Errorf("workflow didn't stop on time")
+	}
+}
+
+// Shutdown gracefully stops the workflow runner during server shutdown.
+// It sends a stop workflow request to the agent platform and waits for acknowledgment.
+// If the original request context is already canceled, it returns immediately.
+// Errors during shutdown are logged but not returned to allow other runners to proceed.
+func (r *runner) Shutdown(ctx context.Context) error {
+	select {
+	case <-r.originalReq.Context().Done():
+		return nil
+	case <-ctx.Done():
+		err := r.stopWorkflow(
+			"WORKHORSE_SERVER_SHUTDOWN",
+			fmt.Errorf("duoworkflow: stopping workflow due to server shutdown"),
+		)
+		if err == nil {
+			log.WithRequest(r.originalReq).WithError(
+				fmt.Errorf("duoworkflow: stopped gracefully due to server shutdown"),
+			).Error()
+		} else {
+			log.WithRequest(r.originalReq).WithError(
+				fmt.Errorf("duoworkflow: failed to gracefully stop a workflow: %v", err),
+			).Error()
+		}
+
+		return err
+	}
+}
