@@ -20,7 +20,7 @@ func TestBlocker(t *testing.T) {
 		{
 			desc:        "blocked",
 			contentType: ResponseContentType,
-			out:         "Internal server error\n",
+			out:         "Internal Server Error\n",
 		},
 		{
 			desc:        "pass",
@@ -41,7 +41,7 @@ func TestBlocker(t *testing.T) {
 			upstreamBody := []byte(upstreamResponse)
 			n, err := bl.Write(upstreamBody)
 			require.NoError(t, err)
-			require.Equal(t, len(upstreamBody), n, "bytes written")
+			require.Len(t, upstreamBody, n, "bytes written")
 
 			rw.Flush()
 
@@ -54,3 +54,13 @@ func TestBlocker(t *testing.T) {
 		})
 	}
 }
+
+func TestBlockerFlushable(t *testing.T) {
+	rw := httptest.NewRecorder()
+	b := blocker{rw: rw}
+	rc := http.NewResponseController(&b) //nolint:bodyclose
+
+	err := rc.Flush()
+	require.NoError(t, err, "the underlying response writer is not flushable")
+	require.True(t, rw.Flushed)
+}
