@@ -4,11 +4,11 @@ import (
 	"fmt"
 	"net/http"
 
-	"gitlab.com/gitlab-org/gitaly/v15/proto/go/gitalypb"
+	"gitlab.com/gitlab-org/gitaly/v16/proto/go/gitalypb"
 
 	"gitlab.com/gitlab-org/gitlab/workhorse/internal/api"
 	"gitlab.com/gitlab-org/gitlab/workhorse/internal/gitaly"
-	"gitlab.com/gitlab-org/gitlab/workhorse/internal/helper"
+	"gitlab.com/gitlab-org/gitlab/workhorse/internal/helper/fail"
 	"gitlab.com/gitlab-org/gitlab/workhorse/internal/log"
 	"gitlab.com/gitlab-org/gitlab/workhorse/internal/senddata"
 )
@@ -24,23 +24,19 @@ var SendDiff = &diff{"git-diff:"}
 func (d *diff) Inject(w http.ResponseWriter, r *http.Request, sendData string) {
 	var params diffParams
 	if err := d.Unpack(&params, sendData); err != nil {
-		helper.Fail500(w, r, fmt.Errorf("SendDiff: unpack sendData: %v", err))
+		fail.Request(w, r, fmt.Errorf("SendDiff: unpack sendData: %v", err))
 		return
 	}
 
 	request := &gitalypb.RawDiffRequest{}
 	if err := gitaly.UnmarshalJSON(params.RawDiffRequest, request); err != nil {
-		helper.Fail500(w, r, fmt.Errorf("diff.RawDiff: %v", err))
+		fail.Request(w, r, fmt.Errorf("diff.RawDiff: %v", err))
 		return
 	}
 
-	ctx, diffClient, err := gitaly.NewDiffClient(
-		r.Context(),
-		params.GitalyServer,
-		gitaly.WithFeatures(params.GitalyServer.Features),
-	)
+	ctx, diffClient, err := gitaly.NewDiffClient(r.Context(), params.GitalyServer)
 	if err != nil {
-		helper.Fail500(w, r, fmt.Errorf("diff.RawDiff: %v", err))
+		fail.Request(w, r, fmt.Errorf("diff.RawDiff: %v", err))
 		return
 	}
 
