@@ -1,26 +1,31 @@
+// Package staticpages provides functionality for serving static pages and handling errors.
 package staticpages
 
 import (
+	"fmt"
 	"net/http"
 	"os"
 	"path/filepath"
-
-	"gitlab.com/gitlab-org/gitlab/workhorse/internal/helper"
 )
 
+// DeployPage deploys the index.html page by serving it using the provided handler.
 func (s *Static) DeployPage(handler http.Handler) http.Handler {
 	deployPage := filepath.Join(s.DocumentRoot, "index.html")
 
 	return http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
-		data, err := os.ReadFile(deployPage)
+		cleanURL := filepath.Clean(deployPage)
+		data, err := os.ReadFile(cleanURL)
 		if err != nil {
 			handler.ServeHTTP(w, r)
 			return
 		}
 
-		helper.SetNoCacheHeaders(w.Header())
+		setNoCacheHeaders(w.Header())
 		w.Header().Set("Content-Type", "text/html; charset=utf-8")
 		w.WriteHeader(http.StatusOK)
-		w.Write(data)
+		_, err = w.Write(data)
+		if err != nil {
+			fmt.Printf("Error reading deploy page file: %v\n", err)
+		}
 	})
 }
