@@ -2,6 +2,7 @@
 package upload
 
 import (
+	"errors"
 	"fmt"
 	"io"
 	"net/http"
@@ -53,7 +54,17 @@ func processRequestBody(h http.Handler, p Preparer, w http.ResponseWriter, r *ht
 
 	fh, err := destination.Upload(r.Context(), r.Body, r.ContentLength, "upload", opts)
 	if err != nil {
-		fail.Request(w, r, fmt.Errorf("RequestBody: upload failed: %v", err))
+		status := http.StatusInternalServerError
+		if errors.Is(err, destination.ErrEntityTooLarge) {
+			status = http.StatusRequestEntityTooLarge
+		}
+		wrappedErr := fmt.Errorf("RequestBody: upload failed: %w", err)
+		// For entity too large errors, include the detailed error message in the response body
+		if status == http.StatusRequestEntityTooLarge {
+			fail.Request(w, r, wrappedErr, fail.WithStatus(status), fail.WithBody(wrappedErr.Error()))
+		} else {
+			fail.Request(w, r, wrappedErr, fail.WithStatus(status))
+		}
 		return
 	}
 
@@ -67,6 +78,7 @@ func processRequestBody(h http.Handler, p Preparer, w http.ResponseWriter, r *ht
 	for k, v := range fields {
 		data.Set(k, v)
 	}
+	data.Set("Content-Type", r.Header.Get("Content-Type"))
 
 	// Hijack body
 	body := data.Encode()
