@@ -1,16 +1,13 @@
-package objectstore_test
+package objectstore
 
 import (
 	"context"
-	"fmt"
 	"strings"
 	"testing"
 	"time"
 
 	"github.com/stretchr/testify/require"
 
-	"gitlab.com/gitlab-org/gitlab/workhorse/internal/testhelper"
-	"gitlab.com/gitlab-org/gitlab/workhorse/internal/upload/destination/objectstore"
 	"gitlab.com/gitlab-org/gitlab/workhorse/internal/upload/destination/objectstore/test"
 )
 
@@ -22,8 +19,8 @@ func TestGoCloudObjectUpload(t *testing.T) {
 
 	objectName := "test.png"
 	testURL := "azuretest://azure.example.com/test-container"
-	p := &objectstore.GoCloudObjectParams{Ctx: ctx, Mux: mux, BucketURL: testURL, ObjectName: objectName}
-	object, err := objectstore.NewGoCloudObject(p)
+	p := &GoCloudObjectParams{Ctx: ctx, Mux: mux, BucketURL: testURL, ObjectName: objectName}
+	object, err := NewGoCloudObject(p)
 	require.NotNil(t, object)
 	require.NoError(t, err)
 
@@ -40,16 +37,16 @@ func TestGoCloudObjectUpload(t *testing.T) {
 	require.NoError(t, err)
 	require.Equal(t, []byte(test.ObjectContent), received)
 
+	attr, err := bucket.Attributes(ctx, objectName)
+	require.NoError(t, err)
+	require.Empty(t, attr.ContentType)
+
 	cancel()
 
-	testhelper.Retry(t, 5*time.Second, func() error {
+	require.Eventually(t, func() bool {
 		exists, err := bucket.Exists(ctx, objectName)
 		require.NoError(t, err)
 
-		if exists {
-			return fmt.Errorf("file %s is still present", objectName)
-		} else {
-			return nil
-		}
-	})
+		return !exists
+	}, 5*time.Second, time.Millisecond, "file %s is still present", objectName)
 }
